@@ -1,5 +1,5 @@
 <?php
-// $Id: useradmin.php,v 1.12.2.3 2006/06/20 06:05:20 makotonton Exp $
+// $Id: useradmin.php,v 1.24 2006/11/30 06:35:30 makotonton Exp $
 //  ------------------------------------------------------------------------ //
 //                XOOPS - PHP Content Management System                      //
 //                    Copyright (c) 2000 XOOPS.org                           //
@@ -80,13 +80,13 @@ foreach( array( 'op' => 'mod_users',
                 'private_item_number_limit' => null,
                 'private_index_number_limit' => null,
                 'private_item_storage_limit' => null,
-                'user_icq' => null,
-                'user_aim' => null,
-                'user_yim' => null,
-                'user_msnm' => null,
-                'user_from' => null,
+                // 'user_icq' => null,
+                // 'user_aim' => null,
+                // 'user_yim' => null,
+                // 'user_msnm' => null,
+                // 'user_from' => null,
                 'user_viewemail' => null,
-                'user_occ' => null,
+                // 'user_occ' => null,
                 'user_intrest' => null,
                 'user_sig' => null,
                 'attachsig' => null,
@@ -94,17 +94,17 @@ foreach( array( 'op' => 'mod_users',
                 'uorder' => null,
                 'notify_method' => null,
                 'notify_mode' => null,
-                'bio' => null,
+                // 'bio' => null,
                 'rank' => null,
                 'password' => null,
                 'pass2' => null,
                 'user_mailok' => null,
                 'groups' => null,
+                'posi' => null,
+                'appeal' => null,
                 'fct' => null,
                 'op' => null,
                 'del_uid' => null,
-                'id' => null,
-                'type' => null,
                 'uid' => null ) as $k => $v ){
     if( array_key_exists( $k, $_GET ) ){
         $$k = $_GET[$k];
@@ -186,17 +186,29 @@ function displayUsers()
 	$email_value = "";
 	$email_cbox_value = 0;
 	$url_value = "";
+	$posi_value = 0;
 //	$avatar_value = "blank.gif";
 //	$theme_value = $xoopsConfig['default_theme'];
-	$timezone_value = $xoopsConfig['default_TZ'];
 // start of XooNIps user info
-	$address_value = "";
 	$division_value = "";
+	$company_name_value = "";
 	$tel_value = "";
 	$fax_value = "";
-	$company_name_value = "";
+	$address_value = "";
 	$country_value = "";
 	$zipcode_value = "";
+	$timezone_value = $xoopsConfig['default_TZ'];
+// end of XooNIps user info
+	// $icq_value = "";
+	// $aim_value = "";
+	// $yim_value = "";
+	// $msnm_value = "";
+	// $location_value = "";
+	// $occ_value = "";
+	$interest_value = "";
+	$appeal_value = "";
+	$sig_value = "";
+	$sig_cbox_value = 0;
 	$notice_mail_value = "";
 	foreach( array( 'private_item_number_limit', 'private_index_number_limit', 'private_item_storage_limit' ) as $k ){
 		$val = '';
@@ -206,23 +218,13 @@ function displayUsers()
 		}
 	}
 	$private_item_storage_limit_value /= 1000000;
-// end of XooNIps user info
-	$icq_value = "";
-	$aim_value = "";
-	$yim_value = "";
-	$msnm_value = "";
-	$location_value = "";
-	$occ_value = "";
-	$interest_value = "";
-	$sig_value = "";
-	$sig_cbox_value = 0;
 	$umode_value = $xoopsConfig['com_mode'];
 	$uorder_value = $xoopsConfig['com_order'];
 	// RMV-NOTIFY
 	include_once XOOPS_ROOT_PATH . '/include/notification_constants.php';
 	$notify_method_value = XOOPS_NOTIFICATION_METHOD_PM;
 	$notify_mode_value = XOOPS_NOTIFICATION_MODE_SENDALWAYS;
-	$bio_value = "";
+	// $bio_value = "";
 	$rank_value = 0;
 	$mailok_value = 0;
 	$op_value = "addUser";
@@ -235,7 +237,7 @@ function displayUsers()
 
 function modifyUser($user)
 {
-	global $xnpsid, $xoopsConfig, $myts;
+	global $xnpsid, $xoopsConfig, $myts, $xoopsDB;
 	xoops_cp_header();
 	$member_handler =& xoops_gethandler('member');
 	$user =& $member_handler->getUser($user);
@@ -261,11 +263,11 @@ function modifyUser($user)
 //		$theme_value = empty($temp) ? $xoopsConfig['default_theme'] : $temp;
 		$timezone_value = $user->getVar("timezone_offset");
 // start of XooNIps user info
-		$address_value = $xoonips_user['address'];
 		$division_value = $xoonips_user['division'];
+		$company_name_value = $xoonips_user['company_name'];
 		$tel_value = $xoonips_user['tel'];
 		$fax_value = $xoonips_user['fax'];
-		$company_name_value = $xoonips_user['company_name'];
+		$address_value = $xoonips_user['address'];
 		$country_value = $xoonips_user['country'];
 		$zipcode_value = $xoonips_user['zipcode'];
 		$notice_mail_value = $xoonips_user['notice_mail'];
@@ -273,11 +275,11 @@ function modifyUser($user)
 		$private_index_number_limit_value = $xoonips_user['index_number_limit'];
 		$private_item_storage_limit_value = $xoonips_user['item_storage_limit'] / 1000000;
 
-		$address_value = htmlspecialchars($address_value, ENT_QUOTES);
 		$division_value = htmlspecialchars($division_value, ENT_QUOTES);
+		$company_name_value = htmlspecialchars($company_name_value, ENT_QUOTES);
 		$tel_value = htmlspecialchars($tel_value, ENT_QUOTES);
 		$fax_value = htmlspecialchars($fax_value, ENT_QUOTES);
-		$company_name_value = htmlspecialchars($company_name_value, ENT_QUOTES);
+		$address_value = htmlspecialchars($address_value, ENT_QUOTES);
 		$country_value = htmlspecialchars($country_value, ENT_QUOTES);
 		$zipcode_value = htmlspecialchars($zipcode_value, ENT_QUOTES);
 		$notice_mail_value = htmlspecialchars($notice_mail_value, ENT_QUOTES);
@@ -285,12 +287,12 @@ function modifyUser($user)
 		$private_index_number_limit_value = htmlspecialchars($private_index_number_limit_value, ENT_QUOTES);
 		$private_item_storage_limit_value = htmlspecialchars($private_item_storage_limit_value, ENT_QUOTES);
 // end of XooNIps user info
-		$icq_value = $user->getVar("user_icq", "E");
-		$aim_value = $user->getVar("user_aim", "E");
-		$yim_value = $user->getVar("user_yim", "E");
-		$msnm_value = $user->getVar("user_msnm", "E");
-		$location_value = $user->getVar("user_from", "E");
-		$occ_value = $user->getVar("user_occ", "E");
+		// $icq_value = $user->getVar("user_icq", "E");
+		// $aim_value = $user->getVar("user_aim", "E");
+		// $yim_value = $user->getVar("user_yim", "E");
+		// $msnm_value = $user->getVar("user_msnm", "E");
+		// $location_value = $user->getVar("user_from", "E");
+		// $occ_value = $user->getVar("user_occ", "E");
 		$interest_value = $user->getVar("user_intrest", "E");
 		$sig_value = $user->getVar("user_sig", "E");
 		$sig_cbox_value = ($user->getVar("attachsig") == 1) ? 1 : 0;
@@ -299,13 +301,30 @@ function modifyUser($user)
 		// RMV-NOTIFY
 		$notify_method_value = $user->getVar("notify_method");
 		$notify_mode_value = $user->getVar("notify_mode");
-		$bio_value = $user->getVar("bio", "E");
+		// $bio_value = $user->getVar("bio", "E");
 		$rank_value = $user->rank(false);
 		$mailok_value = $user->getVar('user_mailok', 'E');
 		$op_value = "updateUser";
 		$form_title = _AM_UPDATEUSER.": ".$user->getVar("uname");
 		$form_isedit = true;
 		$groups = array_values($user->getGroups());
+		$atab = $xoopsDB -> prefix('xoonips_users');
+		$userid = $xoonips_user['uid'];
+		$asql = "SELECT posi, appeal FROM $atab WHERE uid=$userid";
+		$ares = $xoopsDB->query( $asql );
+		$arow = $xoopsDB ->fetchArray($ares);
+		if( !isset( $posi->_posi ) && intval($arow['posi']) !== 0 ) {
+			$ptab = $xoopsDB -> prefix('xoonips_positions');
+			$posiid = intval($arow['posi']);
+			$twsql = "SELECT posi_title, posi_id FROM ".$ptab." WHERE posi_id = ".$posiid." ORDER BY posi_order DESC";
+			$twres = $xoopsDB -> query( $twsql );
+			$posi = $xoopsDB->fetchArray( $twres );
+			$posi['title'] = $myts->makeTboxData4Show($posi['posi_title']);
+			$posi['id'] = intval($posi['posi_id']);
+			$_SESSION['posi_id'] = $posi['id'];
+		}
+		$appeal_value = $arow['appeal'];
+		$appeal_value = htmlspecialchars($appeal_value, ENT_QUOTES);
 		include XOOPS_ROOT_PATH."/modules/xoonips/include/useradminform.php";
 		echo "<br /><string>"._AM_USERPOST."</string><br /><br />\n";
 		echo "<table>\n";
@@ -328,7 +347,7 @@ function modifyUser($user)
 }
 
 // RMV-NOTIFY
-function updateUser($uid, $uname, $name, $url, $email, $user_icq, $user_aim, $user_yim, $user_msnm, $user_from, $user_occ, $user_intrest, $user_viewemail, $user_avatar, $user_sig, $attachsig, $theme, $pass, $pass2, $rank, $bio, $uorder, $umode, $notify_method, $notify_mode, $timezone_offset, $user_mailok, $groups = array())
+function updateUser($uid, $uname, $name, $url, $email, $user_intrest, $user_viewemail, $user_avatar, $user_sig, $attachsig, $theme, $pass, $pass2, $rank, $uorder, $umode, $notify_method, $notify_mode, $timezone_offset, $user_mailok, $groups, $posi, $appeal = array())
 {
 	$member_handler =& xoops_gethandler('member');
 	$edituser =& $member_handler->getUser($uid);
@@ -344,14 +363,14 @@ function updateUser($uid, $uname, $name, $url, $email, $user_icq, $user_aim, $us
 			$edituser->setVar("url", formatURL($url));
 		}
 	//	$edituser->setVar("user_avatar", $user_avatar);
-		$edituser->setVar("user_icq", $user_icq);
-		$edituser->setVar("user_from", $user_from);
+	//	$edituser->setVar("user_icq", $user_icq);
+	//	$edituser->setVar("user_from", $user_from);
 		$edituser->setVar("user_sig", $user_sig);
 		$user_viewemail = (isset($user_viewemail) && $user_viewemail == 1) ? 1 : 0;
 		$edituser->setVar("user_viewemail", $user_viewemail);
-		$edituser->setVar("user_aim", $user_aim);
-		$edituser->setVar("user_yim", $user_yim);
-		$edituser->setVar("user_msnm", $user_msnm);
+	//	$edituser->setVar("user_aim", $user_aim);
+	//	$edituser->setVar("user_yim", $user_yim);
+	//	$edituser->setVar("user_msnm", $user_msnm);
 		$attachsig = (isset($attachsig) && $attachsig == 1) ? 1 : 0;
 		$edituser->setVar("attachsig", $attachsig);
 		$edituser->setVar("timezone_offset", $timezone_offset);
@@ -361,9 +380,9 @@ function updateUser($uid, $uname, $name, $url, $email, $user_icq, $user_aim, $us
 		// RMV-NOTIFY
 		$edituser->setVar("notify_method", $notify_method);
 		$edituser->setVar("notify_mode", $notify_mode);
-		$edituser->setVar("bio", $bio);
+	//	$edituser->setVar("bio", $bio);
 		$edituser->setVar("rank", $rank);
-		$edituser->setVar("user_occ", $user_occ);
+	//	$edituser->setVar("user_occ", $user_occ);
 		$edituser->setVar("user_intrest", $user_intrest);
 		$edituser->setVar('user_mailok', $user_mailok);
 		if ($pass2 != "") {
@@ -397,6 +416,23 @@ function updateUser($uid, $uname, $name, $url, $email, $user_icq, $user_aim, $us
 		            $member_handler->addUserToGroup($groupid, $edituser->getVar('uid'));
 		        }
 		    }
+			if( strlen( trim( $_POST['posi'] ) ) !== 0 ) {
+				global $xoopsDB;
+				$insposi = $_POST['posi'];
+				$insuid = $_POST['uid'];
+				$iptab = $xoopsDB -> prefix("xoonips_users");
+				$ipsql = "UPDATE $iptab SET posi = $insposi WHERE uid = $insuid";
+				$ipres = $xoopsDB -> query( $ipsql );
+				$_SESSION['posi_id'] = array();
+			}
+			if( strlen( trim( $_POST['appeal'] ) ) !== 0 ) {
+				global $xoopsDB;
+				$insapp = $_POST['appeal'];
+				$insuid = $_POST['uid'];
+				$iatab = $xoopsDB -> prefix("xoonips_users");
+				$iasql = "UPDATE $iatab SET appeal = '$insapp' WHERE uid = $insuid";
+                   		$iares = $xoopsDB -> query( $iasql );
+			}
 			redirect_header("useradmin.php",1,_AM_DBUPDATED);
 		}
 	}
@@ -467,14 +503,16 @@ case "updateUser":
 		redirect_header("useradmin.php",2,_MD_XOONIPS_ACCOUNT_CANNOT_UPDATE_USER_INFO);
 		exit();
 	}
-	$new_user['address'] = $myts->stripSlashesGPC($address);
+	$new_user['posi'] = $myts->stripSlashesGPC($posi);
 	$new_user['division'] = $myts->stripSlashesGPC($division);
 	$new_user['company_name'] = $myts->stripSlashesGPC($company_name);
 	$new_user['tel'] = $myts->stripSlashesGPC($tel);
 	$new_user['fax'] = $myts->stripSlashesGPC($fax);
+	$new_user['address'] = $myts->stripSlashesGPC($address);
 	$new_user['country'] = $myts->stripSlashesGPC($country);
 	$new_user['zipcode'] = $myts->stripSlashesGPC($zipcode);
-	$new_user['fax'] = $myts->stripSlashesGPC($fax);
+//	$new_user['fax'] = $myts->stripSlashesGPC($fax);
+	$new_user['appeal'] = $myts->stripSlashesGPC($appeal);
 	$new_user['notice_mail'] = $myts->stripSlashesGPC($notice_mail);
 	$new_user['item_storage_limit'] = max( 0, $private_item_storage_limit ) * 1000000;// storage_limit is changed MegaByte into Byte.
 	$new_user['item_number_limit'] = max( 0, $private_item_number_limit );
@@ -486,13 +524,23 @@ case "updateUser":
 // end of updating XooNIps user information
         $user_avatar = ''; // for PHP Notice message
         $theme = '';       // for PHP Notice message
-	updateUser($uid, $username, $name, $url, $email, $user_icq, $user_aim, $user_yim, $user_msnm, $user_from, $user_occ, $user_intrest, $user_viewemail, $user_avatar, $user_sig, $attachsig, $theme, $password, $pass2, $rank, $bio, $uorder, $umode, $notify_method, $notify_mode, $timezone_offset, $user_mailok, $groups);
+	// updateUser($uid, $username, $name, $url, $email, $user_icq, $user_aim, $user_yim, $user_msnm, $user_from, $user_occ, $user_intrest, $user_viewemail, $user_avatar, $user_sig, $attachsig, $theme, $password, $pass2, $rank, $bio, $uorder, $umode, $notify_method, $notify_mode, $timezone_offset, $user_mailok, $groups, $posi, $appeal);
+	updateUser($uid, $username, $name, $url, $email, $user_intrest, $user_viewemail, $user_avatar, $user_sig, $attachsig, $theme, $password, $pass2, $rank, $uorder, $umode, $notify_method, $notify_mode, $timezone_offset, $user_mailok, $groups, $posi, $appeal);
 	break;
 case "delUser":
 	xoops_cp_header();
 	$member_handler =& xoops_gethandler('member');
 	$userdata =& $member_handler->getUser($uid);
 	xoops_confirm(array('fct' => 'users', 'op' => 'delUserConf', 'del_uid' => $userdata->getVar('uid')), 'useradmin.php', sprintf(_AM_AYSYWTDU,$userdata->getVar('uname')));
+	// delete uid from xoonips_item_show
+	$dsql = "DELETE FROM ".$xoopsDB->prefix('xoonips_item_show')." WHERE uid = ".$uid."";
+	$dres = $xoopsDB->query($dsql);
+		if(!$dres){
+			$err = "Can't select data from database.";
+		}
+		if($dres == FALSE){
+			echo "ERROR: SQL=$dsql<br />\n error=" . $xoopsDB->error() . "<br />\n";
+		}
 	xoops_cp_footer();
 	break;
 case "delete_many":
@@ -626,11 +674,11 @@ case "addUser":
 			$newuser['url'] = formatURL($url);
 			$newuser['user_avatar'] = 'blank.gif';
 // start of XooNIps user information
-			$newuser['address'] = $myts->stripSlashesGPC($address);
 			$newuser['division'] = $myts->stripSlashesGPC($division);
 			$newuser['company_name'] = $myts->stripSlashesGPC($company_name);
 			$newuser['tel'] = $myts->stripSlashesGPC($tel);
 			$newuser['fax'] = $myts->stripSlashesGPC($fax);
+			$newuser['address'] = $myts->stripSlashesGPC($address);
 			$newuser['country'] = $myts->stripSlashesGPC($country);
 			$newuser['zipcode'] = $myts->stripSlashesGPC($zipcode);
 			$newuser['fax'] = $myts->stripSlashesGPC($fax);
@@ -639,12 +687,12 @@ case "addUser":
 			$newuser['item_number_limit'] = max( 0, $private_item_number_limit );
 			$newuser['index_number_limit'] = max( 0, $private_index_number_limit );
 // end of XooNIps user information
-			$newuser['user_icq'] = $myts->stripSlashesGPC($user_icq);
-			$newuser['user_from'] = $myts->stripSlashesGPC($user_from);
-			$newuser['user_sig'] = $myts->stripSlashesGPC($user_sig);
-			$newuser['user_aim'] = $myts->stripSlashesGPC($user_aim);
-			$newuser['user_yim'] = $myts->stripSlashesGPC($user_yim);
-			$newuser['user_msnm'] = $myts->stripSlashesGPC($user_msnm);
+			// $newuser['user_icq'] = $myts->stripSlashesGPC($user_icq);
+			// $newuser['user_from'] = $myts->stripSlashesGPC($user_from);
+			// $newuser['user_sig'] = $myts->stripSlashesGPC($user_sig);
+			// $newuser['user_aim'] = $myts->stripSlashesGPC($user_aim);
+			// $newuser['user_yim'] = $myts->stripSlashesGPC($user_yim);
+			// $newuser['user_msnm'] = $myts->stripSlashesGPC($user_msnm);
 			if ($pass2 != "") {
 				if ( $password != $pass2 ) {
 					xoops_cp_header();
@@ -661,12 +709,14 @@ case "addUser":
 			// RMV-NOTIFY
 			$newuser['notify_method'] = $myts->stripSlashesGPC($notify_method);
 			$newuser['notify_mode'] = $myts->stripSlashesGPC($notify_mode);
-			$newuser['bio'] = $myts->stripSlashesGPC($bio);
+			// $newuser['bio'] = $myts->stripSlashesGPC($bio);
 			$newuser['rank'] = $myts->stripSlashesGPC($rank);
 			$newuser['level'] = 1;
-			$newuser['user_occ'] = $myts->stripSlashesGPC($user_occ);
+			// $newuser['user_occ'] = $myts->stripSlashesGPC($user_occ);
 			$newuser['user_intrest'] = $myts->stripSlashesGPC($user_intrest);
 			$newuser['user_mailok'] = $myts->stripSlashesGPC($user_mailok);
+			$newuser['posi'] = $myts->stripSlashesGPC($posi);
+			$newuser['appeal'] = $myts->stripSlashesGPC($appeal);
 			$uid = 0;
 			if (xnp_insert_account($xnpsid, $newuser, $uid)!=RES_OK) {
 				$adduser_errormsg = _AM_CNRNU;
@@ -675,6 +725,76 @@ case "addUser":
 				if (!$member_handler->addUserToGroup(XOOPS_GROUP_USERS, $uid)) {
 					$adduser_errormsg = _AM_CNRNU2;
 				} else {
+					global $xoopsUser;
+				    $member_handler =& xoops_gethandler('member');
+                    if (!empty($_POST['groups'])) {
+                        foreach ($_POST['groups'] as $groupid) {
+                            $member_handler->addUserToGroup(intval($groupid), intval($uid));
+                        }
+					}
+					// set position in xoonips_users
+					if( strlen( trim ($posi) ) !== 0 && intval($posi) !== 0 ) {
+						$aptab = $xoopsDB -> prefix("xoonips_users");
+						$apsql = "UPDATE ".$aptab." SET posi = ".$posi." WHERE uid = ".$uid."";
+						$apres = $xoopsDB -> query( $apsql );
+					} else {
+						// $posi = 0 -> $posi = number of moderator
+						$grtab = $xoopsDB -> prefix("groups");
+						$grsql = "SELECT groupid FROM ".$grtab." WHERE name IN ('moderator')";
+						$grres = $xoopsDB -> query( $grsql );
+						if ( $grres == FALSE ){
+							echo "ERROR: SQL=$grsql<br />\n error=" . $xoopsDB -> error() . "<br />\n";
+						}
+						$gr = $xoopsDB -> fetchArray( $grres );
+						$gr4sql = intval( $gr['groupid'] ) ;
+							$litab = $xoopsDB -> prefix("groups_users_link");
+							$lisql = "SELECT linkid FROM ".$litab." WHERE groupid = ".$gr4sql." AND uid = ".$uid."";
+							$lires = $xoopsDB -> query( $lisql );
+							if ( $lires == FALSE ){
+								echo "ERROR: SQL=$lisql<br />\n error=" . $xoopsDB -> error() . "<br />\n";
+							}
+							$nummo = $xoopsDB -> getRowsNum($lires);
+							if( strlen( trim ($nummo) ) !== 0 && $nummo !== 0  ){
+								// user is moderator: position->Moderator
+								$potab = $xoopsDB -> prefix("xoonips_positions");
+								$posql = "SELECT posi_id FROM ".$potab." WHERE posi_title IN ('Moderator')";
+								$pores = $xoopsDB -> query( $posql );
+								// there is no title 'Moderator' in xoonips_positions => posi = 0
+								if ( $pores == FALSE ){
+									echo "ERROR: SQL=$posql<br />\n error=" . $xoopsDB -> error() . "<br />\n";
+								}
+								$po = $xoopsDB -> fetchArray( $pores );
+								$po4sql = intval( $po['posi_id'] );
+									$aptab = $xoopsDB -> prefix("xoonips_users");
+									$apsql = "UPDATE ".$aptab." SET posi = ".$po4sql." WHERE uid = ".$uid."";
+									$apres = $xoopsDB -> query( $apsql );
+									if ( $apres == FALSE ){
+										echo "ERROR: SQL=$apsql<br />\n error=" . $xoopsDB -> error() . "<br />\n";
+									}
+							} else {
+								// user is Registered Users: position->Registered Users
+								$potab = $xoopsDB -> prefix("xoonips_positions");
+								$posql = "SELECT posi_id FROM ".$potab." WHERE posi_title IN ('Registered Users')";
+								$pores = $xoopsDB -> query( $posql );
+								// there is no title 'Registered Users' in xoonips_positions => posi = 0
+								if ( $pores == FALSE ){
+									echo "ERROR: SQL=$posql<br />\n error=" . $xoopsDB -> error() . "<br />\n";
+								}
+								$po = $xoopsDB -> fetchArray( $pores );
+								$po4sql = intval( $po['posi_id'] );
+									$aptab = $xoopsDB -> prefix("xoonips_users");
+									$apsql = "UPDATE ".$aptab." SET posi = ".$po4sql." WHERE uid = ".$uid."";
+									$apres = $xoopsDB -> query( $apsql );
+									if ( $apres == FALSE ){
+										echo "ERROR: SQL=$apsql<br />\n error=" . $xoopsDB -> error() . "<br />\n";
+									}
+							}
+					}
+					if( strlen( trim ($appeal) ) !== 0 ){
+						$aatab = $xoopsDB -> prefix("xoonips_users");
+						$aasql = "UPDATE ".$aatab." SET appeal = '".$appeal."' WHERE uid = ".$uid."";
+						$aares = $xoopsDB -> query( $aasql );
+					}
 					redirect_header("useradmin.php",1,_AM_DBUPDATED);
 					exit();
 				}
