@@ -1,5 +1,5 @@
 <?php
-//  $Revision: 1.9.2.1 $                                                                  //
+//  $Revision: 1.16.2.1 $                                                                  //
 //  --------------------------------------------------------------------------  //
 //  XooNIps Xoops modules for Neuroinformatics Platforms                        //
 //  Copyright (C) 2005 RIKEN, Japan. All rights reserved.                       //
@@ -208,7 +208,7 @@ function xoonipsGetUidItemNames( $xnpsid, &$index, &$context, $depth ){
 	// generate pathString
 	$ar = array();
 	for ( $i = 0; $i <= $depth; $i++ )
-		$ar[] = $context['dirArray'][$i]['title'];
+		$ar[] = $context['dirArray'][$i]['titles'][DEFAULT_INDEX_TITLE_OFFSET];
 	$pathString = implode( '/', $ar );
 	
 	// get child item by userid
@@ -227,7 +227,7 @@ function xoonipsGetUidItemNames( $xnpsid, &$index, &$context, $depth ){
 		$uid = $item['uid'];
 		if ( !isset( $context['uidItemNames'][$uid] ) )
 			$context['uidItemNames'][$uid] = array();
-		$context['uidItemNames'][$uid][] = $pathString . "/" . $item['title'];
+		$context['uidItemNames'][$uid][] = $pathString . "/" . $item['titles'][DEFAULT_INDEX_TITLE_OFFSET];
 	}
 	return RES_OK;
 }
@@ -277,25 +277,42 @@ if ( $op == 'open' || $op == '' ){
 	;
 }
 else if ( $op == 'register' ){
-	list( $limitLabel, $indexCount, $indexNumberLimit ) = xoonipsGetIndexCountInfo( $xnpsid, $xid );
-	if ( "$indexNumberLimit" != "" && $indexNumberLimit <= $indexCount ){
-		//$xoopsTpl->assign('registerError', _MD_XOONIPS_INDEX_TOO_MANY_INDEXES);
+
+	$indexes = array();
+	$result = xnp_get_indexes( $xnpsid, $xid, array(), $indexes );
+	if ( $result != RES_OK ){
+		redirect_header(XOOPS_URL.'/index.php',3,"ERROR [AbstractLayer]".xnp_get_last_error_string());
+		exit;
 	}
-	else {
-		// Warning, if there is the same name of index.
-		$indexes = array();
-		$result = xnp_get_indexes( $xnpsid, $xid, array(), $indexes );
-		if ( $result != RES_OK ){
-			redirect_header(XOOPS_URL.'/index.php',3,"ERROR [AbstractLayer]".xnp_get_last_error_string());
-			exit;
-		}
-		foreach ( $indexes as $index ){
-			if ( $index['title'] == $new_index_name ){
-				$error_messages[] = sprintf( _MD_XOONIPS_INDEX_TITLE_CONFLICT, $new_index_name );
-				break;
-			}
+	do{
+		list( $limitLabel, $indexCount, $indexNumberLimit ) = xoonipsGetIndexCountInfo( $xnpsid, $xid );
+		if ( "$indexNumberLimit" != "" && $indexNumberLimit <= $indexCount ){
+			$error_messages[] = _MD_XOONIPS_INDEX_TOO_MANY_INDEXES;
+            break;
 		}
 		
+		$lengths = xnpGetColumnLengths( 'xoonips_item_title' );
+		list( $within, $without ) = xnpTrimString( $new_index_name, $lengths['title'] );
+		
+		// Ĺ¤˰äʤٹ𤹤
+		if ( strlen($without) ){
+			$error_messages[] = sprintf( _MD_XOONIPS_INDEX_TITLE_EXCEEDS, $new_index_name );
+			break;
+		}
+		
+		// ̾ϤƤʤʤٹ𤹤
+		if ( strlen( $new_index_name ) == 0 ){
+			$error_messages[] = _MD_XOONIPS_INDEX_TITLE_EMPTY;
+			break;
+		}
+		
+		// break if sibling has same name
+		foreach ( $indexes as $index ){
+			if ( $index['titles'][DEFAULT_INDEX_TITLE_OFFSET] == $new_index_name ){
+				$error_messages[] = sprintf( _MD_XOONIPS_INDEX_TITLE_CONFLICT, $new_index_name );
+				break 2;
+			}
+		}
 		
 		$index = array();
 		$result = xnp_get_index( $xnpsid, $xid, $index );
@@ -306,30 +323,14 @@ else if ( $op == 'register' ){
 		
 		// register index
 		$index['parent_index_id'] = $xid;
-//		$index['title'] = $myts->stripSlashesGPC( $new_index_name );
-		$index['title'] = $myts->stripSlashesGPC( encodeMacSafari2Server( $new_index_name ) );
+		$index['titles'] = array( $myts->stripSlashesGPC( encodeMacSafari2Server( $new_index_name ) ) );
 		$result = xnp_insert_index( $xnpsid, $index, $new_xid );
 		if ( $result == RES_OK ){
 			$indexCount++;
 			// Record events(insert index)
 			xnp_insert_event( $xnpsid, ETID_INSERT_INDEX, time(), $uid, xnpGetRemoteHost(), array( 'index_id' => $new_xid ) );
 		}
-
-/*		// try to Notification
-		$notification_handler =& xoops_gethandler('notification');
-		$tags = $index;
-		$tags['name'] = 'tags[name]';
-		//function triggerEvent ($category, $item_id, $event, $extra_tags=array(), $user_list=array(), $module_id=null, $omit_user_id=null)
-		//$notification_handler->triggerEvent('thread', $xid, 'new_post', $tags);
-		$notification_handler->triggerEvent('global', 0, 'new_event', $tags);
-		
-		// If notify checkbox is set, add subscription for approve
-		include_once XOOPS_ROOT_PATH . '/include/notification_constants.php';
-		//$notification_handler->subscribe('thread', $new_xid, 'new_post', XOOPS_NOTIFICATION_MODE_SENDALWAYS);
-		$notification_handler->subscribe('global', 0, 'new_event', XOOPS_NOTIFICATION_MODE_SENDALWAYS);
-		echo " $xid / $new_xid ";
-*/
-	}
+	}while( false );
 }
 else if ( $op == 'up' || $op == 'down' ){
 	$step = $steps[$updown_xid];
@@ -371,7 +372,7 @@ else if ( $op == 'up' || $op == 'down' ){
 else if ( ($op == 'rename' || $op == 'delete' || $op == 'moveto') && isset($check) ){
 	
 	$xoopsMailer =& getMailer();
-	
+	$lengths = xnpGetColumnLengths( 'xoonips_item_title' );
 	reset( $check );
 	while ( list( $key, $index_id ) = each( $check ) ){
 		$index_id = (int)$index_id;
@@ -397,8 +398,20 @@ else if ( ($op == 'rename' || $op == 'delete' || $op == 'moveto') && isset($chec
 		}
 		
 		if ( $op == 'rename' ){
-//			$new_index_name = $myts->stripSlashesGPC( $rename[$index_id] );
 			$new_index_name = $myts->stripSlashesGPC( encodeMacSafari2Server( $rename[$index_id] ) );
+			list( $within, $without ) = xnpTrimString( $new_index_name, $lengths['title'] );
+			
+			// Ĺ¤˰äʤٹ𤹤
+			if ( strlen($without) ){
+				$error_messages[] = sprintf( _MD_XOONIPS_INDEX_TITLE_EXCEEDS, $new_index_name );
+				continue;
+			}
+			
+			// ̾ϤƤʤʤٹ𤹤
+			if ( strlen( $new_index_name ) == 0 ){
+				$error_messages[] = _MD_XOONIPS_INDEX_TITLE_EMPTY;
+				continue;
+			}
 			
 			// Warning, if there is the same name of index.
 			$indexes = array();
@@ -407,16 +420,18 @@ else if ( ($op == 'rename' || $op == 'delete' || $op == 'moveto') && isset($chec
 				redirect_header(XOOPS_URL.'/index.php',3,"ERROR [AbstractLayer]".xnp_get_last_error_string());
 				exit;
 			}
+            
 			foreach ( $indexes as $index2 ){
-				if ( $index2['title'] == $new_index_name ){
-					$error_messages[] = sprintf( _MD_XOONIPS_INDEX_TITLE_CONFLICT, $new_index_name );
-					break;
+				if ( $index2['titles'][DEFAULT_INDEX_TITLE_OFFSET] == $within ){
+    				$error_messages[] = sprintf( _MD_XOONIPS_INDEX_TITLE_CONFLICT, $within );
+					continue 2;
 				}
 			}
 			
-			
 			$old_index = $index;
-			$index['title'] = $new_index_name;
+			$index['titles'] = array( $within );
+			$index['without'] = $without;
+			
 			$result = xnp_update_index( $xnpsid, $index );
 			if ( $result == RES_OK ){
 				// record events(update index)
@@ -478,29 +493,26 @@ else if ( ($op == 'rename' || $op == 'delete' || $op == 'moveto') && isset($chec
 				$result = xnp_get_account( $xnpsid, $to_uid, $account );
 				if ( $result != RES_OK )
 					continue;
-				$xoopsMailer->reset();
-				$xoopsMailer->useMail();
-				$xoopsMailer->setFromEmail( $xoopsConfig['adminmail'] );
-				$xoopsMailer->setFromName( $xoopsConfig['sitename'] );
-				$xoopsMailer->setToEmails( $account['email'] );
-				$xoopsMailer->setSubject( $subject );
-				$xoopsMailer->setBody( $body . "\n  " . implode( "\n  ", $itemNames ) );
-				$xoopsMailer->send();
-/*
-				var_dump( $account );
-				echo "To:" . $account['email'] . "\n";
-				echo "Subject: $subject \n";
-				echo "body: $body \n";
-				var_dump( $itemNames );
-*/
+				global $xoopsModule;
+				$tags = array();
+				$tags['AFFECTED_ITEM'] = implode( "\n  ", $itemNames );
+				$notification_handler =& xoops_gethandler('notification');
+				if( $op == 'rename' ){
+                    $tags['INDEX_OLD'] = $oldPathString;
+                    $tags['INDEX_NEW'] = $newPathString;
+					$tags['INDEX_URL'] = XOOPS_URL . '/modules/' . $xoopsModule->dirname() . "/listitem.php?index_id=${index_id}";
+                    $result = $notification_handler->triggerEvent('user', 0, 'index_renamed', $tags, array($account['uid']));
+				}else if( $op == 'delete' ){
+                    $tags['INDEX'] = $oldPathString;
+                    $result = $notification_handler->triggerEvent('user', 0, 'index_deleted', $tags, array($account['uid']));
+				}else if( $op == 'moveto' ){
+                    $tags['INDEX_OLD'] = $oldPathString;
+                    $tags['INDEX_NEW'] = $newPathString;
+					$tags['INDEX_URL'] = XOOPS_URL . '/modules/' . $xoopsModule->dirname() . "/listitem.php?index_id=${index_id}";
+                    $result = $notification_handler->triggerEvent('user', 0, 'index_moved', $tags, array($account['uid']));
+                }
 			}
 		}
-		/* test? 
-		 users, indexes, items.
-		 notificate uncertify items.
-		 error: (there is Binders, or the same name one.)
-		
-		*/
 	}
 }
 else {
@@ -520,8 +532,7 @@ $xoopsTpl->assign('indexNumberLimit', $indexNumberLimit );
 
 function genIndexAnchor( $index ){
 	$xid = $index['item_id'];
-//	$escTitle = htmlspecialchars($index['title']);
-	$escTitle = xnpHtmlspecialchars($index['title']);
+	$escTitle = xnpHtmlspecialchars($index['titles'][DEFAULT_INDEX_TITLE_OFFSET]);
 	$anchor = "<a href='editindex.php?xid=$xid'>$escTitle</a>";
 	return $anchor;
 }
@@ -532,7 +543,7 @@ function xoonipsGetPathString( $xnpsid, $xid ){
 	$dirArray = xoonipsGetPathArray( $xnpsid, $xid );
 	$ar = array();
 	foreach ( $dirArray as $key => $val )
-		$ar[] = $val['title'];
+		$ar[] = $val['titles'][DEFAULT_INDEX_TITLE_OFFSET];
 	return '/' . implode( '/', $ar );
 }
 
@@ -585,7 +596,7 @@ while ( list( $key ) = each( $childIndexes ) ){
 require_once( 'include/gentree.php' );
 
 function genSelectLabels( &$index ){
-	$title = $index['title'];
+	$title = $index['titles'][DEFAULT_INDEX_TITLE_OFFSET];
 	$indent_html = str_repeat( '&nbsp;&nbsp;', (int)($index['depth']));
 	if ( isset( $index['child_count'] ) &&  $index['child_count'] != 0 )
 		$childCount = '( ' . $index['child_count'] . ' )';
@@ -611,6 +622,7 @@ $xoopsTpl->assign('index_path', $dirArray ); //
 $xoopsTpl->assign('child_indexes', $childIndexes );
 $xoopsTpl->assign('index_tree', $indexTree );
 $xoopsTpl->assign('accept_charset', xnpGetMacSafariAcceptCharset() );
+$xoopsTpl->assign( 'xoonips_editprofile_url', XOOPS_URL . '/modules/xoonips/edituser.php?uid=' . $uid );
 
 require(XOOPS_ROOT_PATH.'/footer.php');
 
