@@ -1,5 +1,5 @@
 <?php
-// $Id: edituser.php,v 1.11.2.1 2006/06/20 06:05:20 makotonton Exp $
+// $Id: edituser.php,v 1.20 2006/11/14 08:26:15 makotonton Exp $
 //  ------------------------------------------------------------------------ //
 //                XOOPS - PHP Content Management System                      //
 //                    Copyright (c) 2000 XOOPS.org                           //
@@ -85,13 +85,13 @@ foreach( array( 'op' => 'editprofile',
                 'private_item_number_limit' => null,
                 'private_index_number_limit' => null,
                 'private_item_storage_limit' => null,
-                'user_icq' => null,
-                'user_aim' => null,
-                'user_yim' => null,
-                'user_msnm' => null,
-                'user_from' => null,
+                // 'user_icq' => null,
+                // 'user_aim' => null,
+                // 'user_yim' => null,
+                // 'user_msnm' => null,
+                // 'user_from' => null,
                 'user_viewemail' => null,
-                'user_occ' => null,
+                // 'user_occ' => null,
                 'user_intrest' => null,
                 'user_sig' => null,
                 'attachsig' => null,
@@ -99,11 +99,13 @@ foreach( array( 'op' => 'editprofile',
                 'uorder' => null,
                 'notify_method' => null,
                 'notify_mode' => null,
-                'bio' => null,
+                // 'bio' => null,
                 'rank' => null,
+                'posi' => null,
                 'password' => null,
                 'vpass' => null,
                 'user_mailok' => 0,
+                'appeal' => null,
                 'groups' => null,
                 'fct' => null ) as $k => $v ){
     if( array_key_exists( $k, $_GET ) ){
@@ -186,14 +188,14 @@ if ($op == 'saveuser') {
 			$edituser->setVar('email', $email);
 		}
 		$edituser->setVar('url', formatURL($url));
-		$edituser->setVar('user_icq', $user_icq);
-		$edituser->setVar('user_from', $user_from);
+		// $edituser->setVar('user_icq', $user_icq);
+		// $edituser->setVar('user_from', $user_from);
 		$edituser->setVar('user_sig', xoops_substr($user_sig, 0, 255));
 		$user_viewemail = (!empty($user_viewemail)) ? 1 : 0;
 		$edituser->setVar('user_viewemail', $user_viewemail);
-		$edituser->setVar('user_aim', $user_aim);
-		$edituser->setVar('user_yim', $user_yim);
-		$edituser->setVar('user_msnm', $user_msnm);
+		// $edituser->setVar('user_aim', $user_aim);
+		// $edituser->setVar('user_yim', $user_yim);
+		// $edituser->setVar('user_msnm', $user_msnm);
 		if ( isset($password) && $password != '') {
 			$edituser->setVar('pass', md5($password));
 		}
@@ -204,8 +206,8 @@ if ($op == 'saveuser') {
 		$edituser->setVar('umode', $umode);
 		$edituser->setVar('notify_method', $notify_method);
 		$edituser->setVar('notify_mode', $notify_mode);
-		$edituser->setVar('bio', xoops_substr($bio, 0, 255));
-		$edituser->setVar('user_occ', $user_occ);
+		// $edituser->setVar('bio', xoops_substr($bio, 0, 255));
+		// $edituser->setVar('user_occ', $user_occ);
 		$edituser->setVar('user_intrest', $user_intrest);
 		$edituser->setVar('user_mailok', $user_mailok);
 		if (!empty($_POST['usecookie'])) {
@@ -229,14 +231,16 @@ if ($op == 'saveuser') {
             $sql = $sql."zipcode='".$ts->addSlashes( $zipcode )."', ";
             $sql = $sql."fax='".$ts->addSlashes( $fax )."', ";
             $sql = $sql."notice_mail=".$notice_mail.", ";
-            $sql = $sql."notice_mail_since=UNIX_TIMESTAMP(NOW())";
+            $sql = $sql."notice_mail_since=UNIX_TIMESTAMP(NOW()), ";
+            $sql = $sql."posi='".$ts->addSlashes( $posi )."', ";
+            $sql = $sql."appeal='".$ts->addSlashes( $appeal )."'";
             $sql = $sql." WHERE uid=".$uid;
             if( !mysql_query( $sql ) ){
 	    		include XOOPS_ROOT_PATH.'/header.php';
 		    	echo $edituser->getHtmlErrors();
 			    include XOOPS_ROOT_PATH.'/footer.php';
             }
-			redirect_header('userinfo.php?uid='.$uid, 1, _US_PROFUPDATED);
+			redirect_header('showusers.php',0, _US_PROFUPDATED);
 		}
 		exit();
 	}
@@ -266,11 +270,11 @@ if ($op == 'editprofile') {
         }
     }
 
-	echo "<p>"
-		._MI_XOONIPS_ACCOUNT_PANKUZU_PLATFORM_USER
+	echo '<p>
+		<a href="showusers.php?uid='.$xoopsUser->getVar('uid').'">'._MD_XOONIPS_SHOW_USER_TITLE.'</a>'
 		._MI_XOONIPS_ACCOUNT_PANKUZU_SEPARATOR
-		._MI_XOONIPS_ITEM_PANKUZU_EDIT_ACCOUNT
-		."</p>\n";
+		._US_EDITPROFILE
+		.'</p><br />';
 	$form = new XoopsThemeForm(_US_EDITPROFILE, 'userinfo', 'edituser.php');
 	$uname_label = new XoopsFormLabel(_US_NICKNAME._MD_XOONIPS_ACCOUNT_REQUIRED_MARK, $xoopsUser->getVar('uname'));
 	$form->addElement($uname_label);
@@ -288,16 +292,15 @@ if ($op == 'editprofile') {
 	$email_cbox->addOption(1, _US_ALLOWVIEWEMAIL);
 	$email_tray->addElement($email_cbox);
 	$form->addElement($email_tray);
+	// $icq_text = new XoopsFormText(_US_ICQ, 'user_icq', 15, 15, $xoopsUser->getVar('user_icq', 'E'));
+	// $aim_text = new XoopsFormText(_US_AIM, 'user_aim', 18, 18, $xoopsUser->getVar('user_aim', 'E'));
+	// $yim_text = new XoopsFormText(_US_YIM, 'user_yim', 25, 25, $xoopsUser->getVar('user_yim', 'E'));
+	// $msnm_text = new XoopsFormText(_US_MSNM, 'user_msnm', 30, 100, $xoopsUser->getVar('user_msnm', 'E'));
+	// $location_text = new XoopsFormText(_US_LOCATION, 'user_from', 30, 100, $xoopsUser->getVar('user_from', 'E'));
+	// $occupation_text = new XoopsFormText(_US_OCCUPATION, 'user_occ', 30, 100, $xoopsUser->getVar('user_occ', 'E'));
 	$url_text = new XoopsFormText(_US_WEBSITE, 'url', 30, 100, $xoopsUser->getVar('url', 'E'));
 	$form->addElement($url_text);
-
 	$timezone_select = new XoopsFormSelectTimezone(_US_TIMEZONE, 'timezone_offset', $xoopsUser->getVar('timezone_offset'));
-	$icq_text = new XoopsFormText(_US_ICQ, 'user_icq', 15, 15, $xoopsUser->getVar('user_icq', 'E'));
-	$aim_text = new XoopsFormText(_US_AIM, 'user_aim', 18, 18, $xoopsUser->getVar('user_aim', 'E'));
-	$yim_text = new XoopsFormText(_US_YIM, 'user_yim', 25, 25, $xoopsUser->getVar('user_yim', 'E'));
-	$msnm_text = new XoopsFormText(_US_MSNM, 'user_msnm', 30, 100, $xoopsUser->getVar('user_msnm', 'E'));
-	$location_text = new XoopsFormText(_US_LOCATION, 'user_from', 30, 100, $xoopsUser->getVar('user_from', 'E'));
-	$occupation_text = new XoopsFormText(_US_OCCUPATION, 'user_occ', 30, 100, $xoopsUser->getVar('user_occ', 'E'));
 	$interest_text = new XoopsFormText(_US_INTEREST, 'user_intrest', 30, 150, $xoopsUser->getVar('user_intrest', 'E'));
 	$sig_tray = new XoopsFormElementTray(_US_SIGNATURE, '<br />');
 	include_once XOOPS_ROOT_PATH."/include/xoopscodes.php";
@@ -319,7 +322,7 @@ if ($op == 'editprofile') {
 	$notify_method_select->addOptionArray(array(XOOPS_NOTIFICATION_METHOD_DISABLE=>_NOT_METHOD_DISABLE, XOOPS_NOTIFICATION_METHOD_PM=>_NOT_METHOD_PM, XOOPS_NOTIFICATION_METHOD_EMAIL=>_NOT_METHOD_EMAIL));
 	$notify_mode_select = new XoopsFormSelect(_NOT_NOTIFYMODE, 'notify_mode', $xoopsUser->getVar('notify_mode'));
 	$notify_mode_select->addOptionArray(array(XOOPS_NOTIFICATION_MODE_SENDALWAYS=>_NOT_MODE_SENDALWAYS, XOOPS_NOTIFICATION_MODE_SENDONCETHENDELETE=>_NOT_MODE_SENDONCE, XOOPS_NOTIFICATION_MODE_SENDONCETHENWAIT=>_NOT_MODE_SENDONCEPERLOGIN));
-	$bio_tarea = new XoopsFormTextArea(_US_EXTRAINFO, 'bio', $xoopsUser->getVar('bio', 'E'));
+	// $bio_tarea = new XoopsFormTextArea(_US_EXTRAINFO, 'bio', $xoopsUser->getVar('bio', 'E'));
 	$cookie_radio_value = empty($_COOKIE[$xoopsConfig['usercookie']]) ? 0 : 1;
 	$cookie_radio = new XoopsFormRadioYN(_US_USECOOKIE, 'usecookie', $cookie_radio_value, _YES, _NO);
 	$pwd_text = new XoopsFormPassword('', 'password', 10, 32);
@@ -332,7 +335,7 @@ if ($op == 'editprofile') {
 	$op_hidden = new XoopsFormHidden('op', 'saveuser');
 	$submit_button = new XoopsFormButton('', 'submit', _US_SAVECHANGES, 'submit');
 
-	$form->addElement($timezone_select);
+	// $form->addElement($timezone_select);
 
     //user's information is taken out of prefix("xoonips_users") table, it is set to form.
 	$xoopsDB =& Database::getInstance();
@@ -345,36 +348,68 @@ if ($op == 'editprofile') {
         $ht = array(); // empty hash table
     }
     $ts =& MyTextSanitizer::getInstance();
-	$form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_ADDRESS.$required['address']['mark'], "address", 60, 255, $ts->htmlSpecialChars($ht["address"])), $required['address']['flag']);
+	$posi_select = new XoopsFormSelect(_MD_XOONIPS_ACCOUNT_POSITION, "posi", $ht['posi']);
+		function getUserPosiList(){
+			$db =& Database::getInstance();
+			$myts =& MyTextSanitizer::getInstance();
+			$sql = "SELECT posi_id, posi_title FROM ".$db->prefix("xoonips_positions")." ORDER BY posi_order";
+			$ret = array();
+			$result = $db->query($sql);
+			while ( $myrow = $db->fetchArray($result) ) {
+					$ret[$myrow['posi_id']] = $myts->makeTboxData4Show($myrow['posi_title']);
+				}
+		return $ret;
+		}
+		$posilist =  getUserPosiList();
+		if ( count($posilist) > 0 ) {
+			$posi_select->addOption(0, _MD_XOONIPS_ACCOUNT_NSRA);
+			$posi_select->addOption(0, "--------------");
+			$posi_select->addOptionArray($posilist);
+		} else {
+			$posi_select->addOption(0, _MD_XOONIPS_ACCOUNT_NSRID);
+		}
+
+	$form->addElement($posi_select);
+
 	$form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_DIVISION.$required['division']['mark'], "division", 60, 255, $ts->htmlSpecialChars($ht["division"])), $required['division']['flag']);
+	$form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_COMPANY_NAME.$required['company_name']['mark'], "company_name", 60, 255, $ts->htmlSpecialChars($ht["company_name"])), $required['company_name']['flag']);
 	$form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_TEL.$required['tel']['mark'], "tel", 25, 32, $ts->htmlSpecialChars($ht["tel"])), $required['tel']['flag']);
 	$form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_FAX.$required['fax']['mark'], "fax", 25, 32, $ts->htmlSpecialChars($ht["fax"])), $required['fax']['flag']);
-	$form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_COMPANY_NAME.$required['company_name']['mark'], "company_name", 60, 255, $ts->htmlSpecialChars($ht["company_name"])), $required['company_name']['flag']);
+	$form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_ADDRESS.$required['address']['mark'], "address", 60, 255, $ts->htmlSpecialChars($ht["address"])), $required['address']['flag']);
 	$form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_COUNTRY.$required['country']['mark'], "country", 25, 255, $ts->htmlSpecialChars($ht["country"])), $required['country']['flag']);
 	$form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_ZIPCODE.$required['zipcode']['mark'], "zipcode", 20, 32, $ts->htmlSpecialChars($ht["zipcode"])), $required['zipcode']['flag']);
-	$form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_NOTICE_MAIL, "notice_mail", 5, 10, isset( $ht["notice_mail"] ) ? $ts->htmlSpecialChars($ht["notice_mail"]) : 0 ));
+
+	$form->addElement($timezone_select);
+	$form->addElement($interest_text);
+	
+	// $form->addElement(new XoopsFormTextArea(_MD_XOONIPS_ACCOUNT_APPEAL, "appeal", $ts->htmlSpecialChars($ht["appeal"])));
+	$app_tray = new XoopsFormElementTray(_MD_XOONIPS_ACCOUNT_APPEAL, '<br />');
+	include_once XOOPS_ROOT_PATH."/include/xoopscodes.php";
+	$app_tarea = new XoopsFormDhtmlTextArea('', 'appeal', $ts->htmlSpecialChars($ht["appeal"]), 5, 50, 'u_appeal');
+	$app_tray->addElement($app_tarea);
+	$form->addElement($app_tray);
+	$form->addElement($sig_tray);
 
 	$form->addElement($pwd_tray);
+	$form->addElement(new XoopsFormText(_MD_XOONIPS_ACCOUNT_NOTICE_MAIL, "notice_mail", 5, 10, isset( $ht["notice_mail"] ) ? $ts->htmlSpecialChars($ht["notice_mail"]) : 0 ));
 	$form->addElement($cookie_radio);
 	$form->addElement($mailok_radio);
 
-	$form->addElement($icq_text);
-	$form->addElement($aim_text);
-	$form->addElement($yim_text);
-	$form->addElement($msnm_text);
-	$form->addElement($location_text);
-	$form->addElement($occupation_text);
-	$form->addElement($interest_text);
-	$form->addElement($sig_tray);
+	// $form->addElement($icq_text);
+	// $form->addElement($aim_text);
+	// $form->addElement($yim_text);
+	// $form->addElement($msnm_text);
+	// $form->addElement($location_text);
+	// $form->addElement($occupation_text);
 	$form->addElement($umode_select);
 	$form->addElement($uorder_select);
 	$form->addElement($notify_method_select);
 	$form->addElement($notify_mode_select);
-	$form->addElement($bio_tarea);
-    
+	// $form->addElement($bio_tarea);
 	
 	$form->addElement($uid_hidden);
 	$form->addElement($op_hidden);
+
 	$form->addElement($submit_button);
 	if ($xoopsConfigUser['allow_chgmail'] == 1) {
 		$form->setRequired($email_text);
@@ -383,119 +418,151 @@ if ($op == 'editprofile') {
 	$form->setExtra(xnpGetMacSafariAcceptCharset());
 	$form->display();
 	include XOOPS_ROOT_PATH.'/footer.php';
+
 	mysql_free_result( $result );
 }
 
 
 if ($op == 'avatarform') {
-	if (!is_object($xoopsUser)) {
-		redirect_header('index.php', 1);
-	}
-	include XOOPS_ROOT_PATH.'/header.php';
-	echo '<a href="userinfo.php?uid='.$xoopsUser->getVar('uid').'">'. _US_PROFILE .'</a>&nbsp;<span style="font-weight:bold;">&raquo;&raquo;</span>&nbsp;'. _US_UPLOADMYAVATAR .'<br /><br />';
-	$oldavatar = $xoopsUser->getVar('user_avatar');
-	if ($oldavatar && $oldavatar != 'blank.gif') {
-		echo '<div style="text-align:center;"><h4 style="color:#ff0000; font-weight:bold;">'._US_OLDDELETED.'</h4>';
-		echo '<img src="'.XOOPS_UPLOAD_URL.'/'.$oldavatar.'" alt="" /></div>';
-	}
-	if ($xoopsConfigUser['avatar_allow_upload'] == 1 && $xoopsUser->getVar('posts') >= $xoopsConfigUser['avatar_minposts']) {
-		include_once 'class/xoopsformloader.php';
-		$form = new XoopsThemeForm(_US_UPLOADMYAVATAR, 'uploadavatar', 'edituser.php');
-		$form->setExtra('enctype="multipart/form-data"');
-		$form->addElement(new XoopsFormLabel(_US_MAXPIXEL, $xoopsConfigUser['avatar_width'].' x '.$xoopsConfigUser['avatar_height']));
-		$form->addElement(new XoopsFormLabel(_US_MAXIMGSZ, $xoopsConfigUser['avatar_maxsize']));
-		$form->addElement(new XoopsFormFile(_US_SELFILE, 'avatarfile', $xoopsConfigUser['avatar_maxsize']), true);
-		$form->addElement(new XoopsFormHidden('op', 'avatarupload'));
-		$form->addElement(new XoopsFormHidden('uid', $xoopsUser->getVar('uid')));
-		$form->addElement(new XoopsFormButton('', 'submit', _SUBMIT, 'submit'));
-			$form->display();
-	}
-	$avatar_handler =& xoops_gethandler('avatar');
-	$form2 = new XoopsThemeForm(_US_CHOOSEAVT, 'uploadavatar', 'edituser.php');
-	$avatar_select = new XoopsFormSelect('', 'user_avatar', $xoopsUser->getVar('user_avatar'));
-	$avatar_select->addOptionArray($avatar_handler->getList('S'));
-	$avatar_select->setExtra("onchange='showImgSelected(\"avatar\", \"user_avatar\", \"uploads\", \"\", \"".XOOPS_URL."\")'");
-	$avatar_tray = new XoopsFormElementTray(_US_AVATAR, '&nbsp;');
-	$avatar_tray->addElement($avatar_select);
-	$avatar_tray->addElement(new XoopsFormLabel('', "<img src='".XOOPS_UPLOAD_URL."/".$xoopsUser->getVar("user_avatar", "E")."' name='avatar' id='avatar' alt='' /> <a href=\"javascript:openWithSelfMain('".XOOPS_URL."/misc.php?action=showpopups&amp;type=avatars','avatars',600,400);\">"._LIST."</a>"));
-	$form2->addElement($avatar_tray);
-	$form2->addElement(new XoopsFormHidden('uid', $xoopsUser->getVar('uid')));
-	$form2->addElement(new XoopsFormHidden('op', 'avatarchoose'));
-	$form2->addElement(new XoopsFormButton('', 'submit2', _SUBMIT, 'submit'));
-	$form2->display();
-	include XOOPS_ROOT_PATH.'/footer.php';
+    include XOOPS_ROOT_PATH.'/header.php';
+    echo '<a href="showusers.php?uid='.$xoopsUser->getVar('uid').'">'. _MD_XOONIPS_SHOW_USER_TITLE .'</a>&nbsp;<span style="font-weight:bold;">&raquo;&raquo;</span>&nbsp;'. _US_UPLOADMYAVATAR .'<br /><br />';
+    $oldavatar = $xoopsUser->getVar('user_avatar');
+    if (!empty($oldavatar) && $oldavatar != 'blank.gif') {
+        echo '<div style="text-align:center;"><h4 style="color:#ff0000; font-weight:bold;">'._US_OLDDELETED.'</h4>';
+        echo '<img src="'.XOOPS_UPLOAD_URL.'/'.$oldavatar.'" alt="oldavater" /></div>';
+    }
+    if ($xoopsConfigUser['avatar_allow_upload'] == 1 && $xoopsUser->getVar('posts') >= $xoopsConfigUser['avatar_minposts']) {
+        include_once XOOPS_ROOT_PATH.'/class/xoopsformloader.php';
+        $form = new XoopsThemeForm(_US_UPLOADMYAVATAR, 'uploadavatar', 'edituser.php');
+        $form->setExtra('enctype="multipart/form-data"');
+        $form->addElement(new XoopsFormLabel(_US_MAXPIXEL, $xoopsConfigUser['avatar_width'].' x '.$xoopsConfigUser['avatar_height']));
+        $form->addElement(new XoopsFormLabel(_US_MAXIMGSZ, $xoopsConfigUser['avatar_maxsize']));
+        $form->addElement(new XoopsFormFile(_US_SELFILE, 'avatarfile', $xoopsConfigUser['avatar_maxsize']), true);
+        $form->addElement(new XoopsFormHidden('op', 'avatarupload'));
+        $form->addElement(new XoopsFormToken(XoopsSingleTokenHandler::quickCreate('avatarupload')));
+        $form->addElement(new XoopsFormHidden('uid', $xoopsUser->getVar('uid')));
+        $form->addElement(new XoopsFormButton('', 'submit', _SUBMIT, 'submit'));
+            $form->display();
+    }
+    $avatar_handler =& xoops_gethandler('avatar');
+    $form2 = new XoopsThemeForm(_US_CHOOSEAVT, 'uploadavatar', 'edituser.php');
+    $avatar_select = new XoopsFormSelect('', 'user_avatar', $xoopsUser->getVar('user_avatar'));
+    $avatar_select->addOptionArray($avatar_handler->getList('S'));
+    $avatar_select->setExtra("onchange='showImgSelected(\"avatar\", \"user_avatar\", \"uploads\", \"\", \"".XOOPS_URL."\")'");
+    $avatar_tray = new XoopsFormElementTray(_US_AVATAR, '&nbsp;');
+    $avatar_tray->addElement($avatar_select);
+    $avatar_tray->addElement(new XoopsFormLabel('', "<img src='".XOOPS_UPLOAD_URL."/".$xoopsUser->getVar("user_avatar", "E")."' name='avatar' id='avatar' alt='avatar' /> <a href=\"javascript:openWithSelfMain('".XOOPS_URL."/misc.php?action=showpopups&amp;type=avatars','avatars',600,400);\">"._LIST."</a>"));
+    $form2->addElement($avatar_tray);
+    $form2->addElement(new XoopsFormHidden('uid', $xoopsUser->getVar('uid')));
+    $form2->addElement(new XoopsFormHidden('op', 'avatarchoose'));
+    $form2->addElement(new XoopsFormToken(XoopsSingleTokenHandler::quickCreate('avatarchoose')));
+    $form2->addElement(new XoopsFormButton('', 'submit2', _SUBMIT, 'submit'));
+    $form2->display();
+    include XOOPS_ROOT_PATH.'/footer.php';
 }
 
 if ($op == 'avatarupload') {
-	if (!is_object($xoopsUser) || $xoopsUser->getVar('uid') != $uid ) {
-		redirect_header('index.php',3,_US_NOEDITRIGHT);
-		exit();
-	}
-	if ($xoopsConfigUser['avatar_allow_upload'] == 1 && $xoopsUser->getVar('posts') >= $xoopsConfigUser['avatar_minposts']) {
-		include_once XOOPS_ROOT_PATH.'/class/uploader.php';
-		$uploader = new XoopsMediaUploader(XOOPS_UPLOAD_PATH, array('image/gif', 'image/jpeg', 'image/pjpeg', 'image/x-png', 'image/png'), $xoopsConfigUser['avatar_maxsize'], $xoopsConfigUser['avatar_width'], $xoopsConfigUser['avatar_height']);
-		if ($uploader->fetchMedia($_POST['xoops_upload_file'][0])) {
-			$uploader->setPrefix('cavt');
-			if ($uploader->upload()) {
-				$avt_handler =& xoops_gethandler('avatar');
-				$avatar =& $avt_handler->create();
-				$avatar->setVar('avatar_file', $uploader->getSavedFileName());
-				$avatar->setVar('avatar_name', $xoopsUser->getVar('uname'));
-				$avatar->setVar('avatar_mimetype', $uploader->getMediaType());
-				$avatar->setVar('avatar_display', 1);
-				$avatar->setVar('avatar_type', 'C');
-				if (!$avt_handler->insert($avatar)) {
-					@unlink($uploader->getSavedDestination());
-				} else {
-					$oldavatar = $xoopsUser->getVar('user_avatar');
-					if ($oldavatar && $oldavatar != 'blank.gif' && !preg_match("/^savt/", strtolower($oldavatar))) {
-						$avatars =& $avt_handler->getObjects(new Criteria('avatar_file', $oldavatar));
-						$avt_handler->delete($avatars[0]);
-						@unlink('uploads/'.$oldavatar);
-					}
-					$sql = sprintf("UPDATE %s SET user_avatar = '%s' WHERE uid = %u", $xoopsDB->prefix('users'), $uploader->getSavedFileName(), $xoopsUser->getVar('uid'));
-					$xoopsDB->query($sql);
-					$avt_handler->addUser($avatar->getVar('avatar_id'), $xoopsUser->getVar('uid'));
-					redirect_header('userinfo.php?t='.time().'&amp;uid='.$xoopsUser->getVar('uid'),0, _US_PROFUPDATED);
-				}
-			}
-		}
-		include XOOPS_ROOT_PATH.'/header.php';
-		echo $uploader->getErrors();
-		include XOOPS_ROOT_PATH.'/footer.php';
-	}
+    if (!XoopsSingleTokenHandler::quickValidate('avatarupload')) {
+        redirect_header('index.php',3,_US_NOEDITRIGHT);
+        exit;
+    }
+    $xoops_upload_file = array();
+    $uid = 0;
+    if (!empty($_POST['xoops_upload_file']) && is_array($_POST['xoops_upload_file'])){
+        $xoops_upload_file = $_POST['xoops_upload_file'];
+    }
+    if (!empty($_POST['uid'])) {
+        $uid = intval($_POST['uid']);
+    }
+    if (empty($uid) || $xoopsUser->getVar('uid') != $uid ) {
+        redirect_header('index.php',3,_US_NOEDITRIGHT);
+        exit();
+    }
+    if ($xoopsConfigUser['avatar_allow_upload'] == 1 && $xoopsUser->getVar('posts') >= $xoopsConfigUser['avatar_minposts']) {
+        include_once XOOPS_ROOT_PATH.'/class/uploader.php';
+        $uploader = new XoopsMediaUploader(XOOPS_UPLOAD_PATH, array('image/gif', 'image/jpeg', 'image/pjpeg', 'image/x-png', 'image/png'), $xoopsConfigUser['avatar_maxsize'], $xoopsConfigUser['avatar_width'], $xoopsConfigUser['avatar_height']);
+        $uploader->setAllowedExtensions(array('gif', 'jpeg', 'jpg', 'png'));
+        if ($uploader->fetchMedia($_POST['xoops_upload_file'][0])) {
+            $uploader->setPrefix('cavt');
+            if ($uploader->upload()) {
+                $avt_handler =& xoops_gethandler('avatar');
+                $avatar =& $avt_handler->create();
+                $avatar->setVar('avatar_file', $uploader->getSavedFileName());
+                $avatar->setVar('avatar_name', $xoopsUser->getVar('uname'));
+                $avatar->setVar('avatar_mimetype', $uploader->getMediaType());
+                $avatar->setVar('avatar_display', 1);
+                $avatar->setVar('avatar_type', 'C');
+                if (!$avt_handler->insert($avatar)) {
+                    @unlink($uploader->getSavedDestination());
+                } else {
+                    $oldavatar = $xoopsUser->getVar('user_avatar');
+                    if (!empty($oldavatar) && $oldavatar != 'blank.gif' && !preg_match("/^savt/", strtolower($oldavatar))) {
+                        $avatars =& $avt_handler->getObjects(new Criteria('avatar_file', $oldavatar));
+                        $avt_handler->delete($avatars[0]);
+                        $oldavatar_path = str_replace("\\", "/", realpath(XOOPS_UPLOAD_PATH.'/'.$oldavatar));
+                        if (0 === strpos($oldavatar_path, XOOPS_UPLOAD_PATH) && is_file($oldavatar_path)) {
+                            unlink($oldavatar_path);
+                        }
+                    }
+                    $sql = sprintf("UPDATE %s SET user_avatar = %s WHERE uid = %u", $xoopsDB->prefix('users'), $xoopsDB->quoteString($uploader->getSavedFileName()), $xoopsUser->getVar('uid'));
+                    $xoopsDB->query($sql);
+                    $avt_handler->addUser($avatar->getVar('avatar_id'), $xoopsUser->getVar('uid'));
+                    redirect_header('showusers.php',0, _US_PROFUPDATED);
+                }
+            }
+        }
+        include XOOPS_ROOT_PATH.'/header.php';
+        echo $uploader->getErrors();
+        include XOOPS_ROOT_PATH.'/footer.php';
+    }
 }
 
 if ($op == 'avatarchoose') {
-	if (!is_object($xoopsUser) || $xoopsUser->getVar('uid') != $uid ) {
-		redirect_header('index.php', 3, _US_NOEDITRIGHT);
-		exit();
-	}
-	$member_handler =& xoops_gethandler('member');
-	$user_avatar = trim($user_avatar);
-	$oldavatar = $xoopsUser->getVar('user_avatar');
-	$xoopsUser->setVar('user_avatar', $user_avatar);
-	if (!$member_handler->insertUser($xoopsUser)) {
-		include XOOPS_ROOT_PATH.'/header.php';
-		echo $xoopsUser->getHtmlErrors();
-		include XOOPS_ROOT_PATH.'/footer.php';
-		exit();
-	} else {
-		$avt_handler =& xoops_gethandler('avatar');
-		if ($oldavatar && $oldavatar != 'blank.gif' && !preg_match("/^savt/", strtolower($oldavatar))) {
-			$avatars =& $avt_handler->getObjects(new Criteria('avatar_file', $oldavatar));
-			if (is_object($avatars[0])) {
-				$avt_handler->delete($avatars[0]);
-			}
-			@unlink('uploads/'.$oldavatar);
-		}
-		if ($user_avatar != 'blank.gif') {
-			$avatars =& $avt_handler->getObjects(new Criteria('avatar_file', $user_avatar));
-			if (is_object($avatars[0])) {
-				$avt_handler->addUser($avatars[0]->getVar('avatar_id'), $xoopsUser->getVar('uid'));
-			}
-		}
-		redirect_header('userinfo.php?uid='.$uid, 0, _US_PROFUPDATED);
-	}
+    if (!XoopsSingleTokenHandler::quickValidate('avatarchoose')) {
+        redirect_header('index.php',3,_US_NOEDITRIGHT);
+        exit;
+    }
+    $uid = 0;
+    if (!empty($_POST['uid'])) {
+        $uid = intval($_POST['uid']);
+    }
+    if (empty($uid) || $xoopsUser->getVar('uid') != $uid ) {
+        redirect_header('index.php', 3, _US_NOEDITRIGHT);
+        exit();
+    }
+    $user_avatar = '';
+    if (!empty($_POST['user_avatar'])) {
+        $user_avatar = trim($_POST['user_avatar']);
+    }
+    $user_avatarpath = str_replace("\\", "/", realpath(XOOPS_UPLOAD_PATH.'/'.$user_avatar));
+    if (0 === strpos($user_avatarpath, XOOPS_UPLOAD_PATH) && is_file($user_avatarpath)) {
+        $oldavatar = $xoopsUser->getVar('user_avatar');
+        $xoopsUser->setVar('user_avatar', $user_avatar);
+        $member_handler =& xoops_gethandler('member');
+        if (!$member_handler->insertUser($xoopsUser)) {
+            include XOOPS_ROOT_PATH.'/header.php';
+            echo $xoopsUser->getHtmlErrors();
+            include XOOPS_ROOT_PATH.'/footer.php';
+            exit();
+        }
+        $avt_handler =& xoops_gethandler('avatar');
+        if ($oldavatar && $oldavatar != 'blank.gif' && !preg_match("/^savt/", strtolower($oldavatar))) {
+            $avatars =& $avt_handler->getObjects(new Criteria('avatar_file', $oldavatar));
+            if (is_object($avatars[0])) {
+                $avt_handler->delete($avatars[0]);
+            }
+            $oldavatar_path = str_replace("\\", "/", realpath(XOOPS_UPLOAD_PATH.'/'.$oldavatar));
+            if (0 === strpos($oldavatar_path, XOOPS_UPLOAD_PATH) && is_file($oldavatar_path)) {
+                unlink($oldavatar_path);
+            }
+        }
+        if ($user_avatar != 'blank.gif') {
+            $avatars =& $avt_handler->getObjects(new Criteria('avatar_file', $user_avatar));
+            if (is_object($avatars[0])) {
+                $avt_handler->addUser($avatars[0]->getVar('avatar_id'), $xoopsUser->getVar('uid'));
+            }
+        }
+    }
+    redirect_header('showusers.php', 0, _US_PROFUPDATED);
 }
 ?>
