@@ -1,6 +1,6 @@
 <?php
 /* constant strings
- * $Revision: 1.48.2.14 $
+ * $Revision: 1.109.2.1 $
  */
 
 // _MD_<MODULENAME>_<STRINGNAME>
@@ -26,6 +26,10 @@ define( "_MD_XOONIPS_ITEM_EDIT_INDEX_BUTTON_LABEL", "Edit index" );
 define( "_MD_XOONIPS_ITEM_SEARCH_RESULT", "Search Result" );
 define( "_MD_XOONIPS_ITEM_SEARCH_KEYWORD", "Search Keyword" );
 define( "_MD_XOONIPS_ITEM_SEARCH_ITEMTYPE", "Search Scope" );
+define( "_MI_XOONIPS_ITEM_SEARCH_TAB_ITEM", "Item" );
+define( "_MI_XOONIPS_ITEM_SEARCH_TAB_METADATA", "Metadata" );
+define( "_MI_XOONIPS_ITEM_SEARCH_TAB_FILE", "File" );
+define( "_MI_XOONIPS_ITEM_NO_ITEM_LISTED", "Please also open and check in the child tree." );
 
 define( "_MD_XOONIPS_ITEM_DETAIL_ITEM_TITLE", "Detail" );
 define( "_MD_XOONIPS_ITEM_MODIFY_ITEM_TITLE", "Modify" );
@@ -52,6 +56,7 @@ define( "_MD_XOONIPS_ITEM_ITEM_LABEL", "Item" );
 define( "_MD_XOONIPS_ITEM_INDEX_LABEL", "Index" );
 
 define( "_MD_XOONIPS_ITEM_SELECT_BUTTON_LABEL", "Select" );
+define( "_MD_XOONIPS_ITEM_SELECT_NONE_LABEL", "None" );
 
 define( "_MD_XOONIPS_ITEM_README_LABEL", "Readme" );
 define( "_MD_XOONIPS_ITEM_LICENSE_LABEL", "License" );
@@ -60,6 +65,14 @@ define( "_MD_XOONIPS_ITEM_PREVIEW_LABEL", "Preview" );
 define( "_MD_XOONIPS_ITEM_CAPTION_LABEL", "Caption of Preview" );
 define( "_MD_XOONIPS_ITEM_ATTACHMENT_LABEL", "Attachment" );
 define( "_MD_XOONIPS_ITEM_TEXTFILE_LABEL", "Text file" );
+define( "_MD_XOONIPS_ITEM_FILE_HEAD_LABEL", "File:" );
+define( "_MD_XOONIPS_ITEM_CAPTION_HEAD_LABEL", "Caption:" );
+define( "_MD_XOONIPS_ITEM_ORIGINAL_FILE_NAME_LABEL", "Original file name" );
+define( "_MD_XOONIPS_ITEM_MIME_TYPE_LABEL", "Mime-type" );
+define( "_MD_XOONIPS_ITEM_TYPE_LABEL", "Type" );
+define( "_MD_XOONIPS_ITEM_SIZE_LABEL", "Size" );
+define( "_MD_XOONIPS_ITEM_LAST_UPDATED_LABEL", "Last updated" );
+define( "_MD_XOONIPS_ITEM_DOWNLOAD_LABEL", "Download" );
 
 define( "_MD_XOONIPS_ITEM_TEXT_FILE_EDIT_LABEL", "Edit" );
 define( "_MD_XOONIPS_ITEM_UPLOAD_LABEL", "Upload" );
@@ -83,13 +96,14 @@ define( "_MD_XOONIPS_ADD_TO_PUBLIC_LABEL", "Submit" );
 define( "_MD_XOONIPS_ITEM_TITLE_LABEL", "Title" );
 define( "_MD_XOONIPS_ITEM_KEYWORDS_LABEL", "Free Keywords" );
 define( "_MD_XOONIPS_ITEM_DESCRIPTION_LABEL", "Comment" );
-define( "_MD_XOONIPS_ITEM_DOI_LABEL", "DOI" );
+define( "_MD_XOONIPS_ITEM_DOI_LABEL", "ID" );
 define( "_MD_XOONIPS_ITEM_ITEM_TYPE_LABEL", "Item Type" );
 define( "_MD_XOONIPS_ITEM_CREATION_DATE_LABEL", "Creation Date" );
 define( "_MD_XOONIPS_ITEM_LAST_UPDATE_DATE_LABEL", "Last Modified Date" );
 define( "_MD_XOONIPS_ITEM_CHANGELOG_LABEL", "Change Log" );
 define( "_MD_XOONIPS_ITEM_CHANGELOGS_LABEL", "Change Log(History)" );
 define( "_MD_XOONIPS_ITEM_CONTRIBUTOR_LABEL", "Contributor" );
+define( "_MD_XOONIPS_ITEM_UID_LABEL", "Uid" );
 define( "_MD_XOONIPS_ITEM_PUBLICATION_DATE_LABEL", "Date" );
 define( "_MD_XOONIPS_ITEM_PUBLICATION_YEAR_LABEL", "Year" );
 define( "_MD_XOONIPS_ITEM_PUBLICATION_MONTH_LABEL", "Month" );
@@ -104,19 +118,6 @@ define( "_MD_XOONIPS_ITEM_DELETE_CONFIRMATION_MESSAGE", "Are you sure you want t
 define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_CONFIRMATION_MESSAGE", "Would you like to accept this item?" );
 define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_CONFIRMATION_MESSAGE", "Are you sure you want to reject this item from the Public space?" );
 define( "_MD_XOONIPS_ITEM_WITHDRAW_CONFIRMATION_MESSAGE", "Are you sure you want to withdraw this item from the Public space?" );
-define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_MAIL_SUBJECT", "Your item has been rejected." );
-define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_MAIL_BODY", "Your item has been rejected. See below for details." );
-define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_INDEX_LABEL", "Rejected index" );
-define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_MAIL_SUBJECT", "Your item has been accepted." );
-define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_MAIL_BODY", "Your item has been accepted. See below for details." );
-define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_INDEX_LABEL", "Accepted index" );
-
-define( "_MD_XOONIPS_ITEM_REQUIRE_CERTIFY_MAIL_SUBJECT", "Item has been registerd into index keyword." );
-define( "_MD_XOONIPS_ITEM_REQUIRE_CERTIFY_MAIL_BODY", "Item has been registerd into index keyword.\n"
-                                               ."Judge the item should be certified or not.\n"
-                                               ."See below for details.\n" );
-define( "_MD_XOONIPS_ITEM_REQUIRE_CERTIFY_INDEX_LABEL", "Registerd into" );
-define( "_MD_XOONIPS_ITEM_REQUIRE_CERTIFY_JUDGE_URL_LABEL", "Judge from here" );
 
 define( "_MD_XOONIPS_ITEM_NEW_REGISTRATION_ITEMS_MAIL_SUBJECT", "New registration items" );
 define( "_MD_XOONIPS_ITEM_NEW_REGISTRATION_ITEMS_MAIL_BODY", "" );
@@ -133,12 +134,13 @@ define( "_MD_XOONIPS_HEADER_CERTIFY_ITEMS", "Please certify the following items.
 define( "_MD_XOONIPS_ITEM_WARNING_ITEM_NUMBER_LIMIT", "No more items are able to be registered. Please contact administrator." );
 define( "_MD_XOONIPS_ITEM_WARNING_INDEX_NUMBER_LIMIT", "No more indexes are able to be registered. Please contact administrator." );
 define( "_MD_XOONIPS_ITEM_WARNING_ITEM_STORAGE_LIMIT", "Not enough disk space. No more items are able to be registered. Please contact administrator." );
+define( "_MD_XOONIPS_ITEM_WARNING_FIELD_TRIM", "Red part will be trimmed because of length limit." );
 
 define( "_MD_XOONIPS_ITEM_NUM_OF_ITEM", "Number of Items" );
 define( "_MD_XOONIPS_ITEM_STORAGE_OF_ITEM", "Storage of Items" );
 
 define( "_MI_XOONIPS_ITEM_PANKUZU_ADVANCED_SEARCH", "Advanced Search" );
-define( "_MI_XOONIPS_ITEM_PANKUZU_REGISTER_ITEM", "Contribute New Item" );
+define( "_MI_XOONIPS_ITEM_PANKUZU_REGISTER_ITEM", "Add New Item" );
 define( "_MD_XOONIPS_ITEM_SEARCH_BUTTON_LABEL", "Search" );
 
 define( "_MI_XOONIPS_ITEM_PENDING_NOW", "(Pending)" );
@@ -218,15 +220,17 @@ define("_MI_XOONIPS_MODERATOR_PANKUZU_EDIT_GROUPS", "Edit Groups" );
 define("_MI_XOONIPS_MODERATOR_PANKUZU_LIST_GROUPS", "Group List" );
 define("_MI_XOONIPS_MODERATOR_PANKUZU_CREATE_NEW_GROUPS", "Create new group" );
 
+define("_MD_XOONIPS_MODERATOR_MODIFY_ANY_ITEMS_TITLE", "Moderator can modifiy any user's items" );
+
 define("_MD_XOONIPS_GROUPNAME_ALREADY_EXISTS", "Group name already exists." );
-define("_MD_XOONIPS_USER_CERTIFICATION_SUCCEED", "The user is certified" );
+define("_MD_XOONIPS_USER_CERTIFICATION_SUCCEED", "The user has been certified" );
 
 
 /// following defines for index
 
 define( "_MD_XOONIPS_INDEX_NUMBER_OF_PRIVATE_INDEX_LABEL", "Number of Private Indexes" );
 define( "_MD_XOONIPS_INDEX_NUMBER_OF_GROUP_INDEX_LABEL", "Number of Group Indexes" );
-define( "_MD_XOONIPS_INDEX_TOO_MANY_INDEXES", "Too Many Indexes" );
+define( "_MD_XOONIPS_INDEX_TOO_MANY_INDEXES", "Too Many Indexes. Can't register more index." );
 define( "_MD_XOONIPS_INDEX_NO_INDEX", "No Subindex Keyword" );
 
 define( "_MD_XOONIPS_INDEX_BUTTON_REGISTER", "register");// 
@@ -256,7 +260,9 @@ define( "_MD_XOONIPS_INDEX_DELETE_MESSAGE", "Index keyword %s was deleted. The f
 define( "_MD_XOONIPS_INDEX_DELETE_MAIL_SUBJECT", "Index keyword has been deleted." );
 define( "_MD_XOONIPS_INDEX_MOVETO_MESSAGE", "Index keyword %s was moved to %s. The following items were affected:");// 
 define( "_MD_XOONIPS_INDEX_MOVETO_MAIL_SUBJECT", "Index keyword has been moved." );
-define( "_MD_XOONIPS_INDEX_TITLE_CONFLICT", "WARNING: index name '%s' conflicts" );
+define( "_MD_XOONIPS_INDEX_TITLE_CONFLICT", "index name '%s' conflicts" );
+define( "_MD_XOONIPS_INDEX_TITLE_EXCEEDS", "index name is too long." );
+define( "_MD_XOONIPS_INDEX_TITLE_EMPTY", "index name cannot be empty." );
 define( "_MD_XOONIPS_INDEX_FORBIDDEN", "index tree is hidden from unregistered users" );
 
 // following defines for configuration
@@ -300,6 +306,7 @@ define( '_MI_XOONIPS_BINDER_ADD_FROM_INDEX_BUTTON_LABEL', "Index keyword" );
 define( '_MI_XOONIPS_BINDER_ADD_FROM_SEARCH_BUTTON_LABEL', "Search" );
 
 define( '_MD_XOONIPS_BINDER_ITEM_REQUIRED', 'At least one item is required' );
+define( '_MD_XOONIPS_BINDER_ITEM_LABEL', "Items" );
 
 /// following defines for account
 
@@ -327,6 +334,11 @@ define("_MD_XOONIPS_ACCOUNT_NOTICE_MAIL", "New Item Mail Notification" );
 define("_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_NUMBER_LIMIT",  "Maximum Private Items" );
 define("_MD_XOONIPS_ACCOUNT_PRIVATE_INDEX_NUMBER_LIMIT", "Maximum Private Indexes" );
 define("_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_STORAGE_LIMIT", "Maximum Disk Space for Private Items [MB]" );
+define("_MD_XOONIPS_ACCOUNT_POSITION", "Position" );
+define("_MD_XOONIPS_ACCOUNT_NSRA", "No Position Assigned" );
+define("_MD_XOONIPS_ACCOUNT_NSRID", "No Positions in Database" );
+define("_MD_XOONIPS_ACCOUNT_APPEAL", "Free description" );
+define("_MD_XOONIPS_ACCOUNT_CVITAE", "Curriculum Vitae" );
 
 define("_MD_XOONIPS_ACCOUNT_XNP_USER_INFO", "My Profile" );
 
@@ -376,7 +388,8 @@ define( "_MD_XOONIPS_ACCOUNT_PREFERENCE", "Perference" );
 // 
 // mesasge for user registration
 // 
-define("_MD_XOONIPS_ACTIVATE_BY_USER_CERTIFY_MANUAL", 'An e-mail has sent to the registered e-mail address. Please follow the instructions in the e-mail to activate your account. After activation, please wait for certification of your account by moderator.' );
+define("_MD_XOONIPS_ACTIVATE_KEY_SUBJECT", 'User activation key for %s');
+define("_MD_XOONIPS_ACTIVATE_BY_USER_CERTIFY_MANUAL", 'An e-mail has been sent to the registered e-mail address. You will need to activate your account by following the instructions in the e-mail. After completing the activation, please wait for certification of your account from the moderator.' );
 define("_MD_XOONIPS_ACTIVATE_BY_USER_CERTIFY_AUTO", 'An e-mail has been sent to the registered e-mail address. Please follow the instructions in the e-mail to activate your account.' );
 define("_MD_XOONIPS_ACTIVATE_AUTO_CERTIFY_MANUAL", 'An e-mail has sent to a moderator. Wait for your account certification. You get a notice of certification by e-mail. ' );
 define("_MD_XOONIPS_ACTIVATE_AUTO_CERTIFY_MANUAL_MAILNG", 'Failed in sending e-mail to moderator to request your account certification. Contact to an adminstrator or a moderator.');
@@ -388,7 +401,7 @@ define("_MD_XOONIPS_ACTIVATE_BY_ADMIN_MAILNG", 'Failed in sending e-mail to an a
 define("_MD_XOONIPS_ACTIVATED_BY_USER_CERTIFIED_AUTO", 'Your account of the user has been certified. You have an access to this site with username and password you registered.');
 define("_MD_XOONIPS_ACTIVATED_BY_ADMIN_CERTIFIED_AUTO", 'The account of the user has been activated and certified. An e-mail to notice certification has been sent to registered address.');
 define("_MD_XOONIPS_ACTIVATED_BY_ADMIN_CERTIFIED_AUTO_MAILNG", 'The account of the user has been activated and certified. However, failed in sending e-mail of notice to registered address.');
-define("_MD_XOONIPS_ACTIVATED_BY_USER_AND_CERTIFY_MANUAL", 'Your account has been activated. Wait for your account certification.');
+define("_MD_XOONIPS_ACTIVATED_BY_USER_AND_CERTIFY_MANUAL", 'Your account has been activated. Please wait for its certification before to use it. The certification will be notified to you by an e-mail from the moderator.');
 define("_MD_XOONIPS_ACTIVATED_BY_ADMIN_AND_CERTIFY_MANUAL", 'The account has been activated. After moderator certifies the account, an email is sent to registered address.');
 define("_MD_XOONIPS_ACTIVATED_BY_USER_AND_CERTIFY_MANUAL_MAILNG", 'Failed in sending e-mail to moderator to request your account certification. Contact to a moderator.');
 define("_MD_XOONIPS_ACTIVATED_BY_ADMIN_AND_CERTIFY_MANUAL_MAILNG", 'Failed in sending e-mail to moderator to request your account certification.' );
@@ -445,7 +458,7 @@ define("_MD_XOONIPS_ACCOUNT_REQUIRED"     , 'required'     );
 define( "_MD_XOONIPS_ACCOUNT_REQUIRED_MARK", "(*)" );
 define( "_MD_XOONIPS_ACCOUNT_EXPLAIN_REQUIRED_MARK", "(*) = required" );
 
-define( '_MI_XOONIPS_EVENT_LOG_EVENT_TYPES','dummy,Login Failure,Login Success,Logout,Insert Item,Update Item,Delete Item,View Item,Download File,Request To Certify Item,Insert Index,Update Index,Delete Index,Certify Item,Reject Item,Request To Insert Account,Certify Account,Insert Group,Update Group,Delete Group,Insert Group Member,Delete Group Member,View Top Page,Quick Search,Advanced Search' );
+define( '_MI_XOONIPS_EVENT_LOG_EVENT_TYPES','dummy,Login Failure,Login Success,Logout,Insert Item,Update Item,Delete Item,View Item,Download File,Request To Certify Item,Insert Index,Update Index,Delete Index,Certify Item,Reject Item,Request To Insert Account,Certify Account,Insert Group,Update Group,Delete Group,Insert Group Member,Delete Group Member,View Top Page,Quick Search,Advanced Search,Start SU,End SU' );
 define( '_MI_XOONIPS_EVENT_LOG_EVENT_COLUMNS','Event Type,Timestamp,Exec UID,Remote Host,Index ID,Item ID,File ID,UID,GID,Search Keyword,Login Name,Additional Information' );
 define( "_MD_XOONIPS_EVENT_LOG_00", "Download event log " );
 define( "_MD_XOONIPS_EVENT_LOG_10", " from " );
@@ -470,11 +483,13 @@ define( '_MI_XOONIPS_ITEM_PANKUZU_CERTIFY_GROUP_ITEMS', 'Certify Group Items' );
 define( '_MI_XOONIPS_ITEM_PANKUZU_EDIT_ACCOUNT', 'Edit Account' );
 define( '_MI_XOONIPS_ITEM_PANKUZU_VIEW_ACCOUNT', 'View Account' );
 define( "_MI_XOONIPS_EVENT_LOG_PANKUZU", "Event Log" );
+define( '_MI_XOONIPS_ITEM_PANKUZU_EDIT_CURRICULUM_VITAE', 'Edit Curriculum Vitae' );
 
 //export/import
 define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT', 'Export' );
 define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_CONFIG', 'Export setting' );
 define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_LICENSE', 'License agreement' );
+define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_INDEX', 'Export indexes' );
 define( '_MD_XOONIPS_EXPORT_CONFIG_TITLE', 'Export setting' );
 define( '_MD_XOONIPS_EXPORT_CONFIG_SUBMIT', 'Next' );
 define( '_MD_XOONIPS_EXPORT_RECURSIVE', 'Export indexes recursive' );
@@ -490,6 +505,9 @@ define( '_MD_XOONIPS_EXPORT_NO_ITEMS_FOUND', 'No items found.' );
 define( '_MD_XOONIPS_EXPORT_ACCEPT_ALL', 'Accept all' );
 define( '_MD_XOONIPS_EXPORT_EXPORT_ITEMS_EMPTY', 'no export item specified' );
 define( '_MD_XOONIPS_EXPORT_LICENSE_AGREEMENT_SUBMIT', 'Download' );
+define( '_MD_XOONIPS_EXPORT_EXPORT_INDEX', 'Exporting indexes in following settings' );
+define( '_MD_XOONIPS_EXPORT_TYPE_ITEM', 'Export items' );
+define( '_MD_XOONIPS_EXPORT_TYPE_INDEX', 'Export indexes' );
 define( '_MD_XOONIPS_IMPORT_TITLE', 'Import' );
 define( '_MD_XOONIPS_IMPORT_FILE', 'File to import' );
 define( '_MD_XOONIPS_IMPORT_INDEX', 'Indexes to import' );
@@ -500,16 +518,48 @@ define( '_MD_XOONIPS_IMPORT_PANKUZU_RESOLVE_CONFLICT', 'Resolve conflict' );
 define( '_MD_XOONIPS_IMPORT_TITLE_RESOLVE_CONFLICT', 'Resolve conflict' );
 define( '_MD_XOONIPS_IMPORT_IMPORT_ALL', 'Import all' );
 define( '_MD_XOONIPS_IMPORT_IMPORT_ITEM', 'Import item' );
-define( '_MD_XOONIPS_IMPORT_FOLLOWING_ITEM_CONFLICT', 'Following items have the same title.' );
 define( '_MD_XOONIPS_IMPORT_PANKUZU_UPLOAD_FILE', 'Upload file' );
-define( '_MD_XOONIPS_IMPORT_IMPORT_SUCCESSFULLY', 'Items have been successfully imported' );
+define( '_MD_XOONIPS_IMPORT_IMPORT_SUCCESSFULLY', 'Items have been successfully imported.' );
 define( '_MD_XOONIPS_IMPORT_NO_ITEMS_IMPORTED', 'No items have been imported.' );
 define( '_MD_XOONIPS_IMPORT_INDEX_NUMBER_LIMIT_OVER_FLOW', 'Error: Number of private indexes are exceeded. Please contact admin.' );
 define( '_MD_XOONIPS_IMPORT_ITEM_NUMBER_LIMIT_OVER_FLOW', 'Error: Number of private items are exceeded. Please contact admin.' );
-define( '_MD_XOONIPS_IMPORT_RESOLVE_CONFLICT_SUBMIT', 'Upload' );
+define( '_MD_XOONIPS_IMPORT_RESOLVE_CONFLICT_SUBMIT', 'Next' );
 define( '_MD_XOONIPS_IMPORT_UPLOAD_SUBMIT', 'Next' );
+define( '_MD_XOONIPS_IMPORT_PANKUZU_CHECK_LENGTH', 'Check length of each fields' );
+define( '_MD_XOONIPS_IMPORT_TITLE_CHECK_LENGTH', 'Check length of each fields' );
+define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_SUBMIT', 'Upload' );
+define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_WARNING', 'Following items exceed length limit. Red part will be trimmed.' );
+define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_NO_WARNING', 'No items will be trimmed.' );
 define( '_MD_XOONIPS_IMPORT_INDEX_CANNOT_WRITE', 'Indexes as follows are ignored. You can only import to your own private indexes.' );
-
+define( '_MD_XOONIPS_IMPORT_IGNORE_CHECK', 'Don\'t care confliction and trimming' );
+define( '_MD_XOONIPS_IMPORT_NO_STRINGS_ARE_TRIMMED', 'No strings are trimmed' );
+define( '_MD_XOONIPS_IMPORT_NO_CONFLICT_ITEMS', 'No confliction' );
+define( '_MD_XOONIPS_IMPORT_NUMBER_OF_CONFLICT_ITEMS', 'Number of conflict items:' );
+define( '_MD_XOONIPS_IMPORT_FOLLOWING_ITEM_CONFLICT', 'Following items conflict.' );
+define( '_MD_XOONIPS_IMPORT_IMPORT_ALL_AS_NEW', "All conflict items will be imported as an new items\n(check boxes of update are ignored)." );
+define( '_MD_XOONIPS_IMPORT_IMPORT_MODIFY', 'Update following items that has been registered to indexes imported to' );
+define( '_MD_XOONIPS_IMPORT_CONFLICT_ITEMS_IN_OTHER_INDEXES', 'In other indexes, following items conflict.(not updated)' );
+define( '_MD_XOONIPS_CONFLICT_ITEMS_IN_THE_SAME_FILE', 'In the same import file, following items conflict.' );
+define( '_MD_XOONIPS_IMPORT_IMPORT_CAN_NOT_MODIFY', 'This item can\'t be imported because it conflict with plural items.' );
+define( '_MD_XOONIPS_IMPORT_LOGGING', 'Logging' );
+define( '_MD_XOONIPS_IMPORT_ERROR', 'Error in importing.' );
+define( '_MD_XOONIPS_IMPORT_READY', 'Ready to import.' );
+define( '_MD_XOONIPS_IMPORT_NO_ERROR', 'No errors.' );
+define( '_MD_XOONIPS_IMPORT_REVIEW_LOG', 'Make sure the log.' );
+define( '_MD_XOONIPS_IMPORT_LOCAL_FILE', 'Import a local file' );
+define( '_MD_XOONIPS_IMPORT_REMOTE_FILE', 'Import a remote file' );
+define( '_MD_XOONIPS_IMPORT_ERROR_CHECK_ONLY', 'Don\'t import(Error check only)' );
+define( '_MD_XOONIPS_IMPORT_CONTRIBUTOR_SELECT', 'To import it in place of the other user' );
+define( '_MD_XOONIPS_IMPORT_ERROR_CKECK_DONE', 'Check has done.' );
+define( '_MD_XOONIPS_IMPORT_INDEX_TREE_CREATED', 'Indexes below has been imported to(If the index already exists , it is not modified.)' );
+define( '_MD_XOONIPS_IMPORT_INDEX_TREE_FAILED', 'Imporing index tree failed.' );
+define( '_MD_XOONIPS_IMPORT_FILE_NOT_FOUND', 'Import file is not found.' );
+define( '_MD_XOONIPS_IMPORT_FILE_NOT_SPECIFIED', 'Import file is not specified.' );
+define( '_MD_XOONIPS_IMPORT_CERTIFY_AUTO', 'To certify items automatically.' );
+define( '_MD_XOONIPS_IMPORT_NO_ITEMS_ARE_FOUND', 'No items to be imported are found.  Make sure that import file is correct.' );
+define( '_MD_XOONIPS_IMPORT_FOLLOWING_INDEX', 'Following indexes are imported.' );
+define( '_MD_XOONIPS_IMPORT_FOLLOWING_INDEX_TEST', 'Following indexes will be imported.' );
+define( '_MD_XOONIPS_IMPORT_CIRCULAR_INDEX', 'Indexes can\'t be imported because of circular structure.' );
 
 define( '_MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE', 'RSS file path(empty if you don\'t need RSS)' );
 define( '_MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE_NOT_WRITABLE_ERROR', 'File is not writable. Make sure '._MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE.'.' );
@@ -520,11 +570,11 @@ define( '_MD_XOONIPS_EVENT_ITEM_IS_SHOWN_IN', 'Item is shown in following index'
 define( '_MD_XOONIPS_EVENT_NEW_GROUP', 'New group has been created' );
 
 define( '_MD_XOONIPS_ITEM_LANG_LABEL', 'Language' );
-define( '_MD_XOONIPS_ITEM_LANG_OPTION_IDS', 'eng,jpn,fra,deu,esl,ita,dut,sve,nor,dan,fin,por,chi,kor,mul' );
-define( '_MD_XOONIPS_ITEM_LANG_OPTION_NAMES', 'English,Japanese,French,German,Spanish,Italian,Dutch,Swedish,Norwegian,Danish,Finnish,Portuguese,Chinese,Korean,Multiple languages' );
+define( '_MD_XOONIPS_ITEM_LANG_OPTION_IDS', 'eng,jpn,fra,deu,esl,ita,dut,sve,nor,dan,fin,por,chi,kor' );
+define( '_MD_XOONIPS_ITEM_LANG_OPTION_NAMES', 'English,Japanese,French,German,Spanish,Italian,Dutch,Swedish,Norwegian,Danish,Finnish,Portuguese,Chinese,Korean' );
 
 
-define( '_MD_XOONIPS_DOWNLOAD_LIMITATION_OPTION_LABEL', 'Download Limitation Option' );
+define( '_MD_XOONIPS_DOWNLOAD_LIMITATION_OPTION_LABEL', 'Download Limitation' );
 define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION', 'Download File Compression' );
 define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION_YES', 'Zipped with Metadata' );
 define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION_NO' , 'Uncompressed Plane File' );
@@ -551,6 +601,128 @@ define( '_MD_XOONIPS_REPOSITORY_PUBLISHER_NONE', 'None' );
 define( '_MD_XOONIPS_OAIPMH_CONFIG', 'OAI-PMH Configuration' );
 define( '_MD_XOONIPS_OAIPMH_CONFIG_REPOSITORIES', 'Repositories which to harvest(repository urls per line)' );
 define( '_MD_XOONIPS_OAIPMH_CONFIG_LOGS', 'Results of last harvesting(read only)' );
+define( '_MD_XOONIPS_OAIPMH_HARVESTING', 'Harvest now' );
+define( '_MD_XOONIPS_OAIPMH_HARVESTING_EXPLAIN', '' );
+define( '_MD_XOONIPS_OAIPMH_HARVEST_RESULT', 'Result of harvesting' );
+define( '_MD_XOONIPS_BACK_TO_OAIPMH_CONFIGURATION', 'Back to '._MD_XOONIPS_OAIPMH_CONFIG );
 
 define( '_MD_XOONIPS_METADATA_SEARCH_LABEL', 'Metadata Search' );
-?>
+
+define( '_MD_XOONIPS_FILESEARCH', 'File Search' );
+define( '_MD_XOONIPS_FILESEARCH_NAME', 'Module Name' );
+define( '_MD_XOONIPS_FILESEARCH_VERSION', 'Version' );
+define( '_MD_XOONIPS_FILESEARCH_RESCAN', 'Rescan all files' );
+
+// labels for item_show (edit)
+define( '_MD_XOONIPS_ITEMSHOW_CURRICULUM_VITAE', 'Curriculum Vitae' );
+define( '_MD_XOONIPS_ITEM_SHOW_OPTIONAL_TITLE', 'Choose Publication List from All Public items (if No just from your items)' );
+define( '_MD_XOONIPS_ITEM_SHOW_EDIT_TITLE', 'Edit Show Items' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_PREV', 'PREV' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_NEXT', 'NEXT' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_CHECK', 'Check' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_ITEMS', 'Items' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_SUBMIT', 'Submit' );
+define( '_MD_XOONIPS_NEED_LOGIN', 'The publication list can be inspected by logging in.' );
+define( '_MD_XOONIPS_NO_ITEM_SHOW', 'No Items in List.' );
+
+// admin/posi_order.php
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_TITLE', 'Position Order Select' );
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_EXPLAIN', 'The Position is not displayed if Position_order is less than zero.' );
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_POSI_LABEL', 'Position' );
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_ORDER_LABEL', 'Order' );
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_CHECK_LABEL', 'Check' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_TITLE', 'Add a new position' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_EXPLAIN', 'If Position Order is unentered, it sets up 0.' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_LABEL', 'Add a position' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_POSITITLE_LABEL', 'Position Title' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_POSIORDER_LABEL', 'Position Order' );
+define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_TITLE', 'User Order Select' );
+define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_EXPLAIN', 'The Position is not displayed if User Order is less than zero.' );
+define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_LABEL', 'Position [ Username ]' );
+
+// labels of userlists, showusers
+define( '_MD_XOONIPS_USERLIST_TITLE', 'User List' );
+define( '_MD_XOONIPS_USERLIST_EXPLANATION', 'Self-introduction will be displayed if a name is clicked.' );
+
+define( '_MD_XOONIPS_SHOW_USER_TITLE', 'User Information' );
+define( '_MD_XOONIPS_SEND_MESSAGE', 'Message To' );
+define( '_MD_XOONIPS_SHOW_CV_LABEL', 'Curriculum Vitae' );
+define( '_MD_XOONIPS_SHOW_PUBILICATION_LIST', 'Publication List' );
+define( '_MD_XOONIPS_SHOW_BACKTOLIST_LABEL', 'Back to User List' );
+define( '_MD_XOONIPS_VIEW_USER_ACCOUNT', 'View Account' );
+define( '_MD_XOONIPS_EDIT_LISTS', 'Edit' );
+define( '_MD_XOONIPS_ORDER_CHANGE', 'Order' );
+
+define( '_MD_XOONIPS_UPLOAD_MAX_FILESIZE', 'File size up to:' );
+define( '_MD_XOONIPS_UPLOAD_ERR_OK', 'upload succeed' );
+define( '_MD_XOONIPS_UPLOAD_ERR_INI_SIZE', 'upload filesize too large( upload_max_filesize )' );
+define( '_MD_XOONIPS_UPLOAD_ERR_FORM_SIZE', 'upload filesize too large( MAX_FILE_SIZE )' );
+define( '_MD_XOONIPS_UPLOAD_ERR_PARTIAL', 'uploaded file is imcomplete' );
+define( '_MD_XOONIPS_UPLOAD_ERR_NO_FILE', 'no files are uploaded' );
+define( '_MD_XOONIPS_UPLOAD_ERR_NO_TMP_DIR', 'temporary folder does not exists.' );
+define( '_MD_XOONIPS_UPLOAD_ERR_CANT_WRITE', 'can\'t write to disk.' );
+
+// labels for edit curriculum vitae, publication list.
+define( '_MD_XOONIPS_EDIT_CV_TITLE', 'Edit CV' );
+define( '_MD_XOONIPS_EDIT_CURRICULUM_VITAE', 'Edit Curriculum Vitae' );
+define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE_LABEL', 'Add Curriculum Vitae' );
+define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE_WARNING', 'Please enter the title of Curriculum Vitae.' );
+define( '_MD_XOONIPS_CURRICULUM_VITAE_FROM', 'From' );
+define( '_MD_XOONIPS_CURRICULUM_VITAE_TO', 'To' );
+define( '_MD_XOONIPS_CURRICULUM_VITAE_TITLE', 'Title' );
+define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE', 'Add' );
+define( '_MD_XOONIPS_MODIFY_CURRICULUM_VITAE_LABEL', 'Edit Curriculum Vitae' );
+define( '_MD_XOONIPS_NO_CURRICULUM_VITAE_DATA', 'No Title Data.' );
+define( "_MD_XOONIPS_CURRICULUM_VITAE_BUTTON_EDIT", "modify"); 
+define( '_MD_XOONIPS_CURRICULUM_VITAE_CHECK_INFO', 'Back to your User Information' );
+define( '_MD_XOONIPS_CURRICULUM_VITAE_INSERT', 'Now, Curriculum Vitae data is registered into a database.' );
+define( '_MD_XOONIPS_NO_PUBLICATION_ITEM_DATA', 'No Item data for Publication List.' );
+define( '_MD_XOONIPS_PUBLICATION_ITEM_CHANGE', 'Change item order for Publication List' );
+define( '_MD_XOONIPS_PUBLICATION_ITEM_INSERT', 'Now, Publication item data is registered into a database.' );
+
+define( '_MD_XOONIPS_RANKING_UP', '&#9650;' );
+define( '_MD_XOONIPS_RANKING_DOWN', '&#9660;' );
+define( '_MD_XOONIPS_RANKING_NUM_ROWS_1', 'Show ' );
+define( '_MD_XOONIPS_RANKING_NUM_ROWS_2', ' items in each ranking' );
+define( '_MD_XOONIPS_RANKING_DAYS_1', 'Calculate based on last ' );
+define( '_MD_XOONIPS_RANKING_DAYS_2', ' days log. <br /> sum-file does not affect to ranking if this check is ON.' );
+
+define( '_MD_XOONIPS_RANKING_WHAT_DELETING_LOG_IS', 'Ranking calculation is based on logs. Deletion of logs makes ranking empty unless downloading and uploading sum-file. <br />' );
+define( '_MD_XOONIPS_RANKING_FILE_CONFIG_EXPLAIN', 'download / upload sum-file.' );
+define( '_MD_XOONIPS_RANKING_DOWNLOAD_FILE', 'download' );
+define( '_MD_XOONIPS_RANKING_UPLOAD_FILE', 'upload' );
+define( '_MD_XOONIPS_RANKING_CLEAR', 'clear' );
+
+define( '_MD_XOONIPS_RANKING_LABEL', 'ranking block' );
+define( '_MD_XOONIPS_RANKING_NEW_LABEL', 'new-arrived ranking block' );
+define( '_MD_XOONIPS_RANKING_CHECK_RANKING_LABEL', 'Check rankings to show.' );
+define( '_MD_XOONIPS_RANKING_LOCKED', 'Now calculating. Retry after few seconds.' );
+
+define("_MI_XOONIPS_RANKING_CONFIG", "Ranking configuration"); 
+define("_MI_XOONIPS_RANKING_FILE_CONFIG", "Ranking sum-file configuration"); 
+define("_MD_XOONIPS_RANKING_VISIBLE", "visible"); 
+define("_MD_XOONIPS_RANKING_NAME", "ranking name"); 
+
+define("_MD_XOONIPS_RANKING_DOWNLOAD_LABEL", "file name to download"); 
+define("_MD_XOONIPS_RANKING_UPLOAD_LABEL", "file name to upload"); 
+define("_MD_XOONIPS_RANKING_CLEAR_SOME_LABEL", "have sum ( from %s to %s )"); 
+define("_MD_XOONIPS_RANKING_CLEAR_EMPTY_LABEL", "no sum."); 
+define("_MD_XOONIPS_RANKING_CLEAR_LABEL", "clear sum"); 
+
+// admin/itemtype_order.php
+define("_MD_XOONIPS_ITEMTYPE_CONFIGURATION_LABEL", "ItemTypes Configuration");
+define("_MD_XOONIPS_ITEMTYPE_ORDER_SELECT_LABEL", "ItemTypes Order Select");
+define("_MD_XOONIPS_ITEMTYPE_ORDER_SELECT_EXPLAIN", "Please input the integer of the one or more in order.");
+
+define("_MD_XOONIPS_SU_TITLE", "Start su");
+define("_MD_XOONIPS_SU_TARGET_USER", "Switch to");
+define("_MD_XOONIPS_SU_ADMIN_PASSWORD", "Your Password");
+define("_MD_XOONIPS_SU_OK", "OK");
+define("_MD_XOONIPS_SU_CANNOT_LOGOUT", "End su before logout!");
+
+define("_MD_XOONIPS_SU_START", "Switching to another account.");
+define("_MD_XOONIPS_SU_FAIL", "Incorrect password!");
+define("_MD_XOONIPS_SU_END", "Returning to your account.");
+define("_MD_XOONIPS_SU_EXPLAIN", "You can switch to another account temporary.");
+
+?>
\ No newline at end of file
