@@ -1,6 +1,6 @@
 <?php
 /* constant strings
- * $Revision: 1.40.2.14 $
+ * $Revision: 1.97.2.1 $
  */
 
 // _MD_<MODULENAME>_<STRINGNAME>
@@ -26,6 +26,10 @@ define( "_MD_XOONIPS_ITEM_EDIT_INDEX_BUTTON_LABEL", "ǥåԽ" );
 define( "_MD_XOONIPS_ITEM_SEARCH_RESULT", "" );
 define( "_MD_XOONIPS_ITEM_SEARCH_KEYWORD", "" );
 define( "_MD_XOONIPS_ITEM_SEARCH_ITEMTYPE", "о" );
+define( "_MI_XOONIPS_ITEM_SEARCH_TAB_ITEM", "ƥ" );
+define( "_MI_XOONIPS_ITEM_SEARCH_TAB_METADATA", "᥿ǡ" );
+define( "_MI_XOONIPS_ITEM_SEARCH_TAB_FILE", "ե" );
+define( "_MI_XOONIPS_ITEM_NO_ITEM_LISTED", "ĥ꡼򳫤Ƥ˻ҥǥå֥饦ƤߤƲ" );
 
 define( "_MD_XOONIPS_ITEM_DETAIL_ITEM_TITLE", "ܺ" );
 define( "_MD_XOONIPS_ITEM_MODIFY_ITEM_TITLE", "Խ" );
@@ -52,6 +56,7 @@ define( "_MD_XOONIPS_ITEM_ITEM_LABEL", "ƥ" );
 define( "_MD_XOONIPS_ITEM_INDEX_LABEL", "ǥå" );
 
 define( "_MD_XOONIPS_ITEM_SELECT_BUTTON_LABEL", "" );
+define( "_MD_XOONIPS_ITEM_SELECT_NONE_LABEL", "ʤ" );
 
 define( "_MD_XOONIPS_ITEM_README_LABEL", "Readme" );
 define( "_MD_XOONIPS_ITEM_LICENSE_LABEL", "License" );
@@ -60,6 +65,14 @@ define( "_MD_XOONIPS_ITEM_PREVIEW_LABEL", "ץӥ塼" );
 define( "_MD_XOONIPS_ITEM_CAPTION_LABEL", "ץӥ塼Υץ" );
 define( "_MD_XOONIPS_ITEM_ATTACHMENT_LABEL", "źեե" );
 define( "_MD_XOONIPS_ITEM_TEXTFILE_LABEL", "ƥȥե" );
+define( "_MD_XOONIPS_ITEM_FILE_HEAD_LABEL", "ե롧" );
+define( "_MD_XOONIPS_ITEM_CAPTION_HEAD_LABEL", "ץ" );
+define( "_MD_XOONIPS_ITEM_ORIGINAL_FILE_NAME_LABEL", "ե̾" );
+define( "_MD_XOONIPS_ITEM_MIME_TYPE_LABEL", "Mime-type" );
+define( "_MD_XOONIPS_ITEM_TYPE_LABEL", "Type" );
+define( "_MD_XOONIPS_ITEM_SIZE_LABEL", "Size" );
+define( "_MD_XOONIPS_ITEM_LAST_UPDATED_LABEL", "Last updated" );
+define( "_MD_XOONIPS_ITEM_DOWNLOAD_LABEL", "Download" );
 
 define( "_MD_XOONIPS_ITEM_TEXT_FILE_EDIT_LABEL", "Խ" );
 define( "_MD_XOONIPS_ITEM_UPLOAD_LABEL", "" );
@@ -75,20 +88,21 @@ define( "_MD_XOONIPS_ITEM_UPLOAD_PREVIEW", "Uploadܥ򲡤ơץӥ塼ե '%s' 򥢥å
 define( "_MD_XOONIPS_ITEM_REQUIRED_MARK", "<font color=red>*</font>" );
 define( "_MD_XOONIPS_ITEM_DOWNLOAD_CONFIRMATION", "ΥեΥ饤ʸ˹դޤ" );
 
-define( "_MD_XOONIPS_ADD_TO_PUBLIC_EXPLANATION", "ǥåϿ<br />" );
-define( "_MD_XOONIPS_ADD_TO_PUBLIC_LABEL", "Submit" );
+define( "_MD_XOONIPS_ADD_TO_PUBLIC_EXPLANATION", "ΰɲ<br />" );
+define( "_MD_XOONIPS_ADD_TO_PUBLIC_LABEL", "ɲ" );
 
 //Basic Information field name
 define( "_MD_XOONIPS_ITEM_TITLE_LABEL", "ȥ" );
 define( "_MD_XOONIPS_ITEM_KEYWORDS_LABEL", "ե꡼" );
 define( "_MD_XOONIPS_ITEM_DESCRIPTION_LABEL", "" );
-define( "_MD_XOONIPS_ITEM_DOI_LABEL", "DOI" );
+define( "_MD_XOONIPS_ITEM_DOI_LABEL", "ID" );
 define( "_MD_XOONIPS_ITEM_ITEM_TYPE_LABEL", "ƥॿ" );
 define( "_MD_XOONIPS_ITEM_CREATION_DATE_LABEL", "" );
 define( "_MD_XOONIPS_ITEM_LAST_UPDATE_DATE_LABEL", "ǽ" );
 define( "_MD_XOONIPS_ITEM_CHANGELOG_LABEL", "ѹ" );
 define( "_MD_XOONIPS_ITEM_CHANGELOGS_LABEL", "" );
 define( "_MD_XOONIPS_ITEM_CONTRIBUTOR_LABEL", "Ͽ" );
+define( "_MD_XOONIPS_ITEM_UID_LABEL", "ϿID" );
 define( "_MD_XOONIPS_ITEM_PUBLICATION_DATE_LABEL", "" );
 define( "_MD_XOONIPS_ITEM_PUBLICATION_YEAR_LABEL", "ǯ" );
 define( "_MD_XOONIPS_ITEM_PUBLICATION_MONTH_LABEL", "" );
@@ -103,19 +117,6 @@ define( "_MD_XOONIPS_ITEM_DELETE_CONFIRMATION_MESSAGE", "˺ƤǤ?" );
 define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_CONFIRMATION_MESSAGE", "ˤΥƥǧƤǤ?" );
 define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_CONFIRMATION_MESSAGE", "ˤΥƥѲƤǤ?" );
 define( "_MD_XOONIPS_ITEM_WITHDRAW_CONFIRMATION_MESSAGE", "ˤΥƥѲƤǤ?" );
-define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_MAIL_SUBJECT", "ʤΥƥθϵѲޤ" );
-define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_MAIL_BODY", "ʤΥƥθϵѲޤܤϰʲ򸫤Ʋ" );
-define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_INDEX_LABEL", "Ѳ줿ǥå" );
-define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_MAIL_SUBJECT", "ʤΥƥθϾǧޤ" );
-define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_MAIL_BODY", "ʤΥƥθϾǧޤܤϰʲ򸫤Ʋ" );
-define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_INDEX_LABEL", "Ĥ줿ǥå" );
-
-define( "_MD_XOONIPS_ITEM_REQUIRE_CERTIFY_MAIL_SUBJECT", "ƥबǥåɤϿޤ" );
-define( "_MD_XOONIPS_ITEM_REQUIRE_CERTIFY_MAIL_BODY", "ƥबǥåɤϿޤ\n"
-                                               ."ǧ뤫ݤȽꤷƤ\n"
-	."ܤϰʲ򸫤Ʋ\n" );
-define( "_MD_XOONIPS_ITEM_REQUIRE_CERTIFY_INDEX_LABEL", "Registerd into" );
-define( "_MD_XOONIPS_ITEM_REQUIRE_CERTIFY_JUDGE_URL_LABEL", "餫Ƚꤹ뤳ȤǤޤ" );
 
 define( "_MD_XOONIPS_ITEM_NEW_REGISTRATION_ITEMS_MAIL_SUBJECT", "Ͽ줿ƥ" );
 define( "_MD_XOONIPS_ITEM_NEW_REGISTRATION_ITEMS_MAIL_BODY", "" );
@@ -132,9 +133,10 @@ define( "_MD_XOONIPS_HEADER_CERTIFY_ITEMS", "ʲΥƥǧƲ" );
 define( "_MD_XOONIPS_ITEM_WARNING_ITEM_NUMBER_LIMIT", "ʾ奢ƥϿǤޤ󡥥ȴԤϢƲ" );
 define( "_MD_XOONIPS_ITEM_WARNING_INDEX_NUMBER_LIMIT", "ʾ奤ǥåϿǤޤ󡥥ȴԤϢƲ" );
 define( "_MD_XOONIPS_ITEM_WARNING_ITEM_STORAGE_LIMIT", "ǥΰ褬­ޤ󡥤ʾ奢ƥϿǤޤ󡥥ȴԤϢƲ" );
+define( "_MD_XOONIPS_ITEM_WARNING_FIELD_TRIM", "ʸ¤ΤᡢֻǼʬڤΤƤޤ" );
 
 define( "_MD_XOONIPS_ITEM_NUM_OF_ITEM", "ƥ" );
-define( "_MD_XOONIPS_ITEM_STORAGE_OF_ITEM", "Storage of Items" );
+define( "_MD_XOONIPS_ITEM_STORAGE_OF_ITEM", "źեե" );
 
 define( "_MI_XOONIPS_ITEM_PANKUZU_ADVANCED_SEARCH", "ܺٸ" );
 define( "_MI_XOONIPS_ITEM_PANKUZU_REGISTER_ITEM", "ƥϿ" );
@@ -217,6 +219,7 @@ define("_MI_XOONIPS_MODERATOR_PANKUZU_CERTIFY_USERS", "桼ǧ" );
 define("_MI_XOONIPS_MODERATOR_PANKUZU_EDIT_GROUPS", "롼Խ" );
 define("_MI_XOONIPS_MODERATOR_PANKUZU_LIST_GROUPS", "Group List" );
 define("_MI_XOONIPS_MODERATOR_PANKUZU_CREATE_NEW_GROUPS", "Create new group" );
+define("_MD_XOONIPS_MODERATOR_MODIFY_ANY_ITEMS_TITLE", "ǥ졼桼ΥƥԽǤ" );
 
 define("_MD_XOONIPS_GROUPNAME_ALREADY_EXISTS", "Υ롼̾ϴ¸ߤޤ" );
 define("_MD_XOONIPS_USER_CERTIFICATION_SUCCEED", "桼ǧޤ" );
@@ -225,7 +228,7 @@ define("_MD_XOONIPS_USER_CERTIFICATION_SUCCEED", "桼ǧޤ" );
 
 define( "_MD_XOONIPS_INDEX_NUMBER_OF_PRIVATE_INDEX_LABEL", "ץ饤١ȥǥå" );
 define( "_MD_XOONIPS_INDEX_NUMBER_OF_GROUP_INDEX_LABEL", "롼ץǥå" );
-define( "_MD_XOONIPS_INDEX_TOO_MANY_INDEXES", "ǥå¿ޤ" );
+define( "_MD_XOONIPS_INDEX_TOO_MANY_INDEXES", "ϿǽʥǥåĶᡢǥåǤޤ" );
 define( "_MD_XOONIPS_INDEX_NO_INDEX", "֥ǥåɤϤޤ" );
 
 define( "_MD_XOONIPS_INDEX_BUTTON_REGISTER", "Ͽ");// 
@@ -255,7 +258,9 @@ define( "_MD_XOONIPS_INDEX_DELETE_MESSAGE", "ǥå %s ޤȼΥƥˤƶޤ :");//
 define( "_MD_XOONIPS_INDEX_DELETE_MAIL_SUBJECT", "ǥåɤޤ" );
 define( "_MD_XOONIPS_INDEX_MOVETO_MESSAGE", "ǥå %s  %s ذưޤȼΥƥƶޤ :");//
 define( "_MD_XOONIPS_INDEX_MOVETO_MAIL_SUBJECT", "ǥåɤϰưޤ" );
-define( "_MD_XOONIPS_INDEX_TITLE_CONFLICT", "ٹ: ǥå̾ '%s' 礷Ƥޤ" );
+define( "_MD_XOONIPS_INDEX_TITLE_CONFLICT", "ǥå̾ '%s' 礷Ƥޤ" );
+define( "_MD_XOONIPS_INDEX_TITLE_EXCEEDS", "ǥå̾Ĺޤ" );
+define( "_MD_XOONIPS_INDEX_TITLE_EMPTY", "ǥå̾ˤ뤳ȤϤǤޤ" );
 define( "_MD_XOONIPS_INDEX_FORBIDDEN", "̤Ͽ桼ʤΤǥǥåĥ꡼ɽǤޤ" );
 
 // following defines for configuration
@@ -299,6 +304,7 @@ define( '_MI_XOONIPS_BINDER_ADD_FROM_INDEX_BUTTON_LABEL', "ǥå" );
 define( '_MI_XOONIPS_BINDER_ADD_FROM_SEARCH_BUTTON_LABEL', "" );
 
 define( '_MD_XOONIPS_BINDER_ITEM_REQUIRED', 'ʤȤ1İʾΥƥबɬפǤ' );
+define( '_MD_XOONIPS_BINDER_ITEM_LABEL', "ƥ" );
 
 /// following defines for account
 
@@ -326,6 +332,11 @@ define("_MD_XOONIPS_ACCOUNT_NOTICE_MAIL", "᡼ֳ []" );
 define("_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_NUMBER_LIMIT",  "ץ饤١ȥƥκϿ" );
 define("_MD_XOONIPS_ACCOUNT_PRIVATE_INDEX_NUMBER_LIMIT", "ץ饤١ȥǥåκϿ" );
 define("_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_STORAGE_LIMIT", "ץ饤١ȥƥκǥ [MB]" );
+define("_MD_XOONIPS_ACCOUNT_POSITION", "̾" );
+define("_MD_XOONIPS_ACCOUNT_NSRA", "̾ꤵƤޤ" );
+define("_MD_XOONIPS_ACCOUNT_NSRID", "꤬̾ޤ" );
+define("_MD_XOONIPS_ACCOUNT_APPEAL", "ͳ" );
+define("_MD_XOONIPS_ACCOUNT_CVITAE", "ά" );
 
 define("_MD_XOONIPS_ACCOUNT_XNP_USER_INFO", "桼" );
 
@@ -430,12 +441,12 @@ define("_MD_XOONIPS_ACCOUNT_COUNTRY_OPTIONAL_TITLE" , '̾'  . '' );
 define("_MD_XOONIPS_ACCOUNT_ZIPCODE_OPTIONAL_TITLE" , '͹ֹ'  . '' );
 define("_MD_XOONIPS_ACCOUNT_FAX_OPTIONAL_TITLE"     , 'FAXֹ'      . '' );
 
-define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_ITEM_NUMBER_LIMIT_TITLE"  , 'ĿΰϿǽʥƥν' );
-define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_INDEX_NUMBER_LIMIT_TITLE" , 'ĿΰϿǽʥǥåν' );
-define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_ITEM_STORAGE_LIMIT_TITLE" , 'ĿΰѲǽʥǥ̤ν [MB]' );
-define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_ITEM_NUMBER_LIMIT_TITLE"    , '롼ΰϿǽʥƥν' );
-define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_INDEX_NUMBER_LIMIT_TITLE"   , '롼ΰϿǽʥǥåν' );
-define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_ITEM_STORAGE_LIMIT_TITLE"   , '롼ΰѲǽʥǥ̤ν [MB]' );
+define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_ITEM_NUMBER_LIMIT_TITLE"  , 'ĿΰϿǽʥƥκ' );
+define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_INDEX_NUMBER_LIMIT_TITLE" , 'ĿΰϿǽʥǥåκ' );
+define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_ITEM_STORAGE_LIMIT_TITLE" , 'ĿΰѲǽʥǥ̤κ [MB]' );
+define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_ITEM_NUMBER_LIMIT_TITLE"    , '롼ΰϿǽʥƥκ' );
+define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_INDEX_NUMBER_LIMIT_TITLE"   , '롼ΰϿǽʥǥåκ' );
+define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_ITEM_STORAGE_LIMIT_TITLE"   , '롼ΰѲǽʥǥ̤κ [MB]' );
 
 define("_MD_XOONIPS_ACCOUNT_AMAZON_ASSOCIATES_ID_TITLE"   , 'AmazonID' );
 
@@ -445,7 +456,7 @@ define("_MD_XOONIPS_ACCOUNT_REQUIRED"     , 'ɬ'     );
 define( "_MD_XOONIPS_ACCOUNT_REQUIRED_MARK", "(*)" );
 define( "_MD_XOONIPS_ACCOUNT_EXPLAIN_REQUIRED_MARK", "(*) = ɬ" );
 
-define( '_MI_XOONIPS_EVENT_LOG_EVENT_TYPES','dummy,Login Failure,Login Success,Logout,Insert Item,Update Item,Delete Item,View Item,Download File,Request To Certify Item,Insert Index,Update Index,Delete Index,Certify Item,Reject Item,Request To Insert Account,Certify Account,Insert Group,Update Group,Delete Group,Insert Group Member,Delete Group Member,View Top Page,Quick Search,Advanced Search' );
+define( '_MI_XOONIPS_EVENT_LOG_EVENT_TYPES','dummy,Login Failure,Login Success,Logout,Insert Item,Update Item,Delete Item,View Item,Download File,Request To Certify Item,Insert Index,Update Index,Delete Index,Certify Item,Reject Item,Request To Insert Account,Certify Account,Insert Group,Update Group,Delete Group,Insert Group Member,Delete Group Member,View Top Page,Quick Search,Advanced Search,Start SU,End SU' );
 define( '_MI_XOONIPS_EVENT_LOG_EVENT_COLUMNS','Event Type,Timestamp,Exec UID,Remote Host,Index ID,Item ID,File ID,UID,GID,Search Keyword,Login Name,Additional Information' );
 define( "_MD_XOONIPS_EVENT_LOG_00", "" );
 define( "_MD_XOONIPS_EVENT_LOG_10", "" );
@@ -470,11 +481,13 @@ define( '_MI_XOONIPS_ITEM_PANKUZU_CERTIFY_GROUP_ITEMS', '롼׸ƥྵǧ' );
 define( '_MI_XOONIPS_ITEM_PANKUZU_EDIT_ACCOUNT', 'ץեԽ' );
 define( '_MI_XOONIPS_ITEM_PANKUZU_VIEW_ACCOUNT', 'Ⱦ' );
 define( "_MI_XOONIPS_EVENT_LOG_PANKUZU", "٥ȥ" );
+define( '_MI_XOONIPS_ITEM_PANKUZU_EDIT_CURRICULUM_VITAE', 'άԽ' );
 
 //export/import
 define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT', 'ݡ' );
 define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_CONFIG', 'ݡ' );
 define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_LICENSE', 'ѵ(饤)' );
+define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_INDEX', 'ǥå򥨥ݡ' );
 define( '_MD_XOONIPS_EXPORT_CONFIG_TITLE', 'ݡ' );
 define( '_MD_XOONIPS_EXPORT_CONFIG_SUBMIT', '' );
 define( '_MD_XOONIPS_EXPORT_RECURSIVE', 'ǥåƵŪ˥ݡȤ' );
@@ -490,6 +503,9 @@ define( '_MD_XOONIPS_EXPORT_NO_ITEMS_FOUND', '륢ƥϤޤ' );
 define( '_MD_XOONIPS_EXPORT_ACCEPT_ALL', '٤ƤΥ饤󥹤˹դ' );
 define( '_MD_XOONIPS_EXPORT_EXPORT_ITEMS_EMPTY', 'Export륢ƥब򤵤Ƥޤ' );
 define( '_MD_XOONIPS_EXPORT_LICENSE_AGREEMENT_SUBMIT', '' );
+define( '_MD_XOONIPS_EXPORT_EXPORT_INDEX', 'ʲǥǥå򥨥ݡȤޤ' );
+define( '_MD_XOONIPS_EXPORT_TYPE_ITEM', 'ƥ򥨥ݡȤ' );
+define( '_MD_XOONIPS_EXPORT_TYPE_INDEX', 'ǥåĥ꡼򥨥ݡȤ' );
 define( '_MD_XOONIPS_IMPORT_TITLE', 'ݡ' );
 define( '_MD_XOONIPS_IMPORT_FILE', 'Importե' );
 define( '_MD_XOONIPS_IMPORT_INDEX', 'Import襤ǥå' );
@@ -500,15 +516,48 @@ define( '_MD_XOONIPS_IMPORT_PANKUZU_RESOLVE_CONFLICT', 'ͤβ' );
 define( '_MD_XOONIPS_IMPORT_TITLE_RESOLVE_CONFLICT', 'ͤβ' );
 define( '_MD_XOONIPS_IMPORT_IMPORT_ALL', 'ƥݡ' );
 define( '_MD_XOONIPS_IMPORT_IMPORT_ITEM', 'ݡȤ륢ƥ' );
-define( '_MD_XOONIPS_IMPORT_FOLLOWING_ITEM_CONFLICT', 'ʲΥƥΥȥ뤬ʣƤޤ' );
 define( '_MD_XOONIPS_IMPORT_PANKUZU_UPLOAD_FILE', 'ե륢åץ' );
 define( '_MD_XOONIPS_IMPORT_IMPORT_SUCCESSFULLY', 'ݡȤλޤ' );
 define( '_MD_XOONIPS_IMPORT_NO_ITEMS_IMPORTED', 'ݡȤ륢ƥबޤ' );
 define( '_MD_XOONIPS_IMPORT_INDEX_NUMBER_LIMIT_OVER_FLOW', 'ʾ奤ǥå򥤥ݡȤǤޤ󡥥ȴԤϢƲ' );
 define( '_MD_XOONIPS_IMPORT_ITEM_NUMBER_LIMIT_OVER_FLOW', 'ʾ奢ƥ򥤥ݡȤǤޤ󡥥ȴԤϢƲ' );
-define( '_MD_XOONIPS_IMPORT_RESOLVE_CONFLICT_SUBMIT', 'åץ' );
+define( '_MD_XOONIPS_IMPORT_RESOLVE_CONFLICT_SUBMIT', '' );
 define( '_MD_XOONIPS_IMPORT_UPLOAD_SUBMIT', '' );
+define( '_MD_XOONIPS_IMPORT_PANKUZU_CHECK_LENGTH', 'ʸĶΥå' );
+define( '_MD_XOONIPS_IMPORT_TITLE_CHECK_LENGTH', 'ʸĶΥå' );
+define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_SUBMIT', 'åץ' );
+define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_WARNING', 'ʲΥƥϡʸĶΤڤΤƤޤ(ֻʬ)' );
+define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_NO_WARNING', 'ʸĶ᤹륢ƥϤޤ' );
 define( '_MD_XOONIPS_IMPORT_INDEX_CANNOT_WRITE', 'ʲΥǥå̵뤵ޤݡȤǤ륤ǥåϤʤΥץ饤١ȥǥåΤߤǤ' );
+define( '_MD_XOONIPS_IMPORT_IGNORE_CHECK', 'ͤʸĶåʤ' );
+define( '_MD_XOONIPS_IMPORT_NO_STRINGS_ARE_TRIMMED', 'ʸ¤ۤʸϤޤǤ' );
+define( '_MD_XOONIPS_IMPORT_NO_CONFLICT_ITEMS', 'ͤ륢ƥϤޤǤ' );
+define( '_MD_XOONIPS_IMPORT_NUMBER_OF_CONFLICT_ITEMS', 'ͤ륢ƥο' );
+define( '_MD_XOONIPS_IMPORT_FOLLOWING_ITEM_CONFLICT', 'ʲΥƥबʣƤޤ' );
+define( '_MD_XOONIPS_IMPORT_IMPORT_ALL_AS_NEW', "ͤƤΥƥ򿷤ƥȤƥݡȤ\nʾ񤭥åܥåλ̵뤷ޤˡ" );
+define( '_MD_XOONIPS_IMPORT_IMPORT_MODIFY', 'ݡ襤ǥåˤʲξͥƥ񤭤' );
+define( '_MD_XOONIPS_IMPORT_CONFLICT_ITEMS_IN_OTHER_INDEXES', '̤Υǥå˰ʲξͥƥबޤ(񤭤ޤ)' );
+define( '_MD_XOONIPS_CONFLICT_ITEMS_IN_THE_SAME_FILE', 'ݡȥե˰ʲξͥƥबޤ' );
+define( '_MD_XOONIPS_IMPORT_IMPORT_CAN_NOT_MODIFY', 'ʣΥƥȾͤΤǥݡȤǤޤ' );
+define( '_MD_XOONIPS_IMPORT_LOGGING', 'Ϥ' );
+define( '_MD_XOONIPS_IMPORT_ERROR', 'ݡȽ˥顼ȯޤ' );
+define( '_MD_XOONIPS_IMPORT_READY', 'ݡȤǤޤ' );
+define( '_MD_XOONIPS_IMPORT_NO_ERROR', '顼Ϥޤ' );
+define( '_MD_XOONIPS_IMPORT_REVIEW_LOG', 'ǧƤ' );
+define( '_MD_XOONIPS_IMPORT_LOCAL_FILE', 'ե򥤥ݡȤ' );
+define( '_MD_XOONIPS_IMPORT_REMOTE_FILE', 'оΥե򥤥ݡȤ' );
+define( '_MD_XOONIPS_IMPORT_ERROR_CHECK_ONLY', '顼åԤ' );
+define( '_MD_XOONIPS_IMPORT_CONTRIBUTOR_SELECT', '桼θ¤ǥݡȤ' );
+define( '_MD_XOONIPS_IMPORT_ERROR_CKECK_DONE', '顼åλޤ' );
+define( '_MD_XOONIPS_IMPORT_INDEX_TREE_CREATED', 'ʲΥǥåĥ꡼򥤥ݡȤޤʥꥹδ¸Ʊ̾ǥåƤѹƤޤˡ' );
+define( '_MD_XOONIPS_IMPORT_INDEX_TREE_FAILED', 'ǥåĥ꡼ΥݡȤ˼Ԥޤ' );
+define( '_MD_XOONIPS_IMPORT_FILE_NOT_FOUND', 'ݡȥե뤬Ĥޤ' );
+define( '_MD_XOONIPS_IMPORT_FILE_NOT_SPECIFIED', 'ݡȥե뤬ꤵƤޤ' );
+define( '_MD_XOONIPS_IMPORT_CERTIFY_AUTO', 'ǥåϿ륢ƥưǧ' );
+define( '_MD_XOONIPS_IMPORT_NO_ITEMS_ARE_FOUND', 'ݡȤ륢ƥबĤޤǤݡȥեƤǧƤ' );
+define( '_MD_XOONIPS_IMPORT_FOLLOWING_INDEX', 'ʲΥǥå򥤥ݡȤޤ' );
+define( '_MD_XOONIPS_IMPORT_FOLLOWING_INDEX_TEST', 'ʲΥǥå򥤥ݡȤǤޤ' );
+define( '_MD_XOONIPS_IMPORT_CIRCULAR_INDEX', 'ǥå۴Ĺ¤äƤ뤿ᡢݡȤǤޤ' );
 
 define( '_MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE', 'RSSΥեѥ' );
 define( '_MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE_NOT_WRITABLE_ERROR', '񤭹ߤǤޤ'._MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE.'ǧƤ' );
@@ -519,11 +568,11 @@ define( '_MD_XOONIPS_EVENT_ITEM_IS_SHOWN_IN', 'ƥबʲΥǥå˸ޤ' );
 define( '_MD_XOONIPS_EVENT_NEW_GROUP', '롼פޤ' );
 
 define( '_MD_XOONIPS_ITEM_LANG_LABEL', '' );
-define( '_MD_XOONIPS_ITEM_LANG_OPTION_IDS', 'eng,jpn,fra,deu,esl,ita,dut,sve,nor,dan,fin,por,chi,kor,mul' );
-define( '_MD_XOONIPS_ITEM_LANG_OPTION_NAMES', 'Ѹ,ܸ,ե󥹸,ɥĸ,ڥ,ꥢ,,ǥ,Υ륦,ǥޡ,եɸ,ݥȥ,,ڹ,¿' );
+define( '_MD_XOONIPS_ITEM_LANG_OPTION_IDS', 'eng,jpn,fra,deu,esl,ita,dut,sve,nor,dan,fin,por,chi,kor' );
+define( '_MD_XOONIPS_ITEM_LANG_OPTION_NAMES', 'Ѹ,ܸ,ե󥹸,ɥĸ,ڥ,ꥢ,,ǥ,Υ륦,ǥޡ,եɸ,ݥȥ,,ڹ' );
 
 
-define( '_MD_XOONIPS_DOWNLOAD_LIMITATION_OPTION_LABEL', '¥ץ' );
+define( '_MD_XOONIPS_DOWNLOAD_LIMITATION_OPTION_LABEL', '' );
 define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION', 'ɥե륪ץ' );
 define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION_YES', '᥿ǡZIPʿ侩' );
 define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION_NO' , '̤ʤ' );
@@ -549,7 +598,127 @@ define( '_MD_XOONIPS_REPOSITORY_PUBLISHER_NONE', 'Ѥʤ' );
 define( '_MD_XOONIPS_OAIPMH_CONFIG', 'OAI-PMH' );
 define( '_MD_XOONIPS_OAIPMH_CONFIG_REPOSITORIES', 'ϡ٥ȤݥȥURL(ݥȥꤴȤ˲)' );
 define( '_MD_XOONIPS_OAIPMH_CONFIG_LOGS', 'Ǹ˥ϡ٥ȤȤη(ιܤԽǤޤ)' );
+define( '_MD_XOONIPS_OAIPMH_HARVESTING', 'ϡ٥Ȥ' );
+define( '_MD_XOONIPS_OAIPMH_HARVESTING_EXPLAIN', 'ޤϡ٥ȤˤϤΥܥ򲡤Ƥ' );
+define( '_MD_XOONIPS_OAIPMH_HARVEST_RESULT', 'ϡ٥ȷ' );
+define( '_MD_XOONIPS_BACK_TO_OAIPMH_CONFIGURATION', _MD_XOONIPS_OAIPMH_CONFIG.'' );
 
 define( '_MD_XOONIPS_METADATA_SEARCH_LABEL', '᥿ǡ' );
 
+define( '_MD_XOONIPS_FILESEARCH', 'ե븡' );
+define( '_MD_XOONIPS_FILESEARCH_NAME', '⥸塼̾' );
+define( '_MD_XOONIPS_FILESEARCH_VERSION', 'С' );
+define( '_MD_XOONIPS_FILESEARCH_RESCAN', 'ƤΥեƥ' );
+
+// labels for item_show (edit)
+define( '_MD_XOONIPS_ITEMSHOW_CURRICULUM_VITAE', 'ά' );
+define( '_MD_XOONIPS_ITEM_SHOW_OPTIONAL_TITLE', 'ΰˤƤΥƥफӥƥ򤹤<br />ʤ桼ܿͤϿƥफǽ' );
+define( '_MD_XOONIPS_ITEM_SHOW_EDIT_TITLE', 'ӥƥ' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_PREV', '' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_NEXT', '' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_CHECK', 'å' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_ITEMS', 'ƥ' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_SUBMIT', 'ѹ' );
+define( '_MD_XOONIPS_NEED_LOGIN', '󤹤ȶӤαǤޤ' );
+
+// admin/posi_order.php
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_TITLE', '̾ɽ' );
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_EXPLAIN', 'ɽ̤ͤʤ餽ο̾ϲ̤ɽޤ' );
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_POSI_LABEL', '̾' );
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_ORDER_LABEL', 'ɽ' );
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_CHECK_LABEL', 'å' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_TITLE', '̾ɲåե' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_EXPLAIN', 'ɽ礬ʤ飰ꤷޤ' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_LABEL', '̾ɲ' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_POSITITLE_LABEL', '̾' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_POSIORDER_LABEL', 'ɽ' );
+define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_TITLE', '桼ɽ' );
+define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_EXPLAIN', 'ɽ̤ͤʤ餽Υ桼ϲ̤ɽޤ' );
+define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_LABEL', '̾ [ 桼̾ ]' );
+
+// labels of userlists, showusers
+define( '_MD_XOONIPS_USERLIST_TITLE', '桼' );
+define( '_MD_XOONIPS_USERLIST_EXPLANATION', '桼̾򥯥åȳƥ桼ξɽޤ' );
+
+define( '_MD_XOONIPS_SHOW_USER_TITLE', '桼' );
+define( '_MD_XOONIPS_SEND_MESSAGE', 'å' );
+define( '_MD_XOONIPS_SHOW_CV_LABEL', 'ά' );
+define( '_MD_XOONIPS_SHOW_PUBILICATION_LIST', 'ӥꥹ' );
+define( '_MD_XOONIPS_SHOW_BACKTOLIST_LABEL', '' );
+define( '_MD_XOONIPS_VIEW_USER_ACCOUNT', 'ȳǧ' );
+define( '_MD_XOONIPS_EDIT_LISTS', 'Խ' );
+define( '_MD_XOONIPS_ORDER_CHANGE', 'ɽѹ' );
+
+define( '_MD_XOONIPS_UPLOAD_MAX_FILESIZE', 'ե륵:' );
+define( '_MD_XOONIPS_UPLOAD_ERR_OK', 'åץ' );
+define( '_MD_XOONIPS_UPLOAD_ERR_INI_SIZE', 'ե륵礭ޤ( upload_max_filesize )' );
+define( '_MD_XOONIPS_UPLOAD_ERR_FORM_SIZE', 'ե륵礭ޤ( MAX_FILE_SIZE )' );
+define( '_MD_XOONIPS_UPLOAD_ERR_PARTIAL', 'եΰåפޤǤ' );
+define( '_MD_XOONIPS_UPLOAD_ERR_NO_FILE', 'եϥåץɤޤǤ' );
+define( '_MD_XOONIPS_UPLOAD_ERR_NO_TMP_DIR', 'ƥݥեդޤ' );
+define( '_MD_XOONIPS_UPLOAD_ERR_CANT_WRITE', 'ǥ˽񤭹߽ޤǤ' );
+
+// labels for edit curriculum vitae, publication list
+define( '_MD_XOONIPS_EDIT_CV_TITLE', 'άԽ' );
+define( '_MD_XOONIPS_EDIT_CURRICULUM_VITAE', 'άԽ' );
+define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE_LABEL', 'άɲ' );
+define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE_WARNING', 'ܤϤƤ' );
+define( '_MD_XOONIPS_CURRICULUM_VITAE_FROM', 'From' );
+define( '_MD_XOONIPS_CURRICULUM_VITAE_TO', 'To' );
+define( '_MD_XOONIPS_CURRICULUM_VITAE_TITLE', '' );
+define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE', 'ɲ' );
+define( '_MD_XOONIPS_MODIFY_CURRICULUM_VITAE_LABEL', 'άԽ' );
+define( '_MD_XOONIPS_NO_CURRICULUM_VITAE_DATA', 'άǡϿƤޤ' );
+define( "_MD_XOONIPS_CURRICULUM_VITAE_BUTTON_EDIT", "ѹ");
+define( '_MD_XOONIPS_CURRICULUM_VITAE_CHECK_INFO', '桼' );
+define( '_MD_XOONIPS_CURRICULUM_VITAE_INSERT', 'άǡɲäޤ' );
+define( '_MD_XOONIPS_NO_PUBLICATION_ITEM_DATA', 'ӥꥹȤ˥ƥबϿƤޤ' );
+define( '_MD_XOONIPS_PUBLICATION_ITEM_CHANGE', 'ɽѹ' );
+define( '_MD_XOONIPS_PUBLICATION_ITEM_INSERT', 'ӥꥹȤԽƤޤ' );
+
+define( '_MD_XOONIPS_RANKING_UP', '' );
+define( '_MD_XOONIPS_RANKING_DOWN', '' );
+define( '_MD_XOONIPS_RANKING_NUM_ROWS_1', 'ƥ󥭥󥰤ξ' );
+define( '_MD_XOONIPS_RANKING_NUM_ROWS_2', 'ɽޤ' );
+define( '_MD_XOONIPS_RANKING_DAYS_1', '' );
+define( '_MD_XOONIPS_RANKING_DAYS_2', '֤ΥǡΤߤ󥭥оݤȤޤ<br />λONˤ硤ͥեͤϥ󥭥󥰤ȿǤޤ' );
+
+define( '_MD_XOONIPS_RANKING_WHAT_DELETING_LOG_IS', ' õȥ󥭥󥰤ꥢޤ<br />򤱤ˤϡõǽͥեΥɡåץɤԤäƤ' );
+define( '_MD_XOONIPS_RANKING_FILE_CONFIG_EXPLAIN', 'ͤΥåץɡɤԤޤ' );
+define( '_MD_XOONIPS_RANKING_DOWNLOAD_FILE', '' );
+define( '_MD_XOONIPS_RANKING_UPLOAD_FILE', 'åץ' );
+define( '_MD_XOONIPS_RANKING_CLEAR', 'ꥢ' );
+
+define( '_MD_XOONIPS_RANKING_LABEL', '󥭥ѥ֥å' );
+define( '_MD_XOONIPS_RANKING_NEW_LABEL', '󥭥ѥ֥å' );
+define( '_MD_XOONIPS_RANKING_CHECK_RANKING_LABEL', 'ɽ󥭥󥰤򤷤Ƥ(ʣå)' );
+define( '_MD_XOONIPS_RANKING_LOCKED', '߽ǤԤäƤȥ饤Ƥ' );
+
+define("_MI_XOONIPS_RANKING_CONFIG", "󥭥"); 
+define("_MI_XOONIPS_RANKING_FILE_CONFIG", "󥭥󥰽ץե"); 
+define("_MD_XOONIPS_RANKING_VISIBLE", "ɽ"); 
+define("_MD_XOONIPS_RANKING_NAME", "ɽ"); 
+
+define("_MD_XOONIPS_RANKING_DOWNLOAD_LABEL", "ɤե̾"); 
+define("_MD_XOONIPS_RANKING_UPLOAD_LABEL", "åץɤե"); 
+define("_MD_XOONIPS_RANKING_CLEAR_SOME_LABEL", "%s  %s νͤäƤޤ"); 
+define("_MD_XOONIPS_RANKING_CLEAR_EMPTY_LABEL", "ͤϤޤ"); 
+define("_MD_XOONIPS_RANKING_CLEAR_LABEL", "ͤΥꥢ"); 
+
+// admin/itemtype_order.php
+define("_MD_XOONIPS_ITEMTYPE_CONFIGURATION_LABEL", "ƥॿ");
+define("_MD_XOONIPS_ITEMTYPE_ORDER_SELECT_LABEL", "ƥॿɽѹ");
+define("_MD_XOONIPS_ITEMTYPE_ORDER_SELECT_EXPLAIN", "ɽ1ʾꤷƤ");
+
+define("_MD_XOONIPS_SU_TITLE", "suγ");
+define("_MD_XOONIPS_SU_TARGET_USER", "Ȥڤؤ");
+define("_MD_XOONIPS_SU_ADMIN_PASSWORD", "ʤΥѥ");
+define("_MD_XOONIPS_SU_OK", "OK");
+define("_MD_XOONIPS_SU_CANNOT_LOGOUT", "ȤsuλƤ");
+
+define("_MD_XOONIPS_SU_START", "ȤڤؤƤޤ");
+define("_MD_XOONIPS_SU_FAIL", "ѥɤۤʤޤ");
+define("_MD_XOONIPS_SU_END", "Ԥޤ");
+define("_MD_XOONIPS_SU_EXPLAIN", "Ū¾桼ΥȤǺȤ뤳ȤǤޤ");
+
 ?>
