@@ -1,6 +1,6 @@
 <?php
 /* constant strings
- * $Revision: 1.38.2.12 $
+ * $Revision: 1.95.2.1 $
  */
 
 // _MD_<MODULENAME>_<STRINGNAME>
@@ -26,6 +26,10 @@ define( "_MD_XOONIPS_ITEM_EDIT_INDEX_BUTTON_LABEL", "インデックス編集" )
 define( "_MD_XOONIPS_ITEM_SEARCH_RESULT", "検索結果" );
 define( "_MD_XOONIPS_ITEM_SEARCH_KEYWORD", "検索キーワード" );
 define( "_MD_XOONIPS_ITEM_SEARCH_ITEMTYPE", "検索対象" );
+define( "_MI_XOONIPS_ITEM_SEARCH_TAB_ITEM", "アイテム" );
+define( "_MI_XOONIPS_ITEM_SEARCH_TAB_METADATA", "メタデータ" );
+define( "_MI_XOONIPS_ITEM_SEARCH_TAB_FILE", "ファイル" );
+define( "_MI_XOONIPS_ITEM_NO_ITEM_LISTED", "ツリーを開いてさらに子インデックス内もブラウズしてみて下さい" );
 
 define( "_MD_XOONIPS_ITEM_DETAIL_ITEM_TITLE", "詳細" );
 define( "_MD_XOONIPS_ITEM_MODIFY_ITEM_TITLE", "編集" );
@@ -52,6 +56,7 @@ define( "_MD_XOONIPS_ITEM_ITEM_LABEL", "アイテム" );
 define( "_MD_XOONIPS_ITEM_INDEX_LABEL", "インデックス" );
 
 define( "_MD_XOONIPS_ITEM_SELECT_BUTTON_LABEL", "選択" );
+define( "_MD_XOONIPS_ITEM_SELECT_NONE_LABEL", "なし" );
 
 define( "_MD_XOONIPS_ITEM_README_LABEL", "Readme" );
 define( "_MD_XOONIPS_ITEM_LICENSE_LABEL", "License" );
@@ -60,6 +65,14 @@ define( "_MD_XOONIPS_ITEM_PREVIEW_LABEL", "プレビュー" );
 define( "_MD_XOONIPS_ITEM_CAPTION_LABEL", "プレビューのキャプション" );
 define( "_MD_XOONIPS_ITEM_ATTACHMENT_LABEL", "添付ファイル" );
 define( "_MD_XOONIPS_ITEM_TEXTFILE_LABEL", "テキストファイル" );
+define( "_MD_XOONIPS_ITEM_FILE_HEAD_LABEL", "ファイル：" );
+define( "_MD_XOONIPS_ITEM_CAPTION_HEAD_LABEL", "キャプション：" );
+define( "_MD_XOONIPS_ITEM_ORIGINAL_FILE_NAME_LABEL", "元ファイル名" );
+define( "_MD_XOONIPS_ITEM_MIME_TYPE_LABEL", "Mime-type" );
+define( "_MD_XOONIPS_ITEM_TYPE_LABEL", "Type" );
+define( "_MD_XOONIPS_ITEM_SIZE_LABEL", "Size" );
+define( "_MD_XOONIPS_ITEM_LAST_UPDATED_LABEL", "Last updated" );
+define( "_MD_XOONIPS_ITEM_DOWNLOAD_LABEL", "Download" );
 
 define( "_MD_XOONIPS_ITEM_TEXT_FILE_EDIT_LABEL", "編集" );
 define( "_MD_XOONIPS_ITEM_UPLOAD_LABEL", "更新" );
@@ -75,20 +88,21 @@ define( "_MD_XOONIPS_ITEM_UPLOAD_PREVIEW", "先にUploadボタンを押して、
 define( "_MD_XOONIPS_ITEM_REQUIRED_MARK", "<font color=red>*</font>" );
 define( "_MD_XOONIPS_ITEM_DOWNLOAD_CONFIRMATION", "このファイルのライセンス文に合意しますか？" );
 
-define( "_MD_XOONIPS_ADD_TO_PUBLIC_EXPLANATION", "公開インデックスに登録<br />" );
-define( "_MD_XOONIPS_ADD_TO_PUBLIC_LABEL", "Submit" );
+define( "_MD_XOONIPS_ADD_TO_PUBLIC_EXPLANATION", "公開領域へ追加<br />" );
+define( "_MD_XOONIPS_ADD_TO_PUBLIC_LABEL", "追加" );
 
 //Basic Information field name
 define( "_MD_XOONIPS_ITEM_TITLE_LABEL", "タイトル" );
 define( "_MD_XOONIPS_ITEM_KEYWORDS_LABEL", "フリーキーワード" );
 define( "_MD_XOONIPS_ITEM_DESCRIPTION_LABEL", "コメント" );
-define( "_MD_XOONIPS_ITEM_DOI_LABEL", "DOI" );
+define( "_MD_XOONIPS_ITEM_DOI_LABEL", "ID" );
 define( "_MD_XOONIPS_ITEM_ITEM_TYPE_LABEL", "アイテムタイプ" );
 define( "_MD_XOONIPS_ITEM_CREATION_DATE_LABEL", "作成日" );
 define( "_MD_XOONIPS_ITEM_LAST_UPDATE_DATE_LABEL", "最終更新日" );
 define( "_MD_XOONIPS_ITEM_CHANGELOG_LABEL", "変更内容" );
 define( "_MD_XOONIPS_ITEM_CHANGELOGS_LABEL", "更新履歴" );
 define( "_MD_XOONIPS_ITEM_CONTRIBUTOR_LABEL", "登録者" );
+define( "_MD_XOONIPS_ITEM_UID_LABEL", "登録者ID" );
 define( "_MD_XOONIPS_ITEM_PUBLICATION_DATE_LABEL", "日付" );
 define( "_MD_XOONIPS_ITEM_PUBLICATION_YEAR_LABEL", "年" );
 define( "_MD_XOONIPS_ITEM_PUBLICATION_MONTH_LABEL", "月" );
@@ -103,19 +117,6 @@ define( "_MD_XOONIPS_ITEM_DELETE_CONFIRMATION_MESSAGE", "本当に削除して
 define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_CONFIRMATION_MESSAGE", "本当にこのアイテム公開を承認してよろしいですか?" );
 define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_CONFIRMATION_MESSAGE", "本当にこのアイテム公開を却下してよろしいですか?" );
 define( "_MD_XOONIPS_ITEM_WITHDRAW_CONFIRMATION_MESSAGE", "本当にこのアイテム公開を却下してよろしいですか?" );
-define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_MAIL_SUBJECT", "あなたのアイテムの公開は却下されました" );
-define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_MAIL_BODY", "あなたのアイテムの公開は却下されました．詳しくは以下を見て下さい．" );
-define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_INDEX_LABEL", "却下されたインデックス" );
-define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_MAIL_SUBJECT", "あなたのアイテムの公開は承認されました" );
-define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_MAIL_BODY", "あなたのアイテムの公開は承認されました．詳しくは以下を見て下さい．" );
-define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_INDEX_LABEL", "許可されたインデックス" );
-
-define( "_MD_XOONIPS_ITEM_REQUIRE_CERTIFY_MAIL_SUBJECT", "アイテムがインデックスキーワードに登録されました" );
-define( "_MD_XOONIPS_ITEM_REQUIRE_CERTIFY_MAIL_BODY", "アイテムがインデックスキーワードに登録されました．\n"
-                                               ."公開を承認するか否かを判定してください．\n"
-	."詳しくは以下を見て下さい．\n" );
-define( "_MD_XOONIPS_ITEM_REQUIRE_CERTIFY_INDEX_LABEL", "Registerd into" );
-define( "_MD_XOONIPS_ITEM_REQUIRE_CERTIFY_JUDGE_URL_LABEL", "こちらから判定することができます．" );
 
 define( "_MD_XOONIPS_ITEM_NEW_REGISTRATION_ITEMS_MAIL_SUBJECT", "新規に登録されたアイテム" );
 define( "_MD_XOONIPS_ITEM_NEW_REGISTRATION_ITEMS_MAIL_BODY", "" );
@@ -132,9 +133,10 @@ define( "_MD_XOONIPS_HEADER_CERTIFY_ITEMS", "以下のアイテムを承認し
 define( "_MD_XOONIPS_ITEM_WARNING_ITEM_NUMBER_LIMIT", "これ以上アイテムを登録できません．サイト管理者に連絡して下さい．" );
 define( "_MD_XOONIPS_ITEM_WARNING_INDEX_NUMBER_LIMIT", "これ以上インデックスを登録できません．サイト管理者に連絡して下さい．" );
 define( "_MD_XOONIPS_ITEM_WARNING_ITEM_STORAGE_LIMIT", "ディスク領域が足りません．これ以上アイテムを登録できません．サイト管理者に連絡して下さい．" );
+define( "_MD_XOONIPS_ITEM_WARNING_FIELD_TRIM", "文字数制限のため、赤字で示した部分は切り捨てられます" );
 
 define( "_MD_XOONIPS_ITEM_NUM_OF_ITEM", "アイテム数" );
-define( "_MD_XOONIPS_ITEM_STORAGE_OF_ITEM", "Storage of Items" );
+define( "_MD_XOONIPS_ITEM_STORAGE_OF_ITEM", "添付ファイル容量" );
 
 define( "_MI_XOONIPS_ITEM_PANKUZU_ADVANCED_SEARCH", "詳細検索" );
 define( "_MI_XOONIPS_ITEM_PANKUZU_REGISTER_ITEM", "新規アイテム登録" );
@@ -218,6 +220,8 @@ define("_MI_XOONIPS_MODERATOR_PANKUZU_EDIT_GROUPS", "グループ編集" );
 define("_MI_XOONIPS_MODERATOR_PANKUZU_LIST_GROUPS", "Group List" );
 define("_MI_XOONIPS_MODERATOR_PANKUZU_CREATE_NEW_GROUPS", "Create new group" );
 
+define("_MD_XOONIPS_MODERATOR_MODIFY_ANY_ITEMS_TITLE", "モデレータは全ユーザのアイテムを編集できる" );
+
 define("_MD_XOONIPS_GROUPNAME_ALREADY_EXISTS", "そのグループ名は既に存在します．" );
 define("_MD_XOONIPS_USER_CERTIFICATION_SUCCEED", "ユーザを承認しました．" );
 
@@ -225,7 +229,7 @@ define("_MD_XOONIPS_USER_CERTIFICATION_SUCCEED", "ユーザを承認しました
 
 define( "_MD_XOONIPS_INDEX_NUMBER_OF_PRIVATE_INDEX_LABEL", "プライベートインデックス数" );
 define( "_MD_XOONIPS_INDEX_NUMBER_OF_GROUP_INDEX_LABEL", "グループインデックス数" );
-define( "_MD_XOONIPS_INDEX_TOO_MANY_INDEXES", "インデックスが多すぎます" );
+define( "_MD_XOONIPS_INDEX_TOO_MANY_INDEXES", "登録可能なインデックス数を超えたため、インデックスを作成できません" );
 define( "_MD_XOONIPS_INDEX_NO_INDEX", "サブインデックスキーワードはありません" );
 
 define( "_MD_XOONIPS_INDEX_BUTTON_REGISTER", "登録");// 
@@ -255,7 +259,9 @@ define( "_MD_XOONIPS_INDEX_DELETE_MESSAGE", "インデックスキーワード %
 define( "_MD_XOONIPS_INDEX_DELETE_MAIL_SUBJECT", "インデックスキーワードが削除されました" );
 define( "_MD_XOONIPS_INDEX_MOVETO_MESSAGE", "インデックスキーワード %s が %s へ移動されました．これに伴い次のアイテムも影響がありました :");//
 define( "_MD_XOONIPS_INDEX_MOVETO_MAIL_SUBJECT", "インデックスキーワードは移動されました．" );
-define( "_MD_XOONIPS_INDEX_TITLE_CONFLICT", "警告: インデックス名 '%s' が競合しています．" );
+define( "_MD_XOONIPS_INDEX_TITLE_CONFLICT", "インデックス名 '%s' が競合しています．" );
+define( "_MD_XOONIPS_INDEX_TITLE_EXCEEDS", "インデックス名が長すぎます" );
+define( "_MD_XOONIPS_INDEX_TITLE_EMPTY", "インデックス名を空にすることはできません．" );
 define( "_MD_XOONIPS_INDEX_FORBIDDEN", "未登録ユーザなのでインデックスツリーを表示できません" );
 
 // following defines for configuration
@@ -299,6 +305,7 @@ define( '_MI_XOONIPS_BINDER_ADD_FROM_INDEX_BUTTON_LABEL', "インデックスキ
 define( '_MI_XOONIPS_BINDER_ADD_FROM_SEARCH_BUTTON_LABEL', "検索" );
 
 define( '_MD_XOONIPS_BINDER_ITEM_REQUIRED', '少なくとも1つ以上のアイテムが必要です' );
+define( '_MD_XOONIPS_BINDER_ITEM_LABEL', "アイテム" );
 
 /// following defines for account
 
@@ -326,6 +333,11 @@ define("_MD_XOONIPS_ACCOUNT_NOTICE_MAIL", "新着メール送信間隔 [日]" );
 define("_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_NUMBER_LIMIT",  "プライベートアイテムの最大登録数" );
 define("_MD_XOONIPS_ACCOUNT_PRIVATE_INDEX_NUMBER_LIMIT", "プライベートインデックスの最大登録数" );
 define("_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_STORAGE_LIMIT", "プライベートアイテムの最大ディスク容量 [MB]" );
+define("_MD_XOONIPS_ACCOUNT_POSITION", "職名" );
+define("_MD_XOONIPS_ACCOUNT_NSRA", "職名は設定されていません" );
+define("_MD_XOONIPS_ACCOUNT_NSRID", "職名の設定がありません" );
+define("_MD_XOONIPS_ACCOUNT_APPEAL", "自由記述" );
+define("_MD_XOONIPS_ACCOUNT_CVITAE", "略歴" );
 
 define("_MD_XOONIPS_ACCOUNT_XNP_USER_INFO", "ユーザ情報" );
 
@@ -430,12 +442,12 @@ define("_MD_XOONIPS_ACCOUNT_COUNTRY_OPTIONAL_TITLE" , '国名'  . 'の入力' );
 define("_MD_XOONIPS_ACCOUNT_ZIPCODE_OPTIONAL_TITLE" , '郵便番号'  . 'の入力' );
 define("_MD_XOONIPS_ACCOUNT_FAX_OPTIONAL_TITLE"     , 'FAX番号'      . 'の入力' );
 
-define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_ITEM_NUMBER_LIMIT_TITLE"  , '個人領域に登録可能なアイテム数の初期値' );
-define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_INDEX_NUMBER_LIMIT_TITLE" , '個人領域に登録可能なインデックス数の初期値' );
-define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_ITEM_STORAGE_LIMIT_TITLE" , '個人領域の利用可能なディスク容量の初期値 [MB]' );
-define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_ITEM_NUMBER_LIMIT_TITLE"    , 'グループ領域に登録可能なアイテム数の初期値' );
-define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_INDEX_NUMBER_LIMIT_TITLE"   , 'グループ領域に登録可能なインデックス数の初期値' );
-define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_ITEM_STORAGE_LIMIT_TITLE"   , 'グループ領域の利用可能なディスク容量の初期値 [MB]' );
+define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_ITEM_NUMBER_LIMIT_TITLE"  , '個人領域に登録可能なアイテム数の最大値' );
+define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_INDEX_NUMBER_LIMIT_TITLE" , '個人領域に登録可能なインデックス数の最大値' );
+define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_ITEM_STORAGE_LIMIT_TITLE" , '個人領域の利用可能なディスク容量の最大値 [MB]' );
+define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_ITEM_NUMBER_LIMIT_TITLE"    , 'グループ領域に登録可能なアイテム数の最大値' );
+define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_INDEX_NUMBER_LIMIT_TITLE"   , 'グループ領域に登録可能なインデックス数の最大値' );
+define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_ITEM_STORAGE_LIMIT_TITLE"   , 'グループ領域の利用可能なディスク容量の最大値 [MB]' );
 
 define("_MD_XOONIPS_ACCOUNT_AMAZON_ASSOCIATES_ID_TITLE"   , 'AmazonアソシエイトID' );
 
@@ -445,7 +457,7 @@ define("_MD_XOONIPS_ACCOUNT_REQUIRED"     , '必須'     );
 define( "_MD_XOONIPS_ACCOUNT_REQUIRED_MARK", "(*)" );
 define( "_MD_XOONIPS_ACCOUNT_EXPLAIN_REQUIRED_MARK", "(*) = 必須" );
 
-define( '_MI_XOONIPS_EVENT_LOG_EVENT_TYPES','dummy,Login Failure,Login Success,Logout,Insert Item,Update Item,Delete Item,View Item,Download File,Request To Certify Item,Insert Index,Update Index,Delete Index,Certify Item,Reject Item,Request To Insert Account,Certify Account,Insert Group,Update Group,Delete Group,Insert Group Member,Delete Group Member,View Top Page,Quick Search,Advanced Search' );
+define( '_MI_XOONIPS_EVENT_LOG_EVENT_TYPES','dummy,Login Failure,Login Success,Logout,Insert Item,Update Item,Delete Item,View Item,Download File,Request To Certify Item,Insert Index,Update Index,Delete Index,Certify Item,Reject Item,Request To Insert Account,Certify Account,Insert Group,Update Group,Delete Group,Insert Group Member,Delete Group Member,View Top Page,Quick Search,Advanced Search,Start SU,End SU' );
 define( '_MI_XOONIPS_EVENT_LOG_EVENT_COLUMNS','Event Type,Timestamp,Exec UID,Remote Host,Index ID,Item ID,File ID,UID,GID,Search Keyword,Login Name,Additional Information' );
 define( "_MD_XOONIPS_EVENT_LOG_00", "" );
 define( "_MD_XOONIPS_EVENT_LOG_10", "" );
@@ -470,11 +482,13 @@ define( '_MI_XOONIPS_ITEM_PANKUZU_CERTIFY_GROUP_ITEMS', 'グループ公開ア
 define( '_MI_XOONIPS_ITEM_PANKUZU_EDIT_ACCOUNT', 'プロフィールの編集' );
 define( '_MI_XOONIPS_ITEM_PANKUZU_VIEW_ACCOUNT', 'アカウント情報' );
 define( "_MI_XOONIPS_EVENT_LOG_PANKUZU", "イベントログ" );
+define( '_MI_XOONIPS_ITEM_PANKUZU_EDIT_CURRICULUM_VITAE', '略歴の編集' );
 
 //export/import
 define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT', 'エクスポート' );
 define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_CONFIG', 'エクスポート設定' );
 define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_LICENSE', '利用規約(ライセンス)' );
+define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_INDEX', 'インデックスをエクスポート' );
 define( '_MD_XOONIPS_EXPORT_CONFIG_TITLE', 'エクスポート設定' );
 define( '_MD_XOONIPS_EXPORT_CONFIG_SUBMIT', '次へ' );
 define( '_MD_XOONIPS_EXPORT_RECURSIVE', 'インデックスを再帰的にエクスポートする' );
@@ -490,6 +504,9 @@ define( '_MD_XOONIPS_EXPORT_NO_ITEMS_FOUND', '該当するアイテムはあり
 define( '_MD_XOONIPS_EXPORT_ACCEPT_ALL', 'すべてのライセンスに合意する' );
 define( '_MD_XOONIPS_EXPORT_EXPORT_ITEMS_EMPTY', 'Exportするアイテムが選択されていません．' );
 define( '_MD_XOONIPS_EXPORT_LICENSE_AGREEMENT_SUBMIT', 'ダウンロード' );
+define( '_MD_XOONIPS_EXPORT_EXPORT_INDEX', '以下の設定でインデックスをエクスポートします' );
+define( '_MD_XOONIPS_EXPORT_TYPE_ITEM', 'アイテムをエクスポートする' );
+define( '_MD_XOONIPS_EXPORT_TYPE_INDEX', 'インデックスツリーをエクスポートする' );
 define( '_MD_XOONIPS_IMPORT_TITLE', 'インポート' );
 define( '_MD_XOONIPS_IMPORT_FILE', 'Importするファイル' );
 define( '_MD_XOONIPS_IMPORT_INDEX', 'Import先インデックス' );
@@ -500,15 +517,48 @@ define( '_MD_XOONIPS_IMPORT_PANKUZU_RESOLVE_CONFLICT', '衝突の解決' );
 define( '_MD_XOONIPS_IMPORT_TITLE_RESOLVE_CONFLICT', '衝突の解決' );
 define( '_MD_XOONIPS_IMPORT_IMPORT_ALL', '全てインポート' );
 define( '_MD_XOONIPS_IMPORT_IMPORT_ITEM', 'インポートするアイテム' );
-define( '_MD_XOONIPS_IMPORT_FOLLOWING_ITEM_CONFLICT', '以下のアイテムのタイトルが重複しています' );
 define( '_MD_XOONIPS_IMPORT_PANKUZU_UPLOAD_FILE', 'ファイルアップロード' );
 define( '_MD_XOONIPS_IMPORT_IMPORT_SUCCESSFULLY', 'インポートを完了しました．' );
 define( '_MD_XOONIPS_IMPORT_NO_ITEMS_IMPORTED', 'インポートするアイテムがありません．' );
-define( '_MD_XOONIPS_IMPORT_INDEX_NUMBER_LIMIT_OVER_FLOW', 'これ以上アイテムをインポートできません．サイト管理者に連絡して下さい．' );
-define( '_MD_XOONIPS_IMPORT_ITEM_NUMBER_LIMIT_OVER_FLOW', 'これ以上インデックスをインポートできません．サイト管理者に連絡して下さい．' );
-define( '_MD_XOONIPS_IMPORT_RESOLVE_CONFLICT_SUBMIT', 'アップロード' );
+define( '_MD_XOONIPS_IMPORT_INDEX_NUMBER_LIMIT_OVER_FLOW', 'これ以上インデックスをインポートできません．サイト管理者に連絡して下さい．' );
+define( '_MD_XOONIPS_IMPORT_ITEM_NUMBER_LIMIT_OVER_FLOW', 'これ以上アイテムをインポートできません．サイト管理者に連絡して下さい．' );
+define( '_MD_XOONIPS_IMPORT_RESOLVE_CONFLICT_SUBMIT', '次へ' );
 define( '_MD_XOONIPS_IMPORT_UPLOAD_SUBMIT', '次へ' );
+define( '_MD_XOONIPS_IMPORT_PANKUZU_CHECK_LENGTH', '文字数超過のチェック' );
+define( '_MD_XOONIPS_IMPORT_TITLE_CHECK_LENGTH', '文字数超過のチェック' );
+define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_SUBMIT', 'アップロード' );
+define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_WARNING', '以下のアイテムは、文字数超過のため一部切り捨てられます(赤字の部分)．' );
+define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_NO_WARNING', '文字数が超過するアイテムはありません．' );
 define( '_MD_XOONIPS_IMPORT_INDEX_CANNOT_WRITE', '以下のインデックスは無視されます．インポートできるインデックスはあなたのプライベートインデックスのみです．' );
+define( '_MD_XOONIPS_IMPORT_IGNORE_CHECK', '衝突と文字数超過をチェックしない' );
+define( '_MD_XOONIPS_IMPORT_NO_STRINGS_ARE_TRIMMED', '文字数制限を越える文字列はありませんでした．' );
+define( '_MD_XOONIPS_IMPORT_NO_CONFLICT_ITEMS', '衝突するアイテムはありませんでした．' );
+define( '_MD_XOONIPS_IMPORT_NUMBER_OF_CONFLICT_ITEMS', '衝突するアイテムの数：' );
+define( '_MD_XOONIPS_IMPORT_FOLLOWING_ITEM_CONFLICT', '以下のアイテムが重複しています' );
+define( '_MD_XOONIPS_IMPORT_IMPORT_ALL_AS_NEW', "衝突する全てのアイテムを新しいアイテムとしてインポートする\n（上書きチェックボックスの指定を無視します）．" );
+define( '_MD_XOONIPS_IMPORT_IMPORT_MODIFY', 'インポート先インデックスにある以下の衝突アイテムを上書きする' );
+define( '_MD_XOONIPS_IMPORT_CONFLICT_ITEMS_IN_OTHER_INDEXES', '別のインデックスに以下の衝突アイテムがあります(上書きしません)' );
+define( '_MD_XOONIPS_CONFLICT_ITEMS_IN_THE_SAME_FILE', 'インポートファイル内に以下の衝突アイテムがあります' );
+define( '_MD_XOONIPS_IMPORT_IMPORT_CAN_NOT_MODIFY', '複数のアイテムと衝突するのでインポートできません' );
+define( '_MD_XOONIPS_IMPORT_LOGGING', 'ログを出力する' );
+define( '_MD_XOONIPS_IMPORT_ERROR', 'インポート処理中にエラーが発生しました．' );
+define( '_MD_XOONIPS_IMPORT_READY', 'インポートできます．' );
+define( '_MD_XOONIPS_IMPORT_NO_ERROR', 'エラーはありません．' );
+define( '_MD_XOONIPS_IMPORT_REVIEW_LOG', 'ログを確認してください．' );
+define( '_MD_XOONIPS_IMPORT_LOCAL_FILE', 'ローカルファイルをインポートする' );
+define( '_MD_XOONIPS_IMPORT_REMOTE_FILE', 'サーバ上のファイルをインポートする' );
+define( '_MD_XOONIPS_IMPORT_ERROR_CHECK_ONLY', 'エラーチェックだけを行う' );
+define( '_MD_XOONIPS_IMPORT_CONTRIBUTOR_SELECT', '指定ユーザの権限でインポートする' );
+define( '_MD_XOONIPS_IMPORT_ERROR_CKECK_DONE', 'エラーチェックを完了しました．' );
+define( '_MD_XOONIPS_IMPORT_INDEX_TREE_CREATED', '以下のインデックスツリーをインポートしました（リスト中の既存の同名インデックスの内容は変更されていません）．' );
+define( '_MD_XOONIPS_IMPORT_INDEX_TREE_FAILED', 'インデックスツリーのインポートに失敗しました' );
+define( '_MD_XOONIPS_IMPORT_FILE_NOT_FOUND', 'インポートファイルが見つかりません．' );
+define( '_MD_XOONIPS_IMPORT_FILE_NOT_SPECIFIED', 'インポートファイルが指定されていません．' );
+define( '_MD_XOONIPS_IMPORT_CERTIFY_AUTO', '公開インデックスに登録するアイテムを自動承認する' );
+define( '_MD_XOONIPS_IMPORT_NO_ITEMS_ARE_FOUND', 'インポートするアイテムが見つかりませんでした．インポートファイルの内容を確認してください．' );
+define( '_MD_XOONIPS_IMPORT_FOLLOWING_INDEX', '以下のインデックスをインポートします．' );
+define( '_MD_XOONIPS_IMPORT_FOLLOWING_INDEX_TEST', '以下のインデックスをインポートできます．' );
+define( '_MD_XOONIPS_IMPORT_CIRCULAR_INDEX', 'インデックスが循環構造を持っているため、インポートできません．' );
 
 define( '_MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE', 'RSSのファイルパス' );
 define( '_MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE_NOT_WRITABLE_ERROR', '書き込みできません．'._MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE.'を確認してください' );
@@ -519,11 +569,11 @@ define( '_MD_XOONIPS_EVENT_ITEM_IS_SHOWN_IN', 'アイテムが以下のインデ
 define( '_MD_XOONIPS_EVENT_NEW_GROUP', '新しいグループが作成されました' );
 
 define( '_MD_XOONIPS_ITEM_LANG_LABEL', '言語' );
-define( '_MD_XOONIPS_ITEM_LANG_OPTION_IDS', 'eng,jpn,fra,deu,esl,ita,dut,sve,nor,dan,fin,por,chi,kor,mul' );
-define( '_MD_XOONIPS_ITEM_LANG_OPTION_NAMES', '英語,日本語,フランス語,ドイツ語,スペイン語,イタリア語,オランダ語,スウェーデン語,ノルウェー語,デンマーク語,フィンランド語,ポルトガル語,中国語,韓国語,多言語' );
+define( '_MD_XOONIPS_ITEM_LANG_OPTION_IDS', 'eng,jpn,fra,deu,esl,ita,dut,sve,nor,dan,fin,por,chi,kor' );
+define( '_MD_XOONIPS_ITEM_LANG_OPTION_NAMES', '英語,日本語,フランス語,ドイツ語,スペイン語,イタリア語,オランダ語,スウェーデン語,ノルウェー語,デンマーク語,フィンランド語,ポルトガル語,中国語,韓国語' );
 
 
-define( '_MD_XOONIPS_DOWNLOAD_LIMITATION_OPTION_LABEL', 'ダウンロード制限オプション' );
+define( '_MD_XOONIPS_DOWNLOAD_LIMITATION_OPTION_LABEL', 'ダウンロード制限' );
 define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION', 'ダウンロードファイルオプション' );
 define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION_YES', 'メタデータとZIP（推奨）' );
 define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION_NO' , '圧縮なし' );
@@ -549,7 +599,127 @@ define( '_MD_XOONIPS_REPOSITORY_PUBLISHER_NONE', '使用しない' );
 define( '_MD_XOONIPS_OAIPMH_CONFIG', 'OAI-PMHの設定' );
 define( '_MD_XOONIPS_OAIPMH_CONFIG_REPOSITORIES', 'ハーベストするリポジトリのURL(リポジトリごとに改行)' );
 define( '_MD_XOONIPS_OAIPMH_CONFIG_LOGS', '最後にハーベストしたときの結果(この項目は編集できません)' );
+define( '_MD_XOONIPS_OAIPMH_HARVESTING', 'ハーベストする' );
+define( '_MD_XOONIPS_OAIPMH_HARVESTING_EXPLAIN', 'いますぐハーベストするにはこのボタンを押してください' );
+define( '_MD_XOONIPS_OAIPMH_HARVEST_RESULT', 'ハーベスト結果' );
+define( '_MD_XOONIPS_BACK_TO_OAIPMH_CONFIGURATION', _MD_XOONIPS_OAIPMH_CONFIG.'に戻る' );
 
 define( '_MD_XOONIPS_METADATA_SEARCH_LABEL', 'メタデータ検索' );
 
+define( '_MD_XOONIPS_FILESEARCH', 'ファイル検索' );
+define( '_MD_XOONIPS_FILESEARCH_NAME', 'モジュール名' );
+define( '_MD_XOONIPS_FILESEARCH_VERSION', 'バージョン' );
+define( '_MD_XOONIPS_FILESEARCH_RESCAN', '全てのファイルを再スキャン' );
+
+// labels for item_show (edit)
+define( '_MD_XOONIPS_ITEMSHOW_CURRICULUM_VITAE', '略歴' );
+define( '_MD_XOONIPS_ITEM_SHOW_OPTIONAL_TITLE', '公開領域にある全てのアイテムから業績アイテムを選択する<br />（いいえ：ユーザ本人が登録したアイテムから選択可能）' );
+define( '_MD_XOONIPS_ITEM_SHOW_EDIT_TITLE', '業績アイテム選択' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_PREV', '前へ' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_NEXT', '次へ' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_CHECK', 'チェック' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_ITEMS', 'アイテム' );
+define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_SUBMIT', '変更' );
+define( '_MD_XOONIPS_NEED_LOGIN', 'ログインすると業績の閲覧ができます' );
+
+// admin/posi_order.php
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_TITLE', '職名表示順設定' );
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_EXPLAIN', '表示順の値が０未満ならその職名は画面に表示されません' );
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_POSI_LABEL', '職名' );
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_ORDER_LABEL', '表示順' );
+define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_CHECK_LABEL', '削除チェック' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_TITLE', '職名追加フォーム' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_EXPLAIN', '表示順が空欄なら０を設定します' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_LABEL', '職名追加' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_POSITITLE_LABEL', '職名' );
+define( '_MD_XOONIPS_POSIORDER_ADDPOSI_POSIORDER_LABEL', '表示順' );
+define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_TITLE', 'ユーザ表示順設定' );
+define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_EXPLAIN', '表示順の値が０未満ならそのユーザは画面に表示されません' );
+define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_LABEL', '職名 [ ユーザ名 ]' );
+
+// labels of userlists, showusers
+define( '_MD_XOONIPS_USERLIST_TITLE', 'ユーザ一覧' );
+define( '_MD_XOONIPS_USERLIST_EXPLANATION', 'ユーザ名をクリックすると各ユーザの情報を表示します' );
+
+define( '_MD_XOONIPS_SHOW_USER_TITLE', 'ユーザ情報' );
+define( '_MD_XOONIPS_SEND_MESSAGE', 'メッセージ送信' );
+define( '_MD_XOONIPS_SHOW_CV_LABEL', '略歴' );
+define( '_MD_XOONIPS_SHOW_PUBILICATION_LIST', '業績リスト' );
+define( '_MD_XOONIPS_SHOW_BACKTOLIST_LABEL', '戻る' );
+define( '_MD_XOONIPS_VIEW_USER_ACCOUNT', 'アカウント確認' );
+define( '_MD_XOONIPS_EDIT_LISTS', '編集' );
+define( '_MD_XOONIPS_ORDER_CHANGE', '表示順変更' );
+
+define( '_MD_XOONIPS_UPLOAD_MAX_FILESIZE', '最大ファイルサイズ:' );
+define( '_MD_XOONIPS_UPLOAD_ERR_OK', 'アップロード成功' );
+define( '_MD_XOONIPS_UPLOAD_ERR_INI_SIZE', 'ファイルサイズが大きすぎます( upload_max_filesize )' );
+define( '_MD_XOONIPS_UPLOAD_ERR_FORM_SIZE', 'ファイルサイズが大きすぎます( MAX_FILE_SIZE )' );
+define( '_MD_XOONIPS_UPLOAD_ERR_PARTIAL', 'ファイルの一部しかアップされませんでした' );
+define( '_MD_XOONIPS_UPLOAD_ERR_NO_FILE', 'ファイルはアップロードされませんでした' );
+define( '_MD_XOONIPS_UPLOAD_ERR_NO_TMP_DIR', 'テンポラリフォルダが見付かりません' );
+define( '_MD_XOONIPS_UPLOAD_ERR_CANT_WRITE', 'ディスクに書き込み出来ませんでした' );
+
+// labels for edit curriculum vitae, publication list
+define( '_MD_XOONIPS_EDIT_CV_TITLE', '略歴の編集' );
+define( '_MD_XOONIPS_EDIT_CURRICULUM_VITAE', '略歴編集' );
+define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE_LABEL', '略歴追加' );
+define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE_WARNING', '項目を入力してください' );
+define( '_MD_XOONIPS_CURRICULUM_VITAE_FROM', 'From' );
+define( '_MD_XOONIPS_CURRICULUM_VITAE_TO', 'To' );
+define( '_MD_XOONIPS_CURRICULUM_VITAE_TITLE', '項目' );
+define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE', '追加' );
+define( '_MD_XOONIPS_MODIFY_CURRICULUM_VITAE_LABEL', '略歴編集' );
+define( '_MD_XOONIPS_NO_CURRICULUM_VITAE_DATA', '略歴データは登録されていません' );
+define( "_MD_XOONIPS_CURRICULUM_VITAE_BUTTON_EDIT", "変更");
+define( '_MD_XOONIPS_CURRICULUM_VITAE_CHECK_INFO', 'ユーザ情報へ戻る' );
+define( '_MD_XOONIPS_CURRICULUM_VITAE_INSERT', '略歴データを追加します' );
+define( '_MD_XOONIPS_NO_PUBLICATION_ITEM_DATA', '業績リストにアイテムが登録されていません．' );
+define( '_MD_XOONIPS_PUBLICATION_ITEM_CHANGE', '業績表示順変更' );
+define( '_MD_XOONIPS_PUBLICATION_ITEM_INSERT', '業績リストを編集しています' );
+
+define( '_MD_XOONIPS_RANKING_UP', '▲' );
+define( '_MD_XOONIPS_RANKING_DOWN', '▼' );
+define( '_MD_XOONIPS_RANKING_NUM_ROWS_1', '各ランキングの上位' );
+define( '_MD_XOONIPS_RANKING_NUM_ROWS_2', '件を表示します．' );
+define( '_MD_XOONIPS_RANKING_DAYS_1', '過去' );
+define( '_MD_XOONIPS_RANKING_DAYS_2', '日間のデータのみをランキング対象とします．<br />この指定をONにした場合，集計値ファイルの値はランキングに反映されません．' );
+
+define( '_MD_XOONIPS_RANKING_WHAT_DELETING_LOG_IS', '※ ログを消去するとランキングがクリアされます．<br />それを避けるには，ログ消去の前後で集計値ファイルのダウンロード・アップロードを行ってください．' );
+define( '_MD_XOONIPS_RANKING_FILE_CONFIG_EXPLAIN', '集計値のアップロード・ダウンロードを行います' );
+define( '_MD_XOONIPS_RANKING_DOWNLOAD_FILE', 'ダウンロード' );
+define( '_MD_XOONIPS_RANKING_UPLOAD_FILE', 'アップロード' );
+define( '_MD_XOONIPS_RANKING_CLEAR', 'クリアする' );
+
+define( '_MD_XOONIPS_RANKING_LABEL', 'ランキング用ブロック' );
+define( '_MD_XOONIPS_RANKING_NEW_LABEL', '新着ランキング用ブロック' );
+define( '_MD_XOONIPS_RANKING_CHECK_RANKING_LABEL', '表示するランキングを選択してください(複数チェック可)' );
+define( '_MD_XOONIPS_RANKING_LOCKED', '現在集計中です．数秒待ってからリトライしてください．' );
+
+define("_MI_XOONIPS_RANKING_CONFIG", "ランキング設定"); 
+define("_MI_XOONIPS_RANKING_FILE_CONFIG", "ランキング集計ファイル設定"); 
+define("_MD_XOONIPS_RANKING_VISIBLE", "表示する"); 
+define("_MD_XOONIPS_RANKING_NAME", "表示内容"); 
+
+define("_MD_XOONIPS_RANKING_DOWNLOAD_LABEL", "ダウンロードするファイル名"); 
+define("_MD_XOONIPS_RANKING_UPLOAD_LABEL", "アップロードするファイル"); 
+define("_MD_XOONIPS_RANKING_CLEAR_SOME_LABEL", "%s ～ %s の集計値を持っています"); 
+define("_MD_XOONIPS_RANKING_CLEAR_EMPTY_LABEL", "集計値はありません"); 
+define("_MD_XOONIPS_RANKING_CLEAR_LABEL", "集計値のクリア"); 
+
+// admin/itemtype_order.php
+define("_MD_XOONIPS_ITEMTYPE_CONFIGURATION_LABEL", "アイテムタイプ設定");
+define("_MD_XOONIPS_ITEMTYPE_ORDER_SELECT_LABEL", "アイテムタイプ表示順変更");
+define("_MD_XOONIPS_ITEMTYPE_ORDER_SELECT_EXPLAIN", "表示順は1以上の整数を指定してください．");
+
+define("_MD_XOONIPS_SU_TITLE", "suの開始");
+define("_MD_XOONIPS_SU_TARGET_USER", "アカウントの切り替え先");
+define("_MD_XOONIPS_SU_ADMIN_PASSWORD", "あなたのパスワード");
+define("_MD_XOONIPS_SU_OK", "OK");
+define("_MD_XOONIPS_SU_CANNOT_LOGOUT", "ログアウトする前にsuを終了してください．");
+
+define("_MD_XOONIPS_SU_START", "アカウントを切り替えています");
+define("_MD_XOONIPS_SU_FAIL", "パスワードが異なります");
+define("_MD_XOONIPS_SU_END", "管理者に戻ります");
+define("_MD_XOONIPS_SU_EXPLAIN", "一時的に他ユーザのアカウントで作業することができます．");
+
 ?>
