@@ -1,5 +1,5 @@
 <?php
-//  $Revision: 1.13.2.5 $                                                                  //
+//  $Revision: 1.20 $                                                                  //
 //  --------------------------------------------------------------------------  //
 //  XooNIps Xoops modules for Neuroinformatics Platforms                        //
 //  Copyright (C) 2005 RIKEN, Japan. All rights reserved.                       //
@@ -29,36 +29,31 @@ require_once 'include/create_session.php';
 xnp_load_init_create_session();
 $xnpsid = $_SESSION['XNPSID'];
 
-// If not a user, redirect
-if( $xnpsid != 0 ){
-    if ( !$xoopsUser ) {
-        redirect_header(XOOPS_URL.'/index.php',3,_MD_XOONIPS_ITEM_FORBIDDEN);
-        exit();
-    }
 
+if( isset( $_SESSION['xoopsUserId'] ) ){
     $uid = $_SESSION['xoopsUserId'];
-
-//Uncertified user can't access(except XOOPS administrator).
-    if( !$xoopsUser->isAdmin( $xoopsModule->getVar('mid') )
-        && !xnp_is_activated( $xnpsid, $uid ) ){
-        redirect_header(XOOPS_URL.'/index.php', 3, _MD_XOONIPS_MODERATOR_NOT_ACTIVATED);
-        exit();
-    }
 }
-else {
+
+// If not a user, redirect
+if ( !$xoopsUser ) {
     if( !xnp_is_valid_session_id($xnpsid) ){
         // User is guest group, and guest isn't admitted to access the page.
         redirect_header(XOOPS_URL.'/index.php',3,_MD_XOONIPS_ITEM_FORBIDDEN);
         exit();
     }
     $uid = UID_GUEST;
+}else if( $xoopsUser && !$xoopsUser->isAdmin( $xoopsModule->getVar('mid') )
+	&& !xnp_is_activated( $xnpsid, $uid ) ){
+    //̤ǧΥ桼ѤǤʤ(XOOPSԤ)
+  	redirect_header('index.php', 3, _MD_XOONIPS_MODERATOR_NOT_ACTIVATED);
+  	exit();
+}else{
+    $uid = $_SESSION['xoopsUserId'];
 }
+
 $config_handler =& xoops_gethandler('config');
 $xoopsConfigUser =& $config_handler->getConfigsByCat(XOOPS_CONF_USER);
 
-
-
-
 if( isset( $_GET['num_of_items'] ) ){
     $num_of_items = $_GET['num_of_items'];
 }else if( isset( $_POST['num_of_items'] ) ){
@@ -98,15 +93,50 @@ $_SESSION['xoonips_order_dir'] = $order_dir;
 
 if( $op == 'add_selected_item' ){
     list( $page, $itemcount, $orderby, $index_id ) = explode( ',', $add_to_index );
-    
+
+    $uid_list = array(); // uid(s) who receive notification.
     $add_item_ids = array_diff( $selected, $initially_selected );
     $del_item_ids = array_diff( $initially_selected, $selected );
     
     $is_private = true;
     $index = array();
     $result = xnp_get_index( $xnpsid, $index_id, $index );
-    if ( $result == RES_OK && $index['open_level'] != OL_PRIVATE )
-        $is_private = false;
+    if ( $result != RES_OK ){
+        redirect_header('index.php', 3, "ERROR xnp_get_index (result=$result index_id=$index_id)" );
+    }
+    $is_private = ( $index['open_level'] == OL_PRIVATE );
+    
+    if( !$is_private ){
+        // 
+        // get uid(s) to notice
+        // 
+        if( $index['open_level'] == OL_GROUP_ONLY ){
+            $uids = array();
+            $result = xnp_dump_group_admins( $xnpsid, $index['owner_gid'], array(), $uids );
+            if( $result == RES_OK ){
+                foreach( $uids as $id ){
+                    $user = array();
+                    $result = xnp_get_account( $xnpsid, $id, $user );
+                    if( $result == RES_OK ){
+                        $uid_list[] = $user['uid'];
+                    }
+                }
+            }
+        }else if( $index['open_level'] == OL_PUBLIC ){
+            $uids = array();
+            if( xnp_dump_uids( $xnpsid, array(), $uids ) == RES_OK ){
+                foreach( $uids as $uid ){
+                    if( xnp_is_moderator( $xnpsid, $uid ) ){
+                        $user = array();
+                        $result = xnp_get_account( $xnpsid, $uid, $user );
+                        if( $result == RES_OK ){
+                            $uid_list[] = $user['uid'];
+                        }
+                    }
+                }
+            }
+        }
+    }
     
     $changelog = sprintf( _MD_XOONIPS_ITEM_CHANGE_LOG_AUTOFILL_TEXT, 
                            implode( _MD_XOONIPS_ITEM_CHANGE_LOG_AUTOFILL_DELIMITER, array(_MD_XOONIPS_ITEM_INDEX_LABEL) ) );
@@ -118,8 +148,6 @@ if( $op == 'add_selected_item' ){
         $certify_item = 'on';
     }
     
-    $moderator_emails = xnpGetModeratorEmails( $xnpsid );
-    
     // add selected item into index
     foreach ( $add_item_ids as $item_id ){
         // can't add items when the item is certified already or is in pending state.
@@ -134,17 +162,33 @@ if( $op == 'add_selected_item' ){
         // add
         $result = xnp_register_item( $xnpsid, $index_id, $item_id );
         if ( $result != RES_OK ){
-            echo "cannot add item to index. item_id=$item_id, index_id=$index_id result=$result <br />\n";
-            echo xnp_get_last_error_string();
-            //redirect_header(XOOPS_URL.'/index.php', 3, "ERROR xnp_get_item_types [AbstractLayer]".xnp_get_last_error_string());
-            break;
+            redirect_header('index.php', 3, "ERROR xnp_register_item(result=$result item_id=$item_id index_id=$index_id)" );
         }
         else {
             xnp_insert_change_log( $xnpsid, $item_id, $changelog );
             xnp_insert_event( $xnpsid, ETID_UPDATE_ITEM, time(), $uid, xnpGetRemoteHost(), array( 'item_id' => $item_id ) );
-            
             if ( !$is_private ){
-                xnpRequestCertifyNotify( $xnpsid, $index_id, $item_id, $certify_item, $moderator_emails );
+                $certify_item = '';
+                $result = xnp_get_config_value( 'certify_item', $certify_item );
+                if( $result != RES_OK ){
+                    redirect_header('index.php', 3, "ERROR xnp_get_config_value can't get certify_item(result=$result)");
+                }
+                if ( $certify_item == 'auto' ){
+                    // record events(certify item)
+                    xnp_insert_event( $xnpsid, ETID_CERTIFY_ITEM, time(), $uid, xnpGetRemoteHost(), array( 'item_id' => $item_id, 'index_id'=>$index_id ) );
+                    xnpGenerateRss( ); //update RSS
+                }
+                else if ( $certify_item == 'on' ){
+                    global $xoopsModule;
+                    $notification_handler =& xoops_gethandler('notification');
+                    //define tags here for notification message
+                    $tags = array();
+                    $tags['ITEM_URL'] = XOOPS_URL . '/modules/' . $xoopsModule->dirname() . "/detail.php?item_id=${item_id}";
+                    $tags['CERTIFY_URL'] = XOOPS_URL . '/modules/' . $xoopsModule->dirname() . "/certify.php";
+                    $tags['INDEX'] = xnpGetIndexPathString( $xnpsid, $index_id );
+                    $notification_handler =& xoops_gethandler('notification');
+                    $result = $notification_handler->triggerEvent('administrator', 0, 'item_certify_request', $tags, $uid_list);
+                }
             }
         }
     }
@@ -175,7 +219,7 @@ if( $op == 'add_selected_item' ){
                 if ( $result != RES_OK ){
                     echo "cannot del item from index. item_id=$item_id, index_id=$index_id result=$result <br />\n";
                     echo xnp_get_last_error_string();
-                    //redirect_header(XOOPS_URL.'/index.php', 3, "ERROR xnp_get_item_types [AbstractLayer]".xnp_get_last_error_string());
+                    //redirect_header(XOOPS_URL.'/index.php', 3, "ERROR xnp_get_item_types ".xnp_get_last_error_string());
                     break;
                 }
                 else {
@@ -192,7 +236,7 @@ if( $op == 'add_selected_item' ){
 $itemtypes = array();
 $tmp = array();
 if( xnp_get_item_types( $tmp ) != RES_OK ){
-    redirect_header(XOOPS_URL.'/index.php', 3, "ERROR xnp_get_item_types [AbstractLayer]".xnp_get_last_error_string());
+    redirect_header(XOOPS_URL.'/index.php', 3, "ERROR xnp_get_item_types ".xnp_get_last_error_string());
     break;
 }else{
     foreach( $tmp as $i){
@@ -217,10 +261,11 @@ $xoopsTpl->assign('order_by_label', _MD_XOONIPS_ITEM_ORDER_BY );
 $xoopsTpl->assign('item_count_label', _MD_XOONIPS_ITEM_NUM_OF_ITEM_PER_PAGE );
 //order_by_select: array( "variable name" => "name for view", ... )
 $xoopsTpl->assign("order_by_select",
-                  array( "title"=>"Title",
-                         "last_update_date"=>"Modification Date",
-                         "creation_date" => "Contribution Date",
-                         "publication_date"=>"Date" ) );
+                  array( "title"=>_MD_XOONIPS_ITEM_TITLE_LABEL,
+                         "doi"=>_MD_XOONIPS_ITEM_DOI_LABEL,
+                         "last_update_date"=>_MD_XOONIPS_ITEM_LAST_UPDATE_DATE_LABEL,
+                         "creation_date" => _MD_XOONIPS_ITEM_CREATION_DATE_LABEL,
+                         "publication_date"=>_MD_XOONIPS_ITEM_PUBLICATION_DATE_LABEL ) );
 $xoopsTpl->assign('item_count_select',
                   array( "20", "50", "100" ) );
 if ( $op != 'add_selected_item' ){
@@ -245,13 +290,13 @@ if( $orderby == 'publication_date' ){
 if( isset( $index_id ) ){
     if( !isset( $num_of_items ) ){
         if( xnp_get_item_id_by_index_id( $xnpsid, $index_id, array(), $iids ) != RES_OK ){
-            redirect_header(XOOPS_URL.'/index.php',3,"ERROR [AbstractLayer]".xnp_get_last_error_string());
+            redirect_header(XOOPS_URL.'/index.php',3,"ERROR ".xnp_get_last_error_string());
             break;
         }
         $num_of_items = count( $iids );
     }
     if( xnp_get_item_id_by_index_id( $xnpsid, $index_id, $cri, $iids ) != RES_OK ){
-        redirect_header(XOOPS_URL.'/index.php',3,"ERROR [AbstractLayer]".xnp_get_last_error_string());
+        redirect_header(XOOPS_URL.'/index.php',3,"ERROR ".xnp_get_last_error_string());
         break;
     }
 }else{
@@ -261,7 +306,7 @@ if( isset( $index_id ) ){
 
 	$ret = xnp_dump_item_id( $xnpsid, $cri, $iids );
     if( $ret != RES_OK ){
-        redirect_header(XOOPS_URL.'/index.php',3,"ERROR [AbstractLayer]".xnp_get_last_error_string());
+        redirect_header(XOOPS_URL.'/index.php',3,"ERROR ".xnp_get_last_error_string());
         break;
     }
 }
@@ -274,9 +319,9 @@ if( isset( $index_id ) ){
         // get $index
         $index = array();
         $result = xnp_get_index( $xnpsid, $p_xid, $index );
-        if ( $result != 0 ){
-            redirect_header(XOOPS_URL.'/index.php',3,"ERROR [AbstractLayer]".xnp_get_last_error_string());
-            break;
+        if ( $result != RES_OK ){
+            redirect_header(XOOPS_URL.'/index.php',3,"ERROR ".xnp_get_last_error_string());
+            exit();
         }
         $dirArray[] = $index;
     }
@@ -287,7 +332,7 @@ if( isset( $index_id ) ){
     $index = array();
     $result = xnp_get_index( $xnpsid, $index_id, $index );
     if ( $result != RES_OK ){
-        redirect_header(XOOPS_URL.'/index.php',3,"ERROR [AbstractLayer]".xnp_get_last_error_string());
+        redirect_header(XOOPS_URL.'/index.php',3,"ERROR ".xnp_get_last_error_string());
         break;
     }
     if ( $index['open_level'] == OL_PRIVATE && $index['owner_uid'] == $uid ||
@@ -301,6 +346,20 @@ if( isset( $index_id ) ){
 $pages = array( min( max( 1, $page - 4 ), max( 1, ceil( $num_of_items / $itemcount ) - 9 ) ) );
 for( $i = $pages[0] + 1; $i <= min( 10, ceil( $num_of_items / $itemcount ) ); $i++ ){ $pages[] = $i; }
 
+$page_no_label = min( ( $page - 1 ) * $itemcount + 1, $num_of_items )
+	." - ".min($page * $itemcount, $num_of_items )
+	." of ".$num_of_items." Items" ;
+if( $num_of_items == 0 ) {
+	$result = xnp_get_indexes( $xnpsid, $index_id, array(), $child_index);
+	if ( $result != RES_OK ){
+		redirect_header(XOOPS_URL.'/listitem.php',3,"ERROR ".xnp_get_last_error_string());
+		break;
+	}
+	if( $child_index != NULL ){
+		$page_no_label .= "<br><br>"._MI_XOONIPS_ITEM_NO_ITEM_LISTED;
+	}
+ }
+
 $xoopsTpl->assign('pages', $pages );
 
 $xoopsTpl->assign('prevpage', $page - 1 );
@@ -311,15 +370,12 @@ $xoopsTpl->assign('order_dir', $order_dir);
 $xoopsTpl->assign('page', $page);
 $xoopsTpl->assign('itemcount', $itemcount);
 $xoopsTpl->assign('num_of_items', $num_of_items);
-$xoopsTpl->assign('page_no_label',
-                  min( ( $page - 1 ) * $itemcount + 1, $num_of_items )
-                  ." - ".min($page * $itemcount, $num_of_items )
-                  ." of ".$num_of_items." Items" );
+$xoopsTpl->assign('page_no_label', $page_no_label);
 
 // retrieve items
 // ignore 'start' and 'rows' of criteria because already truncated by dump_item_id
 if( xnp_get_items( $xnpsid, $iids, array( 'orders' => $cri['orders'] ), $items ) != RES_OK ){
-    redirect_header(XOOPS_URL.'/index.php', 3, "ERROR [AbstractLayer]".xnp_get_last_error_string());
+    redirect_header(XOOPS_URL.'/index.php', 3, "ERROR ".xnp_get_last_error_string());
     break;
 }
 
@@ -357,7 +413,7 @@ if( xnp_is_moderator( $xnpsid, $uid ) ){
         $index = array();
         $result = xnp_get_index( $xnpsid, $index_id, $index );
         if ( $result != RES_OK ){
-            redirect_header(XOOPS_URL.'/index.php',3,"ERROR [AbstractLayer]".xnp_get_last_error_string());
+            redirect_header(XOOPS_URL.'/index.php',3,"ERROR ".xnp_get_last_error_string());
             break;
         }
         if( $index['open_level'] == OL_PRIVATE && $index['owner_uid'] == $uid ||
