@@ -1,6 +1,6 @@
 <?php
 //  definition of class for OAI-PMH
-//  $Revision: 1.25.2.3 $                                                                  //
+//  $Revision: 1.31.2.2 $                                                                  //
 //  --------------------------------------------------------------------------  //
 //  XooNIps Xoops modules for Neuroinformatics Platforms                        //
 //  Copyright (C) 2005 RIKEN, Japan. All rights reserved.                       //
@@ -21,7 +21,7 @@
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. //
 //  --------------------------------------------------------------------------  //
 
-include_once "../../mainfile.php";
+include_once XOOPS_ROOT_PATH."/mainfile.php";
 
 $config_handler =& xoops_gethandler('config');
 $xoopsConfig =& $config_handler->getConfigsByCat(XOOPS_CONF);
@@ -34,6 +34,7 @@ if ( file_exists(XOOPS_ROOT_PATH."/language/$language/global.php") ) {
 }
 
 include_once XOOPS_ROOT_PATH.'/modules/xoonips/include/encode.php';
+include_once XOOPS_ROOT_PATH.'/modules/xoonips/include/lib.php';
 
 class OAIPMH {
 
@@ -412,6 +413,7 @@ class OAIPMHHarvester {
 				if( $this->ListMetadataFormats( ) ) {
 					$args = array( 'metadataPrefix' => $this->metadataPrefix );
 					$sql = "SELECT last_success_date FROM ${tbl_repositories} WHERE URL='".$ts->addSlashes( $this->baseURL )."'";
+
 					$result = $xoopsDB->query( $sql );
 					if( $result && $xoopsDB->getRowsNum( $result ) > 0 ) {
 						list( $from_timestamp ) = $xoopsDB->fetchRow( $result );
@@ -686,7 +688,10 @@ class ListMetadataFormatsHandler extends HarvesterHandler {
 
 	function characterDataHandler( $parser, $data ) {
 		if( end( $this->tagstack ) == 'METADATAPREFIX' ) {
-			if( $data == "junii" ) {
+			if( $data == "junii" && $this->metadataPrefix == "oai_dc") {
+				$this->metadataPrefix = $data;
+			}
+			else if( $data == "junii2" ) {
 				$this->metadataPrefix = $data;
 			}
 		}
@@ -753,7 +758,6 @@ class ListRecordsHandler extends HarvesterHandler {
 	}
 
 	function endElementHandler( $parser, $name ) {
-
 		array_push( $this->search_text, ' ' );
 		if( isset( $this->tagstack[2] ) && $this->tagstack[2] == 'RECORD' )
 			array_push( $this->metadata, "</".strtolower( $name ).">" );
@@ -774,8 +778,17 @@ class ListRecordsHandler extends HarvesterHandler {
 				$result = $xoopsDB->query( $sql );
 				list( $id ) = $xoopsDB->fetchRow( $result );
 				if( $id ) {
-					$this->search_text = array_unique( $this->search_text );
-					array_walk( $this -> search_text, 'array_walk_bin2hex' );
+					$str = implode( '', $this->search_text );
+					
+					if (xnpChkServerLang()){
+						$str = encodeMeta2Server( $str ); // UTF8 -> EUC + numeric
+					}
+					else {
+						$str = encodeMeta2Server( $str ); // UTF8 -> ASCII + numeric
+						$str = xnpNumeric2ISO_8859_1( $str ); // numeric -> latin1
+					}
+					
+					$this->search_text = xnpWordSeparation( $str );
 					//insert data into metadata table
 /*
 					$values = array( $ts->addSlashes( $this->identifier ),
@@ -785,12 +798,20 @@ class ListRecordsHandler extends HarvesterHandler {
 									 $ts->addSlashes( implode( '', $this->metadata ) ),
 									 $ts->addSlashes( implode( ' ', $this->search_text ) ) );
 */
-					$values = array( addslashes( encodeMeta2Server( $this->identifier ) ),
+					$enc = array();
+					$enc['identifier'    ] = addslashes( encodeMeta2Server( $this->identifier     ) );
+					$enc['metadataPrefix'] = addslashes( encodeMeta2Server( $this->metadataPrefix ) );
+					$enc['metadata'      ] = addslashes( encodeMeta2Server( implode( '', $this->metadata ) ) );
+					$enc['search_text'   ] = addslashes( encodeMeta2Server( implode( ' ', $this->search_text ) ) );
+					$enc['title'         ] = addslashes( encodeMeta2Server( $this->title ) );
+					
+					$values = array( $enc['identifier'     ],
 									 $id,
-									 addslashes( encodeMeta2Server( $this->metadataPrefix ) ),
-									 addslashes( encodeMeta2Server( $this->title ) ),
-									 addslashes( encodeMeta2Server( implode( '', $this->metadata ) ) ),
-									 addslashes( encodeMeta2Server( implode( ' ', $this->search_text ) ) ) ); 
+									 $enc['metadataPrefix' ],
+									 $enc['title'          ],
+									 $enc['metadata'       ],
+									 $enc['search_text'    ] ); 
+		
 					$sql = "INSERT INTO ${tbl_metadata} (identifier, repository_id, format, title, metadata, search_text) VALUES ('".implode( "', '", $values )."')";
 					$result = $xoopsDB->queryF( $sql );
 					if( !$result && $xoopsDB->errno( ) == 1062 ) {	//1062: Can't write; duplicate key in table '%s' 
@@ -800,10 +821,10 @@ class ListRecordsHandler extends HarvesterHandler {
 										 'metadata' => $ts->addSlashes( implode( '', $this->metadata ) ),
 										 'search_text' => $ts->addSlashes( implode( ' ', $this->search_text ) ) );
 */
-						$update = array( 'title' => addslashes( encodeMeta2Server( $this->title ) ),
-										 'format' => addslashes( encodeMeta2Server( $this->metadataPrefix ) ),
-										 'metadata' => addslashes( encodeMeta2Server( implode( '', $this->metadata ) ) ),
-										 'search_text' => addslashes( encodeMeta2Server( implode( ' ', $this->search_text ) ) ) );
+						$update = array( 'title'       => $enc['title'         ],
+										 'format'      => $enc['metadataPrefix'],
+										 'metadata'    => $enc['metadata'      ],
+										 'search_text' => $enc['search_text'   ] );
 						$sql = "UPDATE ${tbl_metadata} SET ";
 						$update2 = array( );
 						foreach( $update as $k => $v ) $update2[] = "${k}='${v}'";
@@ -826,7 +847,6 @@ class ListRecordsHandler extends HarvesterHandler {
 		}
 		if( end( $this->tagstack ) == 'IDENTIFIER' && prev( $this->tagstack ) == 'HEADER' ) {
 			$this->identifier = $data;
-			echo "${data}\n";
 		}
 
 		//<xxx:title> -> <title>
@@ -840,8 +860,7 @@ class ListRecordsHandler extends HarvesterHandler {
 			return;
 		// $data: unhtmlspecialchars() in characterDataHandler => to get back to XML, we need to do htmlspecialchars().
 		array_push( $this->metadata, htmlspecialchars($data, ENT_QUOTES) );
-		array_push( $this->search_text, $data );
-		$this->search_text = array_merge( $this->search_text, $this -> word_separation( $data ) );
+		$this->search_text[] = $data;
 	}
 
 	function getResumptionToken( ) {
@@ -850,105 +869,8 @@ class ListRecordsHandler extends HarvesterHandler {
 	function getIdentifier( ) {
 		return $this->identifier;
 	}
-
-	//private 
-	function utf8bytes( $c1 ){
-		if( ( $c1 & 0x80 ) == 0 ) return 1;
-		if( ( $c1 & 0xe0 ) == 0xc0 ) return 2;
-		if( ( $c1 & 0xe0 ) == 0xe0 ) return 3;
-		if( ( $c1 & 0xf8 ) == 0xf0 ) return 4;
-		return 0;
-	}
-
-	function window( $bytes ){
-		$length = 8;
-		$ret = array();
-		$word = array();
-		$len = 0;
-
-		for( $len = 0; $len < $length && count( $bytes ) > 0 ; $len++ ){
-			$c1 = reset( $bytes );
-			for( $i = 0; $i < $this -> utf8bytes( $c1 ); $i++ ){
-				array_push( $word, pack( "C", array_shift( $bytes ) ) );
-			}
-		}
-		while( true ){
-			array_push( $ret, implode( '', $word ) );
-			if( count( $bytes ) > 0 && $len >= $length || $len >= 3 ){
-//				$c1 = reset( unpack( "C", reset( $word ) ) );
-				$tmp = unpack( "C", reset( $word ) );
-				$c1 = reset( $tmp );
-				$tmp = $this -> utf8bytes( $c1 );
-//				for( $i = 0; $i < $this -> utf8bytes( $c1 ); $i++ ){
-				for( $i = 0; $i < $tmp; $i++ ){
-					array_shift( $word );
-				}
-				$len--;
-			}else break;
-			if( count( $bytes ) > 0 ){
-				$c1 = reset( $bytes );
-				for( $i = 0; $i < $this -> utf8bytes( $c1 ); $i++ ){
-					array_push( $word, pack( "C", array_shift( $bytes ) ) );
-				}
-				$len++;
-			}
-		}
-		return $ret;
-	}
-
-	/**
-	 * 
-	 * character strings are divided for search.
-	 * Multi byte character strings is applied to window processing of length of 8 characters.
-	 * don't change one byte character strings.
-	 * 
-	 */
-	function word_separation( $text ){
-		$multi = array();
-		$bytes = unpack( "C*", $text );
-		$c1 = 0;
-		$words = array();
-		while( count( $bytes ) >= 0 ){
-			$tmp = array();
-			if( count( $multi ) > 0 && ( $c1 & 0x80 ) != 0 && ( reset( $bytes ) & 0x80 ) == 0 ){
-				$words = array_merge( $words, $this -> window( $multi ) );
-				$multi = array();
-			}else if( count( $multi ) > 0 && ( $c1 & 0x80 ) == 0 && ( reset( $bytes ) & 0x80 ) != 0 ){ 
-				$tmp = array();
-				while( count( $multi ) > 0 ) array_push( $tmp, pack( "C", array_shift( $multi ) ) );
-				$words = array_merge( $words, explode( ' ', implode( '', $tmp ) ) );
-				$multi = array();
-			}
-			if( count( $bytes ) == 0 ) break;
-			$c1 = reset( $bytes );
-			if( $this -> utf8bytes( $c1 ) == 1 ){
-				array_push( $multi, array_shift( $bytes ) );
-			}else{
-				for( $i = 0; $i < $this -> utf8bytes( $c1 ); $i++ ){
-					array_push( $multi, array_shift( $bytes ) );
-				}
-			}
-		}
-		if( count( $multi ) > 0 ){
-			$tmp = array();
-			while( count( $multi ) > 0 ) array_push( $tmp, pack( "C", array_shift( $multi ) ) );
-			$words = array_merge( $words, explode( ' ', implode( '', $tmp ) ) );
-		}
-	
-		return $words;
-	}
-	
 }
 
-function array_walk_bin2hex( &$item1, $key ){
-	if ($item1 == '') return;
-	$tmp = unpack( "C", $item1 );
-//	if( ( reset( unpack( "C", $item1 ) ) & 0x80 ) == 0 || $item1 == ' ' || $item1 == "\n" ) return;
-	if( ( reset( $tmp ) & 0x80 ) == 0 || $item1 == ' ' || $item1 == "\n" ) return;
-	$item1 = bin2hex( $item1 );
-}
-
-
 /**
  * 
  * record resumptionToken and the related information.
@@ -1082,4 +1004,35 @@ function xnpGetMetadataJunii( $id ) {
 	}
 	return $metajunii;
 }
+
+function xnpGetMetadataJunii2( $id ) {
+	if (xnpChkServerLang()) {
+		if (_CHARSET == 'EUC-JP') {
+			include_once XOOPS_ROOT_PATH.'/modules/xoonips/language/japanese/metadata.php';
+		}
+		else {
+			include_once XOOPS_ROOT_PATH.'/modules/xoonips/language/japaneseutf/metadata.php';
+		}
+	}
+	else {
+		include_once XOOPS_ROOT_PATH.'/modules/xoonips/language/english/metadata.php';
+	}
+	$metajuniig = explode( '/', _MD_XOONIPS_METADATA_JUNII2 );
+	$i = 0;
+	$num = $id;
+	$num10 = ($num - ($num % 10)) / 10;
+	$num1 = $num % 10;
+	foreach ($metajuniig as $key => $value1) {
+		$metajuniis = explode( ',', $value1 );
+		$j = 0;
+		foreach ($metajuniis as $key => $value2) {
+			if (($i == $num10) && ($j == $num1)) {
+				$metajunii = $value2;
+			}
+			$j++;
+		}
+		$i++;
+	}
+	return $metajunii;
+}
 ?>
