@@ -1,5 +1,5 @@
 <?php
-// $Id: registeruser.php,v 1.7.4.10 2006/11/16 14:35:24 tani Exp $
+// $Id: registeruser.php,v 1.22.2.1 2007/03/22 05:25:07 tani Exp $
 //  ------------------------------------------------------------------------ //
 //                XOOPS - PHP Content Management System                      //
 //                    Copyright (c) 2000 XOOPS.org                           //
@@ -24,6 +24,11 @@
 //  along with this program; if not, write to the Free Software              //
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
 //  ------------------------------------------------------------------------ //
+//  Modified like below for XooNIps                                          //
+//  - XooNIps user information form and parameter check is added(2005/5/18)  //
+//  - XooNIps event of account is added(2005/7/7)                            //
+//  - Send e-mail for moderator(2006/9/5)                                    //
+//  ------------------------------------------------------------------------ //
 
 $xoopsOption['pagetype'] = 'user';
 
@@ -164,13 +169,13 @@ case 'newuser':
 	$pass = trim($pass);
 	$vpass = trim($vpass);
 	
-	$address      = trim($address      );
 	$division     = trim($division     );
-	$tel          = trim($tel          );
 	$company_name = trim($company_name );
+	$tel          = trim($tel          );
+	$fax          = trim($fax          );
+	$address      = trim($address      );
 	$country      = trim($country      );
 	$zipcode      = trim($zipcode      );
-	$fax          = trim($fax          );
 	$notice_mail  = (int)$notice_mail;
 	
 	$stop = userCheck($uname, $email, $pass, $vpass, $notice_mail);
@@ -199,13 +204,13 @@ case 'newuser':
     }
     
 	$errors = array();
-	if ( strlen($address     ) > 255 ) $errors[] = _MD_XOONIPS_ACCOUNT_REG_TOO_LONG_ADDRESS     ;
 	if ( strlen($division    ) > 255 ) $errors[] = _MD_XOONIPS_ACCOUNT_REG_TOO_LONG_DIVISION    ;
-	if ( strlen($tel         ) > 32  ) $errors[] = _MD_XOONIPS_ACCOUNT_REG_TOO_LONG_TEL         ;
 	if ( strlen($company_name) > 255 ) $errors[] = _MD_XOONIPS_ACCOUNT_REG_TOO_LONG_COMPANY_NAME;
+	if ( strlen($tel         ) > 32  ) $errors[] = _MD_XOONIPS_ACCOUNT_REG_TOO_LONG_TEL         ;
+	if ( strlen($fax         ) > 32  ) $errors[] = _MD_XOONIPS_ACCOUNT_REG_TOO_LONG_FAX         ;
+	if ( strlen($address     ) > 255 ) $errors[] = _MD_XOONIPS_ACCOUNT_REG_TOO_LONG_ADDRESS     ;
 	if ( strlen($country     ) > 255 ) $errors[] = _MD_XOONIPS_ACCOUNT_REG_TOO_LONG_COUNTRY     ;
 	if ( strlen($zipcode     ) > 32  ) $errors[] = _MD_XOONIPS_ACCOUNT_REG_TOO_LONG_ZIPCODE     ;
-	if ( strlen($fax         ) > 32  ) $errors[] = _MD_XOONIPS_ACCOUNT_REG_TOO_LONG_FAX         ;
 	if ( count($errors) != 0 )
 		$stop = $stop . implode("<br />\n", $errors) . "<br />\n";
 	
@@ -226,11 +231,12 @@ case 'newuser':
 		//@@@ display user information in XNP
 		echo _MD_XOONIPS_ACCOUNT_ADDRESS      .": ".$myts->makeTboxData4Preview($address      )."<br />";
 		echo _MD_XOONIPS_ACCOUNT_DIVISION     .": ".$myts->makeTboxData4Preview($division     )."<br />";
-		echo _MD_XOONIPS_ACCOUNT_TEL          .": ".$myts->makeTboxData4Preview($tel          )."<br />";
 		echo _MD_XOONIPS_ACCOUNT_COMPANY_NAME .": ".$myts->makeTboxData4Preview($company_name )."<br />";
+		echo _MD_XOONIPS_ACCOUNT_TEL          .": ".$myts->makeTboxData4Preview($tel          )."<br />";
+		echo _MD_XOONIPS_ACCOUNT_FAX          .": ".$myts->makeTboxData4Preview($fax          )."<br />";
+		echo _MD_XOONIPS_ACCOUNT_ADDRESS      .": ".$myts->makeTboxData4Preview($address      )."<br />";
 		echo _MD_XOONIPS_ACCOUNT_COUNTRY      .": ".$myts->makeTboxData4Preview($country      )."<br />";
 		echo _MD_XOONIPS_ACCOUNT_ZIPCODE      .": ".$myts->makeTboxData4Preview($zipcode      )."<br />";
-		echo _MD_XOONIPS_ACCOUNT_FAX          .": ".$myts->makeTboxData4Preview($fax          )."<br />";
 		echo _MD_XOONIPS_ACCOUNT_NOTICE_MAIL  .": ".$myts->makeTboxData4Preview($notice_mail  )."<br />";
 		
 		echo "<form action='registeruser.php' method='post'>
@@ -240,19 +246,19 @@ case 'newuser':
 		//echo "<input type='hidden' name='user_avatar' value='".$myts->makeTboxData4PreviewInForm($user_avatar)."' />";
 		$user_viewemail = isset($user_viewemail) ? intval($user_viewemail) : 0;
 		echo "<input type='hidden' name='user_viewemail' value='".$user_viewemail."' />
-		<input type='hidden' name='timezone_offset' value='".(float)$timezone_offset."' />
 		<input type='hidden' name='url' value='".$myts->makeTboxData4PreviewInForm($url)."' />
 		<input type='hidden' name='pass' value='".$myts->makeTboxData4PreviewInForm($pass)."' />
 		<input type='hidden' name='vpass' value='".$myts->makeTboxData4PreviewInForm($vpass)."' />
-		<input type='hidden' name='user_mailok' value='".intval($user_mailok)."' />
-		<input type='hidden' name='address' value='".$myts->makeTboxData4PreviewInForm($address)."' />
 		<input type='hidden' name='division' value='".$myts->makeTboxData4PreviewInForm($division)."' />
-		<input type='hidden' name='tel' value='".$myts->makeTboxData4PreviewInForm($tel)."' />
 		<input type='hidden' name='company_name' value='".$myts->makeTboxData4PreviewInForm($company_name)."' />
+		<input type='hidden' name='tel' value='".$myts->makeTboxData4PreviewInForm($tel)."' />
+		<input type='hidden' name='fax' value='".$myts->makeTboxData4PreviewInForm($fax)."' />
+		<input type='hidden' name='address' value='".$myts->makeTboxData4PreviewInForm($address)."' />
 		<input type='hidden' name='country' value='".$myts->makeTboxData4PreviewInForm($country)."' />
 		<input type='hidden' name='zipcode' value='".$myts->makeTboxData4PreviewInForm($zipcode)."' />
-		<input type='hidden' name='fax' value='".$myts->makeTboxData4PreviewInForm($fax)."' />
-		<input type='hidden' name='notice_mail' value='".intval($notice_mail)."' />";
+		<input type='hidden' name='timezone_offset' value='".(float)$timezone_offset."' />
+		<input type='hidden' name='notice_mail' value='".intval($notice_mail)."' />
+		<input type='hidden' name='user_mailok' value='".intval($user_mailok)."' />";
         
 		$value = '';
 		xnp_get_config_value( 'private_item_number_limit', $value );
@@ -289,13 +295,13 @@ case 'finish':
 	
 	
 	//@@@XNP
-	$address      = trim($address     );
 	$division     = trim($division    );
-	$tel          = trim($tel         );
 	$company_name = trim($company_name);
+	$tel          = trim($tel         );
+	$fax          = trim($fax         );
+	$address      = trim($address     );
 	$country      = trim($country     );
 	$zipcode      = trim($zipcode     );
-	$fax          = trim($fax         );
 	$notice_mail  = (int)$notice_mail;
 	
 	$stop = userCheck($uname, $email, $pass, $vpass, $notice_mail);
@@ -350,17 +356,29 @@ case 'finish':
 		if ( $private_item_storage_limit == "" ) $private_item_storage_limit = 'NULL';
 		else                                     $private_item_storage_limit = (double)$private_item_storage_limit;
 		
+		// position value = Registered Users
+		$posi = '';
+		$potab = $xoopsDB -> prefix("xoonips_positions");
+		$posql = "SELECT posi_id FROM ".$potab." WHERE posi_title='Registered Users'";
+		$pores = $xoopsDB -> query( $posql );
+		// there is no title 'Registered Users' in xoonips_positions => posi = 0
+		if ( $pores == FALSE ){
+			echo "ERROR: SQL=$posql<br />\n error=" . $xoopsDB -> error() . "<br />\n";
+		}
+		$po = $xoopsDB -> fetchArray( $pores );
+		$posi = intval( $po['posi_id'] );
+				
 		// add user information in XNP
 		$table = $xoopsDB->prefix("xoonips_users");
 		$uid = $newuser->getVar('uid');
 		$xoonips_keys = array(
-			'address'      ,
 			'division'     ,
-			'tel'          ,
 			'company_name' ,
+			'tel'          ,
+			'fax'          ,
+			'address'      ,
 			'country'      ,
 			'zipcode'      ,
-			'fax'          ,
 			'notice_mail'  
 		);
 		$keys = implode( ',', $xoonips_keys );
@@ -373,14 +391,40 @@ case 'finish':
 			$val_ar[] = "'" . $myts->addSlashes( $$key ) . "'";
 		}
 		$vals = implode( ',', $val_ar );
-		$sql = "replace $table ( uid, $keys, notice_mail_since, private_item_number_limit, private_index_number_limit, private_item_storage_limit ) ".
-		               "values ( $uid, $vals, UNIX_TIMESTAMP(NOW()),$private_item_number_limit,$private_index_number_limit,$private_item_storage_limit )";
+		$sql = "replace $table ( uid, $keys, notice_mail_since, private_item_number_limit, private_index_number_limit, private_item_storage_limit, posi ) ".
+		               "values ( $uid, $vals, UNIX_TIMESTAMP(NOW()),$private_item_number_limit,$private_index_number_limit,$private_item_storage_limit,$posi )";
 		if ( mysql_query( $sql ) == FALSE ){
 			echo _US_REGISTERNG;
 			require( XOOPS_ROOT_PATH.'/footer.php' );
 			exit();
 		}
 		
+		// insert uid into xoonips_item_show
+		$isql = "SELECT item_id FROM ".$xoopsDB->prefix('xoonips_item_status')."";
+		$ires = $xoopsDB->query($isql);
+			if(!$ires){
+				$err = "Can't select data from database.";
+			}
+			if($ires == FALSE){
+				echo "ERROR: SQL=$isql<br />\n error=" . $xoopsDB->error() . "<br />\n";
+			}
+			$ins_iids = array();
+			while( $irow = $xoopsDB->fetchArray($ires) ){
+				$ins_iids[] = intval( $irow['item_id'] );
+			}
+			if( !empty( $ins_iids ) ){
+				foreach( $ins_iids as $itemnum => $itid ){
+					$ins_sql = "INSERT INTO ".$xoopsDB->prefix('xoonips_item_show')." (item_id, uid) VALUES (".$itid.", ".$uid.")";
+					$ins_res = $xoopsDB->query($ins_sql);
+					if(!$ins_res) {
+					$err = "Can't select data from database.";
+					}
+					if($ins_res == FALSE) {
+						echo "ERROR: SQL=$ins_sql<br />\n error=" . $xoopsDB->error() . "<br />\n";
+					}
+				}
+			}
+		
 		// record events(request insert account)
 		xnp_insert_event( XNPSID_GUEST, ETID_REQUEST_INSERT_ACCOUNT, time(), UID_GUEST, xnpGetRemoteHost(), array( 'uid' => $uid ) );
 		
@@ -425,7 +469,11 @@ case 'finish':
 					" values ( $index_id, 1, $uid, NULL, 3, $sort_number ) " ) ){
 					$table = $xoopsDB->prefix( 'xoonips_users' );
 					if ( $xoopsDB->queryF( "update $table set private_index_id = $index_id where uid = $uid " ) ){
-						$success = true;
+						// add data into item_table
+						$item_title_table = $xoopsDB->prefix( 'xoonips_item_title' );
+						if ( $xoopsDB->query( "insert into $item_title_table (item_id, title_id, title) values ($index_id, 0, '$escUname')" ) ){
+							$success = true;
+						}
 					}
 				}
 			}
