@@ -1,5 +1,5 @@
 <?php
-//  $Revision: 1.23.2.6 $                                                                  //
+//  $Revision: 1.32.2.3 $                                                                  //
 //  --------------------------------------------------------------------------  //
 //  XooNIps Xoops modules for Neuroinformatics Platforms                        //
 //  Copyright (C) 2005 RIKEN, Japan. All rights reserved.                       //
@@ -50,11 +50,27 @@
  *   $_GET['edit_binder']
  *           Specified:display Private and Public. Display only Binder's checkbox in Public tab.
  *   (If there is window.top.form[].xoonipsCheckedXID, get initial value in checkbox.)
+ *   $_GET['edit_public']
+ *           Specified:display Public if su.
+ *   $_GET['puid']
+ *           displaying a user's tree specified by puid if xoopsUser is moderator and puid is specified.
  * 
  * output:
  *   nothing. Getting state of checkbox in onSubmit isn't work of 'tree.php'.
  */
 
+/*
+  the font used in a tree is specified like following in css of theme
+    div  .tree { font definition }
+
+  for example
+    .tree {
+        font-family: Times;
+        font-size: 10pt;
+        font-weight: bold;
+    }
+
+*/
 
 /*
   Succession of information in Open/Close, Checked, and Tab.
@@ -108,13 +124,13 @@ opened and visible
 */
 
 
-	$times = array();
-	$times[__LINE__] = posix_times();
+//	$times = array();
+//	$times[__LINE__] = posix_times();
 	//$xoopsOption['pagetype'] = 'user';
 	$xoopsOption['pagetype'] = "pmsg";
 	include_once "../../mainfile.php";
 
-	$times[__LINE__] = posix_times();
+//	$times[__LINE__] = posix_times();
 	include_once XOOPS_ROOT_PATH.'/class/module.textsanitizer.php';
 	include_once XOOPS_ROOT_PATH . '/modules/system/constants.php';
 
@@ -129,17 +145,30 @@ opened and visible
 	
 	
 	// tree node images
-	define("T1_GIF", "images/t1.gif");
-	define("T2_GIF", "images/t2.gif");
-	define("T3_GIF", "images/t3.gif");
-	define("T4_GIF", "images/t4.gif");
-	define("T5_GIF", "images/t5.gif");
-	define("T6_GIF", "images/t6.gif");
-	define("T7_GIF", "images/t7.gif");
-	define("T8_GIF", "images/t8.gif");
-	define("T9_GIF", "images/t9.gif");
-	
-	
+    $tree_swap_image_path = $xoopsConfig['theme_set'].'/'.XOONIPS_TREE_SWAP_IMAGE_DIR;
+    if( is_dir(XOOPS_THEME_PATH.'/'.$tree_swap_image_path) ) {
+		$xoops_themes_dir = str_replace(XOOPS_ROOT_PATH, '', XOOPS_THEME_PATH);
+		define("T1_GIF", "../..".$xoops_themes_dir."/".$tree_swap_image_path."/t1.gif");
+		define("T2_GIF", "../..".$xoops_themes_dir."/".$tree_swap_image_path."/t2.gif");
+		define("T3_GIF", "../..".$xoops_themes_dir."/".$tree_swap_image_path."/t3.gif");
+		define("T4_GIF", "../..".$xoops_themes_dir."/".$tree_swap_image_path."/t4.gif");
+		define("T5_GIF", "../..".$xoops_themes_dir."/".$tree_swap_image_path."/t5.gif");
+		define("T6_GIF", "../..".$xoops_themes_dir."/".$tree_swap_image_path."/t6.gif");
+		define("T7_GIF", "../..".$xoops_themes_dir."/".$tree_swap_image_path."/t7.gif");
+		define("T8_GIF", "../..".$xoops_themes_dir."/".$tree_swap_image_path."/t8.gif");
+		define("T9_GIF", "../..".$xoops_themes_dir."/".$tree_swap_image_path."/t9.gif");
+	}
+    else {
+		define("T1_GIF", "images/t1.gif");
+		define("T2_GIF", "images/t2.gif");
+		define("T3_GIF", "images/t3.gif");
+		define("T4_GIF", "images/t4.gif");
+		define("T5_GIF", "images/t5.gif");
+		define("T6_GIF", "images/t6.gif");
+		define("T7_GIF", "images/t7.gif");
+		define("T8_GIF", "images/t8.gif");
+		define("T9_GIF", "images/t9.gif");
+	}
 	
 	if ( !empty($xoopsUser) ){
 		$uid = $xoopsUser->getVar('uid');
@@ -148,8 +177,10 @@ opened and visible
 		$uid = UID_GUEST;
 	}
 
-	$guest_enabled = xnp_is_valid_session_id(XNPSID_GUEST);
-	if ( $uid == UID_GUEST && !$guest_enabled ){
+	if ( $uid == UID_GUEST && !public_item_target_user_all() ){
+		// 
+		// for guest access, show message that access to index tree is forbidden.
+		// 
 		xoops_header( false );
 		echo "</head><body><div style='font-size: 10pt;'>";
 		echo _MD_XOONIPS_INDEX_FORBIDDEN;
@@ -163,14 +194,22 @@ opened and visible
 	$edit_binder = !empty( $_GET['edit_binder'] );
 	
 	$indexes = genIndexTree0( $xnpsid );
+	$is_moderator = xnp_is_moderator( $xnpsid, $uid );
+	
+	if ( $is_moderator && isset($_GET['puid']) )
+		$puid = $_GET['puid'];
+	else
+		$puid = $uid;
+	
 	if ( $edit_binder )
-		filterPublicPrivateIndex( $indexes, $uid );
-	else if ( xnp_is_moderator( $xnpsid, $uid ) )
-		filterMyIndex( $indexes, $xnpsid, $uid );
+		filterPublicPrivateIndex( $indexes, $puid );
+	else if ( $is_moderator )
+		filterMyIndex( $indexes, $xnpsid, $puid );
 	else
 		;
+	
 	if ( !empty( $_GET['edit'] ) )
-		filterEditableIndex( $indexes, $xnpsid, $uid );
+		filterEditableIndex( $indexes, $xnpsid, $uid, $puid, !empty($_GET['edit_public']) && !empty($_SESSION['xoonips_old_uid']) );
 	
 	if ( !empty( $_GET['hide_binders'] ) )
 		filterNonbinderIndex( $indexes );
@@ -204,16 +243,17 @@ opened and visible
 	}
 	unset( $index );
 	
+	
 ?>
-<<? echo "?"; ?>xml version="1.0" encoding="<?php echo _CHARSET;?>">
-<?
+<<?php echo "?"; ?>xml version="1.0" encoding="<?php echo _CHARSET;?>">
+<?php
 	xoops_header( false );
 ?>
   <style type="text/css">
   <!--
   .directory { font-size: 10pt; font-weight: bold; }
   .directory p { margin: 0px; white-space: nowrap; line-height: 10pt; vertical-align: text-bottom; }
-  .el { margin: 0px; white-space: nowrap; vertical-align: text-bottom; font-size: 10pt; font-weight: bold; }
+  .tree { margin: 0px; white-space: nowrap; vertical-align: text-bottom; font-size: 10pt; font-weight: bold; }
   .directory div { margin: 0px; white-space: nowrap; }
   .directory img { vertical-align: text-bottom; }
   .directory table {  border-spacing: 0px; margin: 0px; border: 0px; padding: 0px; height: 19px;}
@@ -289,9 +329,9 @@ function toggleCheckbox(){
 
 
 var treeHere;
-var url = "<? echo isset( $_GET['url'] ) ? htmlspecialchars($_GET['url']) : 'listitem.php'; ?>";
-var linkIsCheckbox = <? echo (int)( $checkbox || $edit_binder ); ?>;
-var formname = "<? echo empty($_GET['form']) ? '' : htmlspecialchars($_GET['form']); ?>";
+var url = "<?php echo isset( $_GET['url'] ) ? htmlspecialchars($_GET['url']) : 'listitem.php'; ?>";
+var linkIsCheckbox = <?php echo (int)( $checkbox || $edit_binder ); ?>;
+var formname = "<?php echo empty($_GET['form']) ? '' : htmlspecialchars($_GET['form']); ?>";
 var xid2n = {};
 var checkedPrivateCount = 0;
 
@@ -315,14 +355,17 @@ var nodes = [
 	function xnpEntity2Ecma262sub( $str ){
 		return sprintf( '\\u%04x', (int)$str[1] );
 	}
-	
 	// \ -> \\
 	// " -> \"
+	// < -> \x3c
+	// > -> \x3e
+	// \r-> \r
+	// \n-> \n
 	// &#ddddd; => \uxxxx(ECMA262)
 	// EUC characters in $str => unicode (in browser)
 	function xnpEntity2Ecma262($str){
 		return preg_replace_callback('/&#([0-9]+);/i', 'xnpEntity2Ecma262sub', 
-		  str_replace(array('\\', '"'), array('\\\\', '\\"'), $str ));
+		  str_replace(array('\\', '"', '<', '>', "\r", "\n"), array('\\\\', '\\"', '\\x3c', '\\x3e', '\\r', '\\n'), $str ));
 	}
 	
 	$length = count($indexes);
@@ -333,7 +376,7 @@ var nodes = [
 		$isLast      = $index['is_last'] ? 1 : 0;
 		$hasCheckbox = $index['hasCheckbox'];
 		$checkPrivate= $index['checkPrivate'];
-		$htmlTitle   = xnpEntity2Ecma262($index['title']);
+		$htmlTitle   = xnpEntity2Ecma262($index['titles'][DEFAULT_INDEX_TITLE_OFFSET]);
 		$itemCount   = isset($itemCounts[$xid]) ? $itemCounts[$xid] : 0;
 		if ( $itemCount )
 			$htmlTitle .= "($itemCount)";
@@ -354,7 +397,7 @@ var nodes = [
 ];
 
 var treeRoots = [
-<?
+<?php
 	$sep = "";
 	foreach( $indexes as $i => $index ){
 		if ( $index['depth'] == 1 ){
@@ -468,15 +511,15 @@ function CreateClosedElem( n, isVisible, lastinfo, isLast, parent, before ){
 		for ( var i = 0; i < len; i++ ){
 			var img = document.createElement('IMG');
 			div.appendChild( img );
-			if ( i == 0 )                         { img.width =  3; img.height = 19; img.src = '<? echo T9_GIF; ?>'; }
-			else if ( lastinfo.charAt(i) == "1" ) { img.width = 10; img.height = 19; img.src = '<? echo T4_GIF; ?>'; }
-			else                                  { img.width = 10; img.height = 19; img.src = '<? echo T2_GIF; ?>'; }
+			if ( i == 0 )                         { img.width =  3; img.height = 19; img.src = '<?php echo T9_GIF; ?>'; }
+			else if ( lastinfo.charAt(i) == "1" ) { img.width = 10; img.height = 19; img.src = '<?php echo T4_GIF; ?>'; }
+			else                                  { img.width = 10; img.height = 19; img.src = '<?php echo T2_GIF; ?>'; }
 		}
 /*
 		span = document.createElement('span');
 		span.width = len*10-7;
 		span.height = 19;
-		span.src = '<? echo T2_GIF; ?>';
+		span.src = '<?php echo T2_GIF; ?>';
 		div.appendChild( span );
 */
 	}
@@ -484,14 +527,14 @@ function CreateClosedElem( n, isVisible, lastinfo, isLast, parent, before ){
 	var img = document.createElement('IMG');
 	div.appendChild( img );
 	if ( node.child == null ){
-		if ( len == 0 )                         img.src = '<? echo T7_GIF; ?>';
-		else if ( lastinfo.charAt(len) == "1" ) img.src = '<? echo T3_GIF; ?>';
-		else                                    img.src = '<? echo T1_GIF; ?>';
+		if ( len == 0 )                         img.src = '<?php echo T7_GIF; ?>';
+		else if ( lastinfo.charAt(len) == "1" ) img.src = '<?php echo T3_GIF; ?>';
+		else                                    img.src = '<?php echo T1_GIF; ?>';
 	}
 	else {
-		if ( len == 0 )                         img.src = '<? echo T8_GIF; ?>';
-		else if ( lastinfo.charAt(len) == "1" ) img.src = '<? echo T6_GIF; ?>';
-		else                                    img.src = '<? echo T5_GIF; ?>';
+		if ( len == 0 )                         img.src = '<?php echo T8_GIF; ?>';
+		else if ( lastinfo.charAt(len) == "1" ) img.src = '<?php echo T6_GIF; ?>';
+		else                                    img.src = '<?php echo T5_GIF; ?>';
 		img.onclick = onClickImg;
 		img.n = n;
 	}
@@ -525,7 +568,7 @@ function CreateClosedElem( n, isVisible, lastinfo, isLast, parent, before ){
 	
 	if ( formname ){
 		var a = document.createElement( 'A' );
-		a.className = 'el';
+		a.className = 'tree';
 		a.xid = node.xid;
 		a.onclick = xoonipsSubmit;
 		a.target = '_top';
@@ -536,7 +579,7 @@ function CreateClosedElem( n, isVisible, lastinfo, isLast, parent, before ){
 	else if ( linkIsCheckbox ){
 		if ( node.hasCheckbox ){
 			var a = document.createElement( 'A' );
-			a.className = 'el';
+			a.className = 'tree';
 			a.href = '';
 			a.onclick = toggleCheckbox;
 			a.xid = node.xid;
@@ -547,12 +590,15 @@ function CreateClosedElem( n, isVisible, lastinfo, isLast, parent, before ){
 			a.appendChild( text );
 		}
 		else {
-			div.appendChild( text );
+			var span = document.createElement( 'SPAN' );
+			span.className = 'tree';
+			div.appendChild( span );
+			span.appendChild( text );
 		}
 	}
 	else if ( url ){
 		var a = document.createElement( 'A' );
-		a.className = 'el';
+		a.className = 'tree';
 		a.href = url + '?index_id=' + node.xid;
 		a.target = '_top';
 		
@@ -560,7 +606,10 @@ function CreateClosedElem( n, isVisible, lastinfo, isLast, parent, before ){
 		a.appendChild( text );
 	}
 	else {
-		div.appendChild( text );
+		var span = document.createElement( 'SPAN' );
+		span.className = 'tree';
+		div.appendChild( span );
+		span.appendChild( text );
 	}
 	
 	div.id = 'node' + n;
@@ -850,7 +899,7 @@ function onClickCheckbox(){
  </div>
 </div>
 </form>
-<?
+<?php
 /*	foreach ( $times as $key=>$val ){
 		echo " $key " . $val['ticks'] . "<br>";
 	}
